@@ -11,10 +11,10 @@
 #include "util/arg_auto_set.h"
 #include "Rev.h"
 
-#define version "3.0.4"
+#define version "3.0.6"
 
 #define REQ_LIBRND_MAJOR 3
-#define REQ_LIBRND_MINOR 1
+#define REQ_LIBRND_MINOR 2
 
 #define TOSTR_(x) #x
 #define TOSTR(x) TOSTR_(x)
@@ -22,15 +22,15 @@
 #include <librnd/src_3rd/puplug/scconfig_hooks.h>
 #include <librnd/src_3rd/libfungw/scconfig_hooks.h>
 
+/* we are doing /local/pcb/ */
+#define LIBRND_SCCONFIG_APP_TREE "pcb"
+
 #include <librnd/scconfig/plugin_3state.h>
 #include <librnd/scconfig/hooks_common.h>
 #include <librnd/scconfig/rnd_hook_detect.h>
 
 const arg_auto_set_t disable_libs[] = { /* list of --disable-LIBs and the subtree they affect */
 	{"disable-gd",        "libs/gui/gd",                  arg_lib_nodes, "$do not use gd (many exporters need it)"},
-	{"disable-gd-gif",    "libs/gui/gd/gdImageGif",       arg_lib_nodes, "$no gif support in the png rnd_exporter"},
-	{"disable-gd-png",    "libs/gui/gd/gdImagePng",       arg_lib_nodes, "$no png support in the png rnd_exporter"},
-	{"disable-gd-jpg",    "libs/gui/gd/gdImageJpeg",      arg_lib_nodes, "$no jpeg support in the png rnd_exporter"},
 	{"enable-bison",      "/local/pcb/want_bison",        arg_true,      "$enable generating language files using bison/flex"},
 	{"disable-bison",     "/local/pcb/want_bison",        arg_false,     "$disable generating language files using bison/flex"},
 	{"enable-byaccic",    "/local/pcb/want_byaccic",      arg_true,      "$enable generating language files using byaccic/ureglex"},
@@ -178,7 +178,7 @@ int hook_detect_target()
 {
 	int want_gd, want_xml2, want_freetype2, want_fuse;
 
-	want_gd     = plug_is_enabled("export_png") || plug_is_enabled("import_pxm_gd");
+	want_gd     = plug_is_enabled("export_png");
 	want_xml2   = plug_is_enabled("io_eagle") || plug_is_enabled("order_pcbway") || plug_is_enabled("stl_export");
 	want_freetype2 = plug_is_enabled("import_ttf");
 	want_fuse = plug_is_enabled("export_vfs_fuse");
@@ -222,30 +222,12 @@ int hook_detect_target()
 		require("libs/gui/gd/presents", 0, 0);
 		if (!istrue(get("libs/gui/gd/presents"))) {
 			report_repeat("WARNING: Since there's no libgd, disabling gd based exports and pixmap imports (png, gif, jpeg)...\n");
-			hook_custom_arg("disable-gd-gif", NULL);
-			hook_custom_arg("disable-gd-png", NULL);
-			hook_custom_arg("disable-gd-jpg", NULL);
 			hook_custom_arg("disable-export_png", NULL);
-			hook_custom_arg("disable-import_pxm_gd", NULL);
 			want_gd = 0;
-			goto disable_gd_formats;
-		}
-		else {
-			require("libs/gui/gd/gdImagePng/presents", 0, 0);
-			require("libs/gui/gd/gdImageGif/presents", 0, 0);
-			require("libs/gui/gd/gdImageJpeg/presents", 0, 0);
-			require("libs/gui/gd/gdImageSetResolution/presents", 0, 0);
-			if (!istrue(get("libs/gui/gd/gdImagePng/presents"))) {
-				report_repeat("WARNING: libgd is installed, but its png code fails, some exporters will be compiled with reduced functionality\n");
-			}
 		}
 	}
 	else {
 		put("libs/gui/gd/presents", sfalse);
-		disable_gd_formats:;
-		put("libs/gui/gd/gdImagePng/presents", sfalse);
-		put("libs/gui/gd/gdImageGif/presents", sfalse);
-		put("libs/gui/gd/gdImageJpeg/presents", sfalse);
 	}
 
 	/* yacc/lex - are we able to regenerate languages? */
