@@ -34,6 +34,7 @@ int find_io_pipe(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
 		NL "#include <unistd.h>"
+		NL "#include <stdio.h>"
 		NL "int main() {"
 		NL "	int fd[2];"
 		NL "	if (pipe(fd) == 0)"
@@ -48,11 +49,55 @@ int find_io_pipe(const char *name, int logdepth, int fatal)
 	logprintf(logdepth, "find_io_pipe: trying to find pipe(2)...\n");
 	logdepth++;
 
-
-	if (try_icl(logdepth, "libs/io/pipe", test_c, NULL, NULL, NULL)) return 0;
+	if (try_icl(logdepth, "libs/io/pipe", test_c, "#include <unistd.h>\n", NULL, NULL)) return 0;
 	return try_fail(logdepth, "libs/io/pipe");
 }
 
+int find_io_pipe2(const char *name, int logdepth, int fatal)
+{
+	const char *test_c =
+		NL "#include <unistd.h>"
+		NL "#include <stdio.h>"
+		NL "int main() {"
+		NL "	int fd[2];"
+		NL "	if (pipe2(fd, 0) == 0)"
+		NL "		puts(\"OK\");"
+		NL "	return 0;"
+		NL "}"
+		NL;
+
+	require("cc/cc", logdepth, fatal);
+
+	report("Checking for pipe2(2)... ");
+	logprintf(logdepth, "find_io_pipe2: trying to find pipe2(2)...\n");
+	logdepth++;
+
+	if (try_icl(logdepth, "libs/io/pipe2", test_c, "#include <unistd.h>\n", NULL, NULL)) return 0;
+	return try_fail(logdepth, "libs/io/pipe2");
+}
+
+int find_io__pipe(const char *name, int logdepth, int fatal)
+{
+	const char *test_c =
+		NL "#include <stdio.h>"
+		NL "int main() {"
+		NL "	int fd[2];"
+		NL "	if (_pipe(fd, 1024, _O_BINARY) == 0)"
+		NL "		puts(\"OK\");"
+		NL "	return 0;"
+		NL "}"
+		NL;
+
+	require("cc/cc", logdepth, fatal);
+
+	report("Checking for _pipe()... ");
+	logprintf(logdepth, "find_io__pipe: trying to find _pipe()...\n");
+	logdepth++;
+
+	if (try_icl(logdepth, "libs/io/_pipe", test_c, "#include <io.h>\n#include <fcntl.h>\n", NULL, NULL)) return 0;
+	return try_fail(logdepth, "libs/io/_pipe");
+}
+
 int find_io_dup2(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
@@ -82,7 +127,7 @@ int find_io_fileno(const char *name, int logdepth, int fatal)
 	char *test_c_ =
 		NL "#include <stdio.h>"
 		NL "int main() {"
-		NL no_implicit(int, "%s", "%s")
+		    /* NOTE: can not check for implicit declaration as fileno() may be a macro (e.g. on MINIX3) */
 		NL "	if (%s(stdout) >= 0)"
 		NL "		puts(\"OK\"); "
 		NL "	return 0;"
@@ -96,20 +141,26 @@ int find_io_fileno(const char *name, int logdepth, int fatal)
 	logdepth++;
 
 	/* UNIX */
-	sprintf(test_c, test_c_, "fileno", "fileno", "fileno");
+	sprintf(test_c, test_c_, "fileno");
+	if (try_icl(logdepth, "libs/io/fileno", test_c, NULL, NULL, NULL)) {
+		put("libs/io/fileno/call", "fileno");
+		return 0;
+	}
+
+	sprintf(test_c, test_c_, "fileno");
 	if (try_icl(logdepth, "libs/io/fileno", test_c, "#include <unistd.h>\n", NULL, NULL)) {
 		put("libs/io/fileno/call", "fileno");
 		return 0;
 	}
 
-	sprintf(test_c, test_c_, "fileno", "fileno", "fileno");
+	sprintf(test_c, test_c_, "fileno");
 	if (try_icl(logdepth, "libs/io/fileno", test_c, "#define _XOPEN_SOURCE\n#include <unistd.h>\n", NULL, NULL)) {
 		put("libs/io/fileno/call", "fileno");
 		return 0;
 	}
 
 	/* windows */
-	sprintf(test_c, test_c_, "_fileno", "_fileno", "_fileno");
+	sprintf(test_c, test_c_, "_fileno");
 	if (try_icl(logdepth, "libs/io/fileno", test_c, "#include <stdio.h>\n", NULL, NULL)) {
 		put("libs/io/fileno/call", "_fileno");
 		return 0;
