@@ -27,6 +27,7 @@
 int find_script_stutter(const char *name, int logdepth, int fatal)
 {
 	char *test_c =
+		NL "#include <stdio.h>"
 		NL "#include <stutter.h>"
 		NL "int main() {"
 		NL "	varctx *global;"
@@ -53,3 +54,35 @@ int find_script_stutter(const char *name, int logdepth, int fatal)
 
 	return try_fail(logdepth, "libs/script/stutter");
 }
+
+int find_script_estutter(const char *name, int logdepth, int fatal)
+{
+	char *test_c =
+		NL "#include <stdio.h>"
+		NL "#include <estutter/stutter.h>"
+		NL "int main() {"
+		NL "	stt_ctx_t stt;"
+		NL "	stt.next_serial = 4242;"
+		NL "	stt_init(&stt);"
+		NL "	if (stt.next_serial != 4242)"
+		NL "		puts(\"OK\");"
+		NL "	return 0;"
+		NL "}"
+		NL;
+
+	require("cc/cc", logdepth, fatal);
+
+	report("Checking for estutter... ");
+	logprintf(logdepth, "find_estutter: trying to find estutter...\n");
+	logdepth++;
+
+	/* TODO: do we need -ldl? */
+	if (
+			try_icl(logdepth, "libs/script/estutter", test_c, NULL, NULL, "-lestutter") ||
+			try_icl(logdepth, "libs/script/estutter", test_c, NULL, "-I/usr/include/estutter", "-lestutter") ||
+			try_icl(logdepth, "libs/script/estutter", test_c, NULL, "-I/usr/local/include/estutter", "-lestutter")
+			)
+		return 0;
+
+	return try_fail(logdepth, "libs/script/estutter");
+}
