@@ -41,10 +41,16 @@ void deps_scripts_init()
 	dep_add("libs/script/estutter/*",       find_script_estutter);
 	dep_add("libs/script/funlisp/*",        find_script_funlisp);
 	dep_add("libs/script/duktape/*",        find_script_duktape);
+	dep_add("libs/script/mujs/*",           find_script_mujs);
+	dep_add("libs/script/mujs_isboolean/*", find_script_mujs_isboolean);
 	dep_add("libs/script/m4/bin/*",         find_script_m4);
+	dep_add("libs/script/welltype/*",       find_script_welltype);
+	dep_add("libs/script/welltype/wtc/*",   find_script_wtc);
+	dep_add("libs/script/picol/*",          find_script_picol);
 
 	dep_add("libs/script/fungw/presents",         find_script_fungw);
 	dep_add("libs/script/fungw/user_call_ctx/*",  find_script_fungw_user_call_ctx);
+	dep_add("libs/script/fungw/cfg_pupdir/*",     find_script_fungw_cfg_pupdir);
 	dep_add("libs/script/fungw/*",                find_script_fungw_all);
 }
 
