@@ -62,3 +62,40 @@ int find_sul_libext2fs(const char *name, int logdepth, int fatal)
 
 	return try_fail(logdepth, node);
 }
+
+int find_sul_fuse(const char *name, int logdepth, int fatal)
+{
+	const char *test_c =
+		NL "#include <stdio.h>"
+		NL "static struct fuse_operations oper;"
+		NL "int main()"
+		NL "{"
+		NL "	char *argv[] = {\"fusetest\", \"-h\", NULL};"
+		NL "	int ret;"
+		NL "	fclose(stderr);"
+		NL "	ret = fuse_main(2, argv, &oper, NULL);"
+		NL "	if ((ret == 1) || (ret == 0))"
+		NL "		puts(\"OK\");"
+		NL "	return 0;"
+		NL "}"
+		NL;
+	const char *node = "libs/sul/fuse";
+	const char **inc;
+	const char *incs[] = {
+		"#define FUSE_USE_VERSION 26\n#include <fuse.h>",
+		"#define _FILE_OFFSET_BITS 64\n#define FUSE_USE_VERSION 26\n#include <fuse.h>",
+		"#if ((!defined _POSIX_C_SOURCE || (_POSIX_C_SOURCE - 0) < 199309L))\n#define _POSIX_C_SOURCE 199309\n#define FUSE_USE_VERSION 26\n#include <fuse.h>",
+		"#if ((!defined _POSIX_C_SOURCE || (_POSIX_C_SOURCE - 0) < 199309L))\n#define _POSIX_C_SOURCE 199309\n#endif\n#define _FILE_OFFSET_BITS 64\n#define FUSE_USE_VERSION 26\n#include <fuse.h>",
+		NULL};
+
+	if (require("cc/cc", logdepth, fatal))
+		return 1;
+
+	report("Checking for fuse... ");
+
+	for(inc = incs; *inc != NULL; inc++)
+		if (try_icl(logdepth, node, test_c, *inc, NULL, "-lfuse"))
+			return 0;
+
+	return try_fail(logdepth, node);
+}
