@@ -41,7 +41,8 @@ int find_gpm(const char *name, int logdepth, int fatal)
 		NL "	Gpm_Open(&conn, 0);"
 		NL "	puts(\"OK\");"
 		NL "	return 0;"
-		NL "}";
+		NL "}"
+		NL;
 	if (require("cc/cc", logdepth, fatal))
 		return 1;
 
