@@ -42,7 +42,8 @@ int find_slang(const char *name, int logdepth, int fatal)
 		NL "	else"
 		NL "		puts(\"OK\");"
 		NL "	return 0;"
-		NL "}";
+		NL "}"
+		NL;
 	if (require("cc/cc", logdepth, fatal))
 		return 1;
 
