@@ -67,7 +67,9 @@ char *pcb_get_info_program(void)
 		first_time = 0;
 		gds_init(&info);
 		gds_append_str(&info, "This is pcb-rnd " PCB_VERSION " (" PCB_REVISION ")" "\nan interactive ");
-		gds_append_str(&info, "printed circuit board editor\nfrom the Ringdove EDA suite\ncompiled using librnd version " RND_VER_STR "\n");
+		gds_append_str(&info, "printed circuit board editor\nfrom the Ringdove EDA suite\ncompiled using librnd version " RND_VER_STR "\nrunning with librnd version ");
+		gds_append_str(&info, rnd_ver_str);
+		gds_append(&info, '\n');
 	}
 	return info.array;
 }
@@ -82,7 +84,7 @@ char *pcb_get_info_copyright(void)
 		gds_init(&info);
 
 		gds_append_str(&info, "Recent pcb-rnd copyright:\n");
-		gds_append_str(&info, "Copyright (C) Tibor Palinkas 2013..2021 (pcb-rnd)\n");
+		gds_append_str(&info, "Copyright (C) Tibor Palinkas 2013..2022 (pcb-rnd)\n");
 		gds_append_str(&info, "For a more complete list of pcb-rnd authors and\ncontributors, see http://repo.hu/cgi-bin/pcb-rnd-people.cgi\n\n");
 
 		gds_append_str(&info, "Historical copyright:\n");
