@@ -487,6 +487,7 @@ static fgw_error_t pcb_act_ChangeName(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	int op;
 	char *name;
 	pcb_objtype_t type;
+	rnd_coord_t x, y;
 
 	RND_ACT_CONVARG(1, FGW_KEYWORD, ChangeName, op = fgw_keyword(&argv[1]));
 
@@ -494,7 +495,6 @@ static fgw_error_t pcb_act_ChangeName(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		/* change the refdes of a subcircuit */
 		case F_Subc:
 		{
-			rnd_coord_t x, y;
 			rnd_hid_get_coords("Select a subcircuit", &x, &y, 0);
 			type = op = PCB_OBJ_SUBC;
 			goto do_chg_name;
@@ -503,7 +503,6 @@ static fgw_error_t pcb_act_ChangeName(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		case F_Object:
 		case F_Refdes:
 			{
-				rnd_coord_t x, y;
 				void *ptr1, *ptr2, *ptr3;
 				rnd_hid_get_coords("Select an Object", &x, &y, 0);
 				type = op == F_Refdes ? PCB_OBJ_SUBC : PCB_CHANGENAME_TYPES;
@@ -677,7 +676,7 @@ static fgw_error_t pcb_act_SetThermal(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_CONVARG(2, FGW_STR, SetThermal, style = argv[2].val.str);
 
 	if (function && *function && style && *style) {
-		rnd_bool absolute;
+		rnd_bool absolute = 1;
 
 		if (rnd_strcasecmp(style, "noshape") == 0)
 			kind = PCB_THERMAL_NOSHAPE | PCB_THERMAL_ON;
@@ -689,7 +688,14 @@ static fgw_error_t pcb_act_SetThermal(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			switch (rnd_funchash_get(function, NULL)) {
 			case F_Object:
 				rnd_hid_get_coords("Click on object for SetThermal", &gx, &gy, 0);
-				if ((type = pcb_search_screen(gx, gy, PCB_CHANGETHERMAL_TYPES, &ptr1, &ptr2, &ptr3)) != PCB_OBJ_VOID) {
+				/* prefer padstacks */
+				type = pcb_search_screen(gx, gy, PCB_CHANGETHERMAL_TYPES | PCB_OBJ_PSTK, &ptr1, &ptr2, &ptr3);
+#if 0
+This would need extra checks for object being on a copper layer
+				if (type == PCB_OBJ_VOID) /* fall back on any thermal */
+					type = pcb_search_screen(gx, gy, PCB_CHANGETHERMAL_TYPES | PCB_OBJ_CLASS_TERM, &ptr1, &ptr2, &ptr3);
+#endif
+				if (type != PCB_OBJ_VOID) {
 					pcb_chg_obj_thermal(type, ptr1, ptr2, ptr3, kind, PCB_CURRLID(PCB_ACT_BOARD));
 					pcb_undo_inc_serial();
 					pcb_draw();
@@ -701,7 +707,7 @@ static fgw_error_t pcb_act_SetThermal(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				break;
 			case F_Selected:
 			case F_SelectedElements:
-				pcb_chg_selected_thermals(PCB_CHANGETHERMAL_TYPES, kind, PCB_CURRLID(PCB_ACT_BOARD));
+				pcb_chg_selected_thermals(PCB_CHANGETHERMAL_TYPES | PCB_OBJ_PSTK, kind, PCB_CURRLID(PCB_ACT_BOARD));
 				break;
 			default:
 				err = 1;
