@@ -32,8 +32,8 @@
 typedef struct comp_ctx_s {
 	pcb_draw_info_t *info;
 	const pcb_layergrp_t *grp;
-	pcb_layergrp_id_t gid;
-	const pcb_color_t *color;
+	rnd_layergrp_id_t gid;
+	const rnd_color_t *color;
 
 	unsigned thin:1;
 	unsigned invert:1;
@@ -41,28 +41,28 @@ typedef struct comp_ctx_s {
 
 static void comp_fill_board(comp_ctx_t *ctx)
 {
-	pcb_render->set_color(pcb_draw_out.fgGC, ctx->color);
+	rnd_render->set_color(pcb_draw_out.fgGC, ctx->color);
 	if (ctx->info->drawn_area == NULL)
-		pcb_render->fill_rect(pcb_draw_out.fgGC, 0, 0, ctx->info->pcb->hidlib.size_x, ctx->info->pcb->hidlib.size_y);
+		rnd_render->fill_rect(pcb_draw_out.fgGC, 0, 0, ctx->info->pcb->hidlib.size_x, ctx->info->pcb->hidlib.size_y);
 	else
-		pcb_render->fill_rect(pcb_draw_out.fgGC, ctx->info->drawn_area->X1, ctx->info->drawn_area->Y1, ctx->info->drawn_area->X2, ctx->info->drawn_area->Y2);
+		rnd_render->fill_rect(pcb_draw_out.fgGC, ctx->info->drawn_area->X1, ctx->info->drawn_area->Y1, ctx->info->drawn_area->X2, ctx->info->drawn_area->Y2);
 }
 
 static void comp_start_sub_(comp_ctx_t *ctx)
 {
-	pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_NEGATIVE, pcb_draw_out.direct, ctx->info->drawn_area);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_NEGATIVE, pcb_draw_out.direct, ctx->info->drawn_area);
 }
 
 static void comp_start_add_(comp_ctx_t *ctx)
 {
-	pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
 }
 
 static void comp_start_sub(comp_ctx_t *ctx)
 {
 	if (ctx->thin) {
-		pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
-		pcb_render->set_color(pcb_draw_out.pmGC, ctx->color);
+		rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
+		rnd_render->set_color(pcb_draw_out.pmGC, ctx->color);
 		return;
 	}
 
@@ -75,7 +75,7 @@ static void comp_start_sub(comp_ctx_t *ctx)
 static void comp_start_add(comp_ctx_t *ctx)
 {
 	if (ctx->thin) {
-		pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
+		rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
 		return;
 	}
 
@@ -87,12 +87,12 @@ static void comp_start_add(comp_ctx_t *ctx)
 
 static void comp_finish(comp_ctx_t *ctx)
 {
-	pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_FLUSH, pcb_draw_out.direct, ctx->info->drawn_area);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_FLUSH, pcb_draw_out.direct, ctx->info->drawn_area);
 }
 
 static void comp_init(comp_ctx_t *ctx, int negative)
 {
-	pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_RESET, pcb_draw_out.direct, ctx->info->drawn_area);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_RESET, pcb_draw_out.direct, ctx->info->drawn_area);
 
 	if (ctx->thin)
 		return;
@@ -102,7 +102,7 @@ static void comp_init(comp_ctx_t *ctx, int negative)
 
 	if ((!ctx->thin) && (negative)) {
 		/* drawing the big poly for the negative */
-		pcb_render->set_drawing_mode(pcb_render, PCB_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
+		rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, pcb_draw_out.direct, ctx->info->drawn_area);
 		comp_fill_board(ctx);
 	}
 }
@@ -129,7 +129,7 @@ static void comp_draw_layer_real(comp_ctx_t *ctx, void (*draw_auto)(comp_ctx_t *
 		}
 
 		{
-			pcb_hid_gc_t old_fg = pcb_draw_out.fgGC;
+			rnd_hid_gc_t old_fg = pcb_draw_out.fgGC;
 			pcb_draw_out.fgGC = pcb_draw_out.pmGC;
 			if ((l->comb & PCB_LYC_AUTO) && (draw_auto != NULL))
 				draw_auto(ctx, auto_data);
@@ -153,7 +153,7 @@ int pcb_draw_layergrp_is_comp(const pcb_layergrp_t *g)
 	return 0;
 }
 
-int pcb_draw_layer_is_comp(pcb_layer_id_t id)
+int pcb_draw_layer_is_comp(rnd_layer_id_t id)
 {
 	pcb_layergrp_t *g = pcb_get_layergrp(PCB, PCB->Data->Layer[id].meta.real.grp);
 	if (g == NULL) return 0;
@@ -180,17 +180,21 @@ static void pcb_draw_groups_auto(comp_ctx_t *ctx, void *lym)
 		pcb_draw_pstks(ctx->info, ctx->gid, 0, *pstk_lyt_match);
 }
 
-void pcb_draw_groups(pcb_board_t *pcb, pcb_layer_type_t lyt, int purpi, char *purpose, const pcb_box_t *screen, const pcb_color_t *default_color, pcb_layer_type_t pstk_lyt_match, int thin_draw, int invert)
+void pcb_draw_groups(rnd_hid_t *hid, pcb_board_t *pcb, pcb_layer_type_t lyt, int purpi, char *purpose, const rnd_box_t *screen, const rnd_color_t *default_color, pcb_layer_type_t pstk_lyt_match, int thin_draw, int invert)
 {
 	pcb_draw_info_t info;
-	pcb_layergrp_id_t gid;
+	rnd_layergrp_id_t gid;
 	pcb_layergrp_t *g;
 	comp_ctx_t cctx;
+	rnd_xform_t tmp;
 
 	memset(&info, 0, sizeof(info));
 	info.pcb = pcb;
 	info.drawn_area = screen;
 
+	pcb_draw_setup_default_xform_info(hid, &info);
+	xform_setup(&info, &tmp, NULL);
+
 	for(gid = 0, g = pcb->LayerGroups.grp; gid < pcb->LayerGroups.len; gid++,g++) {
 		pcb_layer_t *ly = NULL;
 
