@@ -5,7 +5,7 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996, 2005 Thomas Nau
- *  pcb-rnd Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  pcb-rnd Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -722,8 +722,8 @@ static rnd_bool pcb_isc_line_poly_blt(const pcb_find_t *ctx, pcb_line_t *Line, p
 		return pcb_poly_is_rect_in_p(x1, y1, x2, y2, Polygon);
 	}
 	if (box_isc_poly_any_island_bbox(ctx, Box, Polygon, !PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, Polygon))) {
-		if (!(lp = pcb_poly_from_pcb_line(Line, Line->Thickness + bloat)))
-			return rnd_false;							/* error */
+		if (!(lp = pcb_poly_from_pcb_line(Line, Line->Thickness + bloat*2)))
+			return rnd_false; /* error generating the line */
 		return box_isc_poly_any_island_free(lp, Polygon, !PCB_FLAG_TEST(PCB_FLAG_FULLPOLY, Polygon));
 	}
 	return rnd_false;
@@ -838,11 +838,11 @@ rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2
 
 	/* cheat: poly-clear-poly means we did generate the clearance; this
 	   shall happen only if there's exactly one poly that is clearing the other */
-	if ((Bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P1)) {
+	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P1) && !PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P2)) {
 		pcp_cnt++;
 		pcp_gap = pcb_obj_clearance_p2(P1, P2) / 2.0;
 	}
-	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P2)) {
+	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P2) && !PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P1)) {
 		pcp_cnt++;
 		pcp_gap = pcb_obj_clearance_p2(P2, P1) / 2.0;
 	}
@@ -867,7 +867,7 @@ rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2
 	}
 
 	/* now the difficult case of bloated for each island vs. island */
-	if (Bloat > 0) {
+	if (Bloat != 0) {
 		for(pa1 = pcb_poly_island_first(P1, &it1); pa1 != NULL; pa1 = pcb_poly_island_next(&it1)) {
 			rnd_pline_t *c1 = pcb_poly_contour(&it1);
 			for(pa2 = pcb_poly_island_first(P2, &it2); pa2 != NULL; pa2 = pcb_poly_island_next(&it2)) {
@@ -884,6 +884,20 @@ rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2
 		}
 	}
 
+	/* corner case: one poly is fully within the other; by now partial overlaps
+	   are found by edge intersections, so only full embedding remains which means
+	   it's enough to check one random point and ignore bloat */
+		for(pa1 = pcb_poly_island_first(P1, &it1); pa1 != NULL; pa1 = pcb_poly_island_next(&it1)) {
+			rnd_pline_t *c1 = pcb_poly_contour(&it1);
+			if (pcb_poly_is_point_in_p(c1->head->point[0], c1->head->point[1], 0, P2))
+				return rnd_true;
+		}
+		for(pa2 = pcb_poly_island_first(P2, &it2); pa2 != NULL; pa2 = pcb_poly_island_next(&it2)) {
+			rnd_pline_t *c2 = pcb_poly_contour(&it2);
+			if (pcb_poly_is_point_in_p(c2->head->point[0], c2->head->point[1], 0, P1))
+				return rnd_true;
+		}
+
 	return rnd_false;
 }
 
@@ -925,9 +939,9 @@ RND_INLINE rnd_bool_t pcb_isc_line_polyline(const pcb_find_t *ctx, rnd_pline_t *
 		rnd_vector_t q[4];
 
 		q[0][0] = x1 + ox; q[0][1] = y1 + oy;
-		q[1][0] = x2 + ox; q[1][1] = y2 + oy;
-		q[2][0] = x1 - ox; q[2][1] = y1 - oy;
-		q[3][0] = x2 - ox; q[3][1] = y2 - oy;
+		q[1][0] = x1 - ox; q[1][1] = y1 - oy;
+		q[2][0] = x2 - ox; q[2][1] = y2 - oy;
+		q[3][0] = x2 + ox; q[3][1] = y2 + oy;
 
 		return rnd_is_point_in_convex_quad(pl->head->point, q);
 	}
