@@ -39,9 +39,9 @@
 #include <string.h>
 
 #include "flag_str.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
+#include <librnd/core/misc_util.h>
 #include "obj_common.h"
-#include "macro.h"
 
 /* Because the common flag access macros expect an object struct to work on. */
 typedef struct {
@@ -49,13 +49,12 @@ typedef struct {
 } FlagHolder;
 
 /* Be careful to list more specific flags first, followed by general
- * flags, when two flags use the same bit.  For example, "onsolder" is
- * for elements only, while "auto" is for everything else.  They use
- * the same bit, but onsolder is listed first so that elements will
- * use it and not auto.
- *
- * Thermals are handled separately, as they're layer-selective.
- */
+   flags, when two flags use the same bit.  For example, "onsolder" is
+   for elements only, while "auto" is for everything else.  They use
+   the same bit, but onsolder is listed first so that elements will
+   use it and not auto.
+
+   Thermals are handled separately, as they're layer-selective. */
 
 #define N(x) x, sizeof(x)-1
 #define FN(x) x, #x
@@ -77,7 +76,7 @@ pcb_flag_bits_t pcb_object_flagbits[] = {
 	{FN(PCB_FLAG_RUBBEREND),     N("rubberend"),     PCB_OBJ_LINE | PCB_OBJ_ARC, "For lines, used internally for rubber band moves: indicates one end already rubber banding.", 0, 0},
 	{FN(PCB_FLAG_WARN),          N("warn"),          PCB_OBJ_CLASS_PIN, "For pins, vias, and pads, set to indicate a warning.", 0, 0},
 	{FN(PCB_FLAG_USETHERMAL),    N("usetherm"),      PCB_OBJ_CLASS_PIN | PCB_OBJ_LINE | PCB_OBJ_ARC, "Obsolete, indicates that pins/vias should be drawn with thermal fingers.", 0, 1},
-	{FN(PCB_FLAG_OCTAGON),       N("octagon"),       0, "Draw pins and vias as octagons.", 0, 0},
+	{FN(PCB_FLAG_OCTAGON),       N("octagon"),       0, "Draw pins and vias as octagons.", PCB_OBJ_PSTK, 0},
 	{FN(PCB_FLAG_DRC),           N("drc"),           PCB_OBJ_ANY, "Set for objects that fail DRC: flag like FOUND flag for DRC checking.", 0},
 	{FN(PCB_FLAG_EXPORTSEL),     N("exportsel"),     PCB_OBJ_ANY, "Set for objects that should be exported in a partial export.", 1},
 	{FN(PCB_FLAG_LOCK),          N("lock"),          PCB_OBJ_ANY, "Set for locked objects.", 0, 0},
@@ -93,17 +92,15 @@ pcb_flag_bits_t pcb_object_flagbits[] = {
 #undef N
 #undef FN
 
-const int pcb_object_flagbits_len = PCB_ENTRIES(pcb_object_flagbits);
+const int pcb_object_flagbits_len = RND_ENTRIES(pcb_object_flagbits);
 
 /* List of old/obsolete flags to silently ignore on load */
 static const char *old_flag_ignore[] = { "connected", NULL };
 
-/*
- * This helper function maintains a small list of buffers which are
- * used by pcb_strflg_f2s().  Each buffer is allocated from the heap,
- * but the caller must not free them (they get realloced when they're
- * reused, but never completely freed).
- */
+/* This helper function maintains a small list of buffers which are
+   used by pcb_strflg_f2s().  Each buffer is allocated from the heap,
+   but the caller must not free them (they get realloced when they're
+   reused, but never completely freed). */
 
 static struct {
 	char *ptr;
@@ -137,12 +134,10 @@ void pcb_strflg_uninit_buf(void)
 	}
 }
 
-/*
- * This set of routines manages a list of layer-specific flags.
- * Callers should call grow_layer_list(0) to reset the list, and
- * set_layer_list(layer,1) to set bits in the layer list.  The results
- * are stored in layers[], which has num_layers valid entries.
- */
+/* This set of routines manages a list of layer-specific flags.
+   Callers should call grow_layer_list(0) to reset the list, and
+   set_layer_list(layer,1) to set bits in the layer list. The results
+   are stored in layers[], which has num_layers valid entries. */
 
 static char *layers = 0;
 static int max_layers = 0, num_layers = 0;
@@ -179,21 +174,18 @@ static inline void set_layer_list(int layer, int v)
 	layers[layer] = v;
 }
 
-/*
- * These next two convert between layer lists and strings.
- * parse_layer_list() is passed a pointer to a string, and parses a
- * list of integer which reflect layers to be flagged.  It returns a
- * pointer to the first character following the list.  The syntax of
- * the list is a paren-surrounded, comma-separated list of integers
- * and/or pairs of integers separated by a dash (like "(1,2,3-7)").
- * Spaces and other punctuation are not allowed.  The results are
- * stored in layers[] defined above.
- *
- * print_layer_list() does the opposite - it uses the flags set in
- * layers[] to build a string that represents them, using the syntax
- * above.
- *
- */
+/* These next two convert between layer lists and strings.
+   parse_layer_list() is passed a pointer to a string, and parses a
+   list of integer which reflect layers to be flagged.  It returns a
+   pointer to the first character following the list.  The syntax of
+   the list is a paren-surrounded, comma-separated list of integers
+   and/or pairs of integers separated by a dash (like "(1,2,3-7)").
+   Spaces and other punctuation are not allowed.  The results are
+   stored in layers[] defined above.
+
+   print_layer_list() does the opposite - it uses the flags set in
+   layers[] to build a string that represents them, using the syntax
+   above. */
 
 /* Returns a pointer to the first character past the list. */
 static const char *parse_layer_list(const char *bp, int (*error) (const char *))
@@ -325,7 +317,7 @@ static int error_ignore(const char *msg)
 
 static pcb_flag_t empty_flags;
 
-pcb_flag_t pcb_strflg_common_s2f(const char *flagstring, int (*error) (const char *msg), pcb_flag_bits_t * flagbits, int n_flagbits, unsigned char *intconn, int compat)
+pcb_flag_t pcb_strflg_common_s2f(const char *flagstring, int (*error) (const char *msg), pcb_flag_bits_t *flagbits, int n_flagbits, unsigned char *intconn, int compat)
 {
 	const char *fp, *ep;
 	int flen;
@@ -407,7 +399,7 @@ pcb_flag_t pcb_strflg_common_s2f(const char *flagstring, int (*error) (const cha
 				error(msg);
 
 				u = malloc(sizeof(pcb_unknown_flag_t));
-				u->str = pcb_strndup(fp, flen);
+				u->str = rnd_strndup(fp, flen);
 				u->next = NULL;
 				/* need to append, to keep order of flags */
 				if (rv.Flags.unknowns != NULL) {
@@ -426,10 +418,10 @@ pcb_flag_t pcb_strflg_common_s2f(const char *flagstring, int (*error) (const cha
 
 pcb_flag_t pcb_strflg_s2f(const char *flagstring, int (*error) (const char *msg), unsigned char *intconn, int compat)
 {
-	return pcb_strflg_common_s2f(flagstring, error, pcb_object_flagbits, PCB_ENTRIES(pcb_object_flagbits), intconn, compat);
+	return pcb_strflg_common_s2f(flagstring, error, pcb_object_flagbits, RND_ENTRIES(pcb_object_flagbits), intconn, compat);
 }
 
-char *pcb_strflg_common_f2s(pcb_flag_t flags, int object_type, pcb_flag_bits_t * flagbits, int n_flagbits, unsigned char *intconn, int compat)
+char *pcb_strflg_common_f2s(pcb_flag_t flags, int object_type, pcb_flag_bits_t *flagbits, int n_flagbits, unsigned char *intconn, int compat)
 {
 	int len;
 	int i;
@@ -449,7 +441,7 @@ char *pcb_strflg_common_f2s(pcb_flag_t flags, int object_type, pcb_flag_bits_t *
 
 	savef = fh;
 
-	len = 3;											/* for "()\0" */
+	len = 3; /* for "()\0" */
 
 	for (i = 0; i < n_flagbits; i++) {
 		long my_obj_typs = flagbits[i].object_types | (compat ? flagbits[i].compat_types : 0);
@@ -540,12 +532,12 @@ char *pcb_strflg_common_f2s(pcb_flag_t flags, int object_type, pcb_flag_bits_t *
 
 char *pcb_strflg_f2s(pcb_flag_t flags, int object_type, unsigned char *intconn, int compat)
 {
-	return pcb_strflg_common_f2s(flags, object_type, pcb_object_flagbits, PCB_ENTRIES(pcb_object_flagbits), intconn, compat);
+	return pcb_strflg_common_f2s(flags, object_type, pcb_object_flagbits, RND_ENTRIES(pcb_object_flagbits), intconn, compat);
 }
 
 const pcb_flag_bits_t *pcb_strflg_1bit(unsigned long bit, int object_type)
 {
-	int i, n_flagbits = PCB_ENTRIES(pcb_object_flagbits);;
+	int i, n_flagbits = RND_ENTRIES(pcb_object_flagbits);;
 	for (i = 0; i < n_flagbits; i++) {
 		unsigned long my_obj_typs = pcb_object_flagbits[i].object_types;
 		if ((my_obj_typs & object_type) && (!pcb_object_flagbits[i].omit_list) && (pcb_object_flagbits[i].mask & bit))
@@ -556,7 +548,7 @@ const pcb_flag_bits_t *pcb_strflg_1bit(unsigned long bit, int object_type)
 
 const pcb_flag_bits_t *pcb_strflg_name(const char *name, int object_type)
 {
-	int i, n_flagbits = PCB_ENTRIES(pcb_object_flagbits);;
+	int i, n_flagbits = RND_ENTRIES(pcb_object_flagbits);;
 	for (i = 0; i < n_flagbits; i++) {
 		unsigned long my_obj_typs = pcb_object_flagbits[i].object_types;
 		if ((my_obj_typs & object_type) && (!pcb_object_flagbits[i].omit_list) && (strcmp(pcb_object_flagbits[i].name, name) == 0))
@@ -567,7 +559,7 @@ const pcb_flag_bits_t *pcb_strflg_name(const char *name, int object_type)
 
 void pcb_strflg_map(unsigned long fbits, int object_type, void *ctx, void (*cb)(void *ctx, unsigned long flg, const pcb_flag_bits_t *fb))
 {
-	int n, i, n_flagbits = PCB_ENTRIES(pcb_object_flagbits);
+	int n, i, n_flagbits = RND_ENTRIES(pcb_object_flagbits);
 	for(n = 0; n < 32; n++) {
 		unsigned long bit = 1 << n;
 		if (!(fbits & bit))
@@ -615,10 +607,10 @@ static pcb_flag_bits_t pcb_flagbits[] = {
 
 char *pcb_strflg_board_f2s(pcb_flag_t flags)
 {
-	return pcb_strflg_common_f2s(flags, PCB_OBJ_ANY, pcb_flagbits, PCB_ENTRIES(pcb_flagbits), NULL, 0);
+	return pcb_strflg_common_f2s(flags, PCB_OBJ_ANY, pcb_flagbits, RND_ENTRIES(pcb_flagbits), NULL, 0);
 }
 
-pcb_flag_t pcb_strflg_board_s2f(const char *flagstring, int (*error) (const char *msg))
+pcb_flag_t pcb_strflg_board_s2f(const char *flagstring, int (*error)(const char *msg))
 {
-	return pcb_strflg_common_s2f(flagstring, error, pcb_flagbits, PCB_ENTRIES(pcb_flagbits), NULL, 0);
+	return pcb_strflg_common_s2f(flagstring, error, pcb_flagbits, RND_ENTRIES(pcb_flagbits), NULL, 0);
 }
