@@ -42,8 +42,8 @@ fgw_error_t pcb_act_load_font_from(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *fname = NULL, *sid = NULL;
 	static char *default_file = NULL;
-	pcb_font_id_t fid, dst_fid = -1;
-	pcb_font_t *fnt;
+	rnd_font_id_t fid, dst_fid = -1;
+	rnd_font_t *fnt;
 	int r;
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
@@ -119,8 +119,8 @@ fgw_error_t pcb_act_save_font_to(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *fname = NULL, *sid = NULL;
 	static char *default_file = NULL;
-	pcb_font_id_t fid;
-	pcb_font_t *fnt;
+	rnd_font_id_t fid;
+	rnd_font_t *fnt;
 	int r;
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
