@@ -4,8 +4,8 @@
 /* Hash: subcircuit -> pointer */
 
 /* hash instance */
-typedef const pcb_subc_t *htscp_key_t;
-typedef int htscp_value_t;
+typedef pcb_subc_t *htscp_key_t;
+typedef void * htscp_value_t;
 #define HT(x) htscp_ ## x
 #include <genht/ht.h>
 #undef HT
