@@ -184,6 +184,54 @@ void pcb_arc_get_end(pcb_arc_t *arc, int which, rnd_coord_t *x, rnd_coord_t *y)
 	rnd_arc_get_endpt(arc->X, arc->Y, arc->Width, arc->Height, arc->StartAngle, arc->Delta, which, x, y);
 }
 
+int pcb_angle_in_arc_(double arc_sa, double arc_da, double ang, int inclusive)
+{
+	double arc_ea;
+
+	/* make sure angle is always positive */
+	if (ang < 0)
+		ang += 360.0;
+
+	if (arc_da < 0) { /* swap endpoints so da is always positive */
+		arc_sa = arc_sa + arc_da;
+		arc_da = -arc_da;
+	}
+	if (arc_sa < 0)
+		arc_sa += 360.0;
+
+	arc_ea = arc_sa + arc_da;
+
+	/* if arc spans from some high value through zero, the end angle has
+	   to be larger than 360; if ang is under both start and end, that may
+	   be the case so add a full circle to ang, last chance to get it in
+	   range */
+	if ((arc_sa > ang) && (arc_ea > ang))
+		ang += 360.0;
+
+	if (inclusive) {
+		if ((ang >= arc_sa) && (ang <= arc_ea))
+			return 1;
+	}
+	else {
+		if ((ang > arc_sa) && (ang < arc_ea))
+			return 1;
+	}
+
+	if (arc_ea > 360.0) {
+		ang += 360.0;
+		if (inclusive) {
+			if ((ang >= arc_sa) && (ang <= arc_ea))
+				return 1;
+		}
+		else {
+			if ((ang > arc_sa) && (ang < arc_ea))
+				return 1;
+		}
+	}
+
+	return 0;
+}
+
 
 void pcb_arc_set_angles(pcb_layer_t *Layer, pcb_arc_t *a, rnd_angle_t new_sa, rnd_angle_t new_da)
 {
@@ -912,11 +960,28 @@ void *pcb_arcop_rotate(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *Arc)
 	return Arc;
 }
 
+rnd_angle_t pcb_arc_get_angle(pcb_arc_t *arc, rnd_coord_t x, rnd_coord_t y)
+{
+	return atan2(-(y - arc->Y), (x - arc->X)) * 180.0 / M_PI + 180.0;
+}
+
+int pcb_arc_get_xy(pcb_arc_t *arc, rnd_angle_t ang, rnd_coord_t *x, rnd_coord_t *y)
+{
+	if (!pcb_angle_in_arc(arc, ang, 1))
+		return -1;
+
+	*x = rnd_round((double)arc->X - (double)arc->Width * cos(ang * RND_M180));
+	*y = rnd_round((double)arc->Y + (double)arc->Height * sin(ang * RND_M180));
+
+	return 0;
+}
+
+
 void *pcb_arc_insert_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_arc_t *arc)
 {
 	rnd_angle_t end_ang = arc->StartAngle + arc->Delta;
 	rnd_coord_t x = pcb_crosshair.X, y = pcb_crosshair.Y;
-	rnd_angle_t angle = atan2(-(y - arc->Y), (x - arc->X)) * 180.0 / M_PI + 180.0;
+	rnd_angle_t angle = pcb_arc_get_angle(arc, x, y);
 	pcb_arc_t *new_arc;
 
 	if (end_ang > 360.0)
