@@ -278,6 +278,9 @@ RND_INLINE pcb_line_merge_t can_merge_lines(const pcb_line_t *old_line, const pc
 
 	/* common overlapping segment */
 	if (ov_o1n && ov_n2o) {
+		if (rnd_distance2(old_line->Point1.X, old_line->Point1.Y, new_line->Point2.X, new_line->Point2.Y) <= 4*4)
+			return PCB_LINMER_NONE; /* don't merge if points are within rounding error range: they are the same point in a \_ configuration but with a few nm error that looks like an overlap */
+
 		out->Point1.X = old_line->Point2.X;
 		out->Point1.Y = old_line->Point2.Y;
 		out->Point2.X = new_line->Point1.X;
@@ -286,6 +289,9 @@ RND_INLINE pcb_line_merge_t can_merge_lines(const pcb_line_t *old_line, const pc
 	}
 
 	if (ov_o1n && ov_n1o) {
+		if (rnd_distance2(old_line->Point1.X, old_line->Point1.Y, new_line->Point1.X, new_line->Point1.Y) <= 4*4)
+			return PCB_LINMER_NONE; /* don't merge if points are within rounding error range: they are the same point in a \_ configuration but with a few nm error that looks like an overlap */
+
 		out->Point1.X = old_line->Point2.X;
 		out->Point1.Y = old_line->Point2.Y;
 		out->Point2.X = new_line->Point2.X;
@@ -294,6 +300,9 @@ RND_INLINE pcb_line_merge_t can_merge_lines(const pcb_line_t *old_line, const pc
 	}
 
 	if (ov_o2n && ov_n2o) {
+		if (rnd_distance2(old_line->Point2.X, old_line->Point2.Y, new_line->Point2.X, new_line->Point2.Y) <= 4*4)
+			return PCB_LINMER_NONE; /* don't merge if points are within rounding error range: they are the same point in a \_ configuration but with a few nm error that looks like an overlap */
+
 		out->Point1.X = old_line->Point1.X;
 		out->Point1.Y = old_line->Point1.Y;
 		out->Point2.X = new_line->Point1.X;
@@ -302,6 +311,9 @@ RND_INLINE pcb_line_merge_t can_merge_lines(const pcb_line_t *old_line, const pc
 	}
 
 	if (ov_o2n && ov_n1o) {
+		if (rnd_distance2(old_line->Point2.X, old_line->Point2.Y, new_line->Point1.X, new_line->Point1.Y) <= 4*4)
+			return PCB_LINMER_NONE; /* don't merge if points are within rounding error range: they are the same point in a \_ configuration but with a few nm error that looks like an overlap */
+
 		out->Point1.X = old_line->Point1.X;
 		out->Point1.Y = old_line->Point1.Y;
 		out->Point2.X = new_line->Point2.X;
@@ -1191,6 +1203,24 @@ void pcb_line_mirror(pcb_line_t *line, rnd_coord_t y_offs, rnd_bool undoable)
 	if (undoable) pcb_undo_inc_serial();
 }
 
+void pcb_line_modify(pcb_line_t *line, rnd_coord_t *x1, rnd_coord_t *y1, rnd_coord_t *x2, rnd_coord_t *y2, rnd_coord_t *thick, rnd_coord_t *clr, rnd_bool undoable)
+{
+	undo_line_geo_t gtmp, *g = &gtmp;
+
+	if (undoable) g = pcb_undo_alloc(pcb_data_get_top(line->parent.layer->parent.data), &undo_line_geo, sizeof(undo_line_geo_t));
+
+	g->line = line;
+	g->Point1.X  = (x1 == NULL) ? line->Point1.X : *x1;
+	g->Point1.Y  = (y1 == NULL) ? line->Point1.Y : *y1;
+	g->Point2.X  = (x2 == NULL) ? line->Point2.X : *x2;
+	g->Point2.Y  = (y2 == NULL) ? line->Point2.Y : *y2;
+	g->Thickness = (thick == NULL) ? line->Thickness : *thick;
+	g->Clearance = (clr == NULL) ? line->Clearance : *clr;
+
+	undo_line_geo_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+}
+
 void pcb_line_scale(pcb_line_t *line, double sx, double sy, double sth)
 {
 	int onbrd = (line->parent.layer != NULL) && (!line->parent.layer->is_bound);
