@@ -39,7 +39,7 @@ rnd_r_dir_t pcb_poly_draw_term_callback(const rnd_box_t * b, void *cl);
 void pcb_poly_invalidate_erase(pcb_poly_t *Polygon);
 void pcb_poly_invalidate_draw(pcb_layer_t *Layer, pcb_poly_t *Polygon);
 void pcb_poly_name_invalidate_draw(pcb_poly_t *poly);
-void pcb_poly_draw_label(pcb_draw_info_t *info, pcb_poly_t *poly);
+void pcb_poly_draw_label(pcb_draw_info_t *info, pcb_poly_t *poly, rnd_bool vis_side);
 void pcb_poly_draw_annotation(pcb_draw_info_t *info, pcb_poly_t *poly);
 
 
