@@ -31,6 +31,8 @@
 
 #include "config.h"
 
+#include "brave.h"
+
 #include "rotate.h"
 #include "board.h"
 #include "data.h"
@@ -55,6 +57,8 @@
 #include "obj_text_draw.h"
 #include "conf_core.h"
 
+#include <rnd_inclib/font/font.h>
+
 TODO("ui_layer parent fix: remove this")
 #include "layer_ui.h"
 
@@ -127,7 +131,7 @@ typedef struct {
 	rnd_coord_t thickness;
 	rnd_coord_t clearance;
 	double rot;
-	pcb_font_id_t fid;
+	rnd_font_id_t fid;
 } undo_text_geo_t;
 
 static int undo_text_geo_swap(void *udata)
@@ -148,7 +152,7 @@ static int undo_text_geo_swap(void *udata)
 	rnd_swap(rnd_coord_t, g->thickness, g->text->thickness);
 	rnd_swap(rnd_coord_t, g->clearance, g->text->clearance);
 	rnd_swap(double, g->rot, g->text->rot);
-	rnd_swap(pcb_font_id_t, g->fid, g->text->fid);
+	rnd_swap(rnd_font_id_t, g->fid, g->text->fid);
 
 	if (pcb != NULL)
 		pcb_text_bbox(pcb_font(pcb, g->text->fid, 1), g->text);
@@ -173,7 +177,7 @@ static const uundo_oper_t undo_text_geo = {
 };
 
 
-pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
+pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
 {
 	pcb_text_t *text;
 
@@ -208,7 +212,7 @@ pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X
 }
 
 /* creates a new text on a layer */
-pcb_text_t *pcb_text_new(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, int Scale, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
+pcb_text_t *pcb_text_new(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, int Scale, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
 {
 	pcb_text_t *text = pcb_text_new_(Layer, PCBFont, X, Y, rot, 0, Scale, 0, 0, thickness, TextString, Flags);
 
@@ -217,7 +221,7 @@ pcb_text_t *pcb_text_new(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X,
 	return text;
 }
 
-pcb_text_t *pcb_text_new_scaled(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
+pcb_text_t *pcb_text_new_scaled(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
 {
 	pcb_text_t *text = pcb_text_new_(Layer, PCBFont, X, Y, rot, mirror, Scale, scx, scy, thickness, TextString, Flags);
 
@@ -226,7 +230,7 @@ pcb_text_t *pcb_text_new_scaled(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coo
 	return text;
 }
 
-pcb_text_t *pcb_text_new_by_bbox(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t bbw, rnd_coord_t bbh, rnd_coord_t anchx, rnd_coord_t anchy, double scxy, pcb_text_mirror_t mirror, double rot, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
+pcb_text_t *pcb_text_new_by_bbox(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t bbw, rnd_coord_t bbh, rnd_coord_t anchx, rnd_coord_t anchy, double scxy, pcb_text_mirror_t mirror, double rot, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags)
 {
 	rnd_coord_t obw, obh, nbw, nbh;
 	double gsc, gscx, gscy, cs, sn, mx = 1, my = 1, nanchx, nanchy;
@@ -313,7 +317,7 @@ pcb_text_t *pcb_text_dup_at(pcb_layer_t *dst, pcb_text_t *src, rnd_coord_t dx, r
 	return t;
 }
 
-void pcb_add_text_on_layer(pcb_layer_t *Layer, pcb_text_t *text, pcb_font_t *PCBFont)
+void pcb_add_text_on_layer(pcb_layer_t *Layer, pcb_text_t *text, rnd_font_t *PCBFont)
 {
 	/* calculate size of the bounding box */
 	pcb_text_bbox(PCBFont, text);
@@ -423,149 +427,65 @@ int pcb_text_old_scale(pcb_text_t *text, int *scale_out)
 	return -1;
 }
 
-/* creates the bounding box of a text object */
-void pcb_text_bbox(pcb_font_t *FontPtr, pcb_text_t *Text)
+int pcb_text_invalid_chars(pcb_board_t *pcb, rnd_font_t *FontPtr, pcb_text_t *Text)
 {
-	pcb_symbol_t *symbol;
-	unsigned char *s, *rendered = pcb_text_render_str(Text);
-	int i;
-	int space;
-	rnd_coord_t minx, miny, maxx, maxy, tx;
-	rnd_coord_t min_final_radius;
-	rnd_coord_t min_unscaled_radius;
-	rnd_bool first_time = rnd_true;
-	pcb_poly_t *poly;
-	double scx, scy;
-	pcb_xform_mx_t mx = PCB_XFORM_MX_IDENT;
-	rnd_coord_t cx[4], cy[4];
-	pcb_text_mirror_t mirror;
-
-	pcb_text_get_scale_xy(Text, &scx, &scy);
-
-	s = rendered;
+	unsigned char *rendered;
+	int ctr;
 
 	if (FontPtr == NULL)
-		FontPtr = pcb_font(PCB, Text->fid, 1);
+		FontPtr = pcb_font(pcb, Text->fid, 1);
 
-	symbol = FontPtr->Symbol;
+	rendered = pcb_text_render_str(Text);
+	if (rendered == NULL)
+		return 0;
 
-	minx = miny = maxx = maxy = tx = 0;
+	ctr = rnd_font_invalid_chars(FontPtr, rendered);
+
+	pcb_text_free_str(Text, rendered);
+
+	return ctr;
+}
+
+
+void pcb_text_bbox(rnd_font_t *FontPtr, pcb_text_t *Text)
+{
+		rnd_coord_t cx[4], cy[4];
+		unsigned char *rendered = pcb_text_render_str(Text);
+		double scx, scy;
+		rnd_coord_t min_line_width;
+		rnd_font_t *font = pcb_font(PCB, Text->fid, 1);
 
 	/* Calculate the bounding box based on the larger of the thicknesses
-	 * the text might clamped at on silk or copper layers.
-	 */
-	min_final_radius = MAX(conf_core.design.min_wid, conf_core.design.min_slk) / 2;
+	 * the text might clamped at on silk or copper layers. */
+		min_line_width = MAX(conf_core.design.min_wid, conf_core.design.min_slk);
 
-	/* Pre-adjust the line radius for the fact we are initially computing the
-	 * bounds of the un-scaled text, and the thickness clamping applies to
-	 * scaled text.
-	 */
-	min_unscaled_radius = PCB_UNPCB_SCALE_TEXT(min_final_radius, Text->Scale);
+		pcb_text_get_scale_xy(Text, &scx, &scy);
+		rnd_font_string_bbox_pcb_rnd(cx, cy, font, rendered, Text->X, Text->Y, scx, scy, Text->rot, text_mirror_bits(Text), Text->thickness, min_line_width, Text->Scale);
+		pcb_text_free_str(Text, rendered);
 
-	/* calculate size of the bounding box */
-	for (; s && *s; s++) {
-		if (*s <= PCB_MAX_FONTPOSITION && symbol[*s].Valid) {
-			pcb_line_t *line = symbol[*s].Line;
-			pcb_arc_t *arc;
-			for (i = 0; i < symbol[*s].LineN; line++, i++) {
-				/* Clamp the width of text lines at the minimum thickness.
-				 * NB: Divide 4 in thickness calculation is comprised of a factor
-				 *     of 1/2 to get a radius from the center-line, and a factor
-				 *     of 1/2 because some stupid reason we render our glyphs
-				 *     at half their defined stroke-width.
-				 */
-				rnd_coord_t unscaled_radius = MAX(min_unscaled_radius, line->Thickness / 4);
+/*		rnd_trace("orig   %mm %mm   %mm %mm\n", Text->bbox_naked.X1, Text->bbox_naked.Y1, Text->bbox_naked.X2, Text->bbox_naked.Y2);*/
 
-				if (first_time) {
-					minx = maxx = line->Point1.X;
-					miny = maxy = line->Point1.Y;
-					first_time = rnd_false;
-				}
+		/* calculate the axis-aligned version */
+		Text->bbox_naked.X1 = Text->bbox_naked.X2 = cx[0];
+		Text->bbox_naked.Y1 = Text->bbox_naked.Y2 = cy[0];
+		rnd_box_bump_point(&Text->bbox_naked, cx[1], cy[1]);
+		rnd_box_bump_point(&Text->bbox_naked, cx[2], cy[2]);
+		rnd_box_bump_point(&Text->bbox_naked, cx[3], cy[3]);
+		rnd_close_box(&Text->bbox_naked);
 
-				minx = MIN(minx, line->Point1.X - unscaled_radius + tx);
-				miny = MIN(miny, line->Point1.Y - unscaled_radius);
-				minx = MIN(minx, line->Point2.X - unscaled_radius + tx);
-				miny = MIN(miny, line->Point2.Y - unscaled_radius);
-				maxx = MAX(maxx, line->Point1.X + unscaled_radius + tx);
-				maxy = MAX(maxy, line->Point1.Y + unscaled_radius);
-				maxx = MAX(maxx, line->Point2.X + unscaled_radius + tx);
-				maxy = MAX(maxy, line->Point2.Y + unscaled_radius);
-			}
+		/* the bounding box covers the extent of influence
+		 * so it must include the clearance values too
+		 */
+		Text->BoundingBox.X1 = Text->bbox_naked.X1 - conf_core.design.bloat;
+		Text->BoundingBox.Y1 = Text->bbox_naked.Y1 - conf_core.design.bloat;
+		Text->BoundingBox.X2 = Text->bbox_naked.X2 + conf_core.design.bloat;
+		Text->BoundingBox.Y2 = Text->bbox_naked.Y2 + conf_core.design.bloat;
+		rnd_close_box(&Text->BoundingBox);
 
-			for(arc = arclist_first(&symbol[*s].arcs); arc != NULL; arc = arclist_next(arc)) {
-				pcb_arc_bbox(arc);
-				maxx = MAX(maxx, arc->bbox_naked.X2);
-				maxy = MAX(maxy, arc->bbox_naked.Y2);
-			}
-
-			for(poly = polylist_first(&symbol[*s].polys); poly != NULL; poly = polylist_next(poly)) {
-				int n;
-				rnd_point_t *pnt;
-				for(n = 0, pnt = poly->Points; n < poly->PointN; n++,pnt++) {
-					maxx = MAX(maxx, pnt->X + tx);
-					maxy = MAX(maxy, pnt->Y);
-				}
-			}
-
-			space = symbol[*s].Delta;
-		}
-		else {
-			rnd_box_t *ds = &FontPtr->DefaultSymbol;
-			rnd_coord_t w = ds->X2 - ds->X1;
-
-			minx = MIN(minx, ds->X1 + tx);
-			miny = MIN(miny, ds->Y1);
-			minx = MIN(minx, ds->X2 + tx);
-			miny = MIN(miny, ds->Y2);
-			maxx = MAX(maxx, ds->X1 + tx);
-			maxy = MAX(maxy, ds->Y1);
-			maxx = MAX(maxx, ds->X2 + tx);
-			maxy = MAX(maxy, ds->Y2);
-
-			space = w / 5;
-		}
-		tx += symbol[*s].Width + space;
-	}
-
-	mirror = text_mirror_bits(Text);
-
-	/* it is enough to do the transformations only once, on the raw bounding box */
-	pcb_xform_mx_translate(mx, Text->X, Text->Y);
-	if (mirror != PCB_TXT_MIRROR_NO)
-		pcb_xform_mx_scale(mx, (mirror & PCB_TXT_MIRROR_X) ? -1 : 1, (mirror & PCB_TXT_MIRROR_Y) ? -1 : 1);
-	pcb_xform_mx_rotate(mx, Text->rot);
-	pcb_xform_mx_scale(mx, scx, scy);
-
-	/* calculate the transformed coordinates of all 4 corners of the raw
-	   (non-axis-aligned) bounding box */
-	cx[0] = rnd_round(pcb_xform_x(mx, minx, miny));
-	cy[0] = rnd_round(pcb_xform_y(mx, minx, miny));
-	cx[1] = rnd_round(pcb_xform_x(mx, maxx, miny));
-	cy[1] = rnd_round(pcb_xform_y(mx, maxx, miny));
-	cx[2] = rnd_round(pcb_xform_x(mx, maxx, maxy));
-	cy[2] = rnd_round(pcb_xform_y(mx, maxx, maxy));
-	cx[3] = rnd_round(pcb_xform_x(mx, minx, maxy));
-	cy[3] = rnd_round(pcb_xform_y(mx, minx, maxy));
-
-	/* calculate the axis-aligned version */
-	Text->bbox_naked.X1 = Text->bbox_naked.X2 = cx[0];
-	Text->bbox_naked.Y1 = Text->bbox_naked.Y2 = cy[0];
-	rnd_box_bump_point(&Text->bbox_naked, cx[1], cy[1]);
-	rnd_box_bump_point(&Text->bbox_naked, cx[2], cy[2]);
-	rnd_box_bump_point(&Text->bbox_naked, cx[3], cy[3]);
-
-	/* the bounding box covers the extent of influence
-	 * so it must include the clearance values too
-	 */
-	Text->BoundingBox.X1 = Text->bbox_naked.X1 - conf_core.design.bloat;
-	Text->BoundingBox.Y1 = Text->bbox_naked.Y1 - conf_core.design.bloat;
-	Text->BoundingBox.X2 = Text->bbox_naked.X2 + conf_core.design.bloat;
-	Text->BoundingBox.Y2 = Text->bbox_naked.Y2 + conf_core.design.bloat;
-	rnd_close_box(&Text->bbox_naked);
-	rnd_close_box(&Text->BoundingBox);
-	pcb_text_free_str(Text, rendered);
+/*		rnd_trace(" new   %mm %mm   %mm %mm\n", Text->bbox_naked.X1, Text->bbox_naked.Y1, Text->bbox_naked.X2, Text->bbox_naked.Y2);*/
 }
 
+
 int pcb_text_eq(const pcb_host_trans_t *tr1, const pcb_text_t *t1, const pcb_host_trans_t *tr2, const pcb_text_t *t2)
 {
 	double rotdir1 = tr1->on_bottom ? -1.0 : 1.0, rotdir2 = tr2->on_bottom ? -1.0 : 1.0;
@@ -1068,7 +988,7 @@ void pcb_text_scale(pcb_text_t *text, double sx, double sy, double sth)
 }
 
 
-void pcb_text_set_font(pcb_text_t *text, pcb_font_id_t fid)
+void pcb_text_set_font(pcb_text_t *text, rnd_font_id_t fid)
 {
 	pcb_layer_t *layer = text->parent.layer;
 
@@ -1234,335 +1154,156 @@ int pcb_text_chg_any(pcb_text_t *text, const pcb_text_t *src, rnd_bool undoable)
 /*** draw ***/
 
 #define MAX_SIMPLE_POLY_POINTS 256
-static void draw_text_poly(pcb_draw_info_t *info, pcb_poly_t *poly, pcb_xform_mx_t mx, rnd_coord_t xo, int xordraw, int thindraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_draw_text_cb cb, void *cb_ctx)
+static void font_draw_atom(void *cb_ctx, const rnd_glyph_atom_t *a)
 {
-	rnd_coord_t x[MAX_SIMPLE_POLY_POINTS], y[MAX_SIMPLE_POLY_POINTS];
-	int max, n;
-	rnd_point_t *p;
-
-	max = poly->PointN;
-	if (max > MAX_SIMPLE_POLY_POINTS) {
-		max = MAX_SIMPLE_POLY_POINTS;
+	pcb_draw_info_t *info = cb_ctx;
+	switch(a->type) {
+		case RND_GLYPH_LINE:
+			{
+				pcb_line_t newline = {0};
+				newline.Point1.X = a->line.x1;
+				newline.Point1.Y = a->line.y1;
+				newline.Point2.X = a->line.x2;
+				newline.Point2.Y = a->line.y2;
+				newline.Thickness = a->line.thickness;
+				pcb_line_draw_(info, &newline, 0);
+			}
+			break;
+		case RND_GLYPH_ARC:
+			{
+				pcb_arc_t newarc = {0};
+				newarc.X = a->arc.cx;
+				newarc.Y = a->arc.cy;
+				newarc.StartAngle = a->arc.start;
+				newarc.Delta = a->arc.delta;
+				newarc.Height = newarc.Width = a->arc.r;
+				newarc.Thickness = a->arc.thickness;
+				pcb_arc_draw_(info, &newarc, 0);
+			}
+			break;
+		case RND_GLYPH_POLY:
+			{
+				int half = a->poly.pts.used/2;
+				rnd_render->fill_polygon(pcb_draw_out.fgGC, half, &a->poly.pts.array[0], &a->poly.pts.array[half]);
+			}
+			break;
 	}
+}
 
-	/* transform each coordinate */
-	for(n = 0, p = poly->Points; n < max; n++,p++) {
-		x[n] = rnd_round(pcb_xform_x(mx, p->X + xo, p->Y));
-		y[n] = rnd_round(pcb_xform_y(mx, p->X + xo, p->Y));
+typedef struct {
+	pcb_draw_text_cb cb;
+	void *cb_ctx;
+} font_draw_atom_user_cb_t;
+
+static void font_draw_atom_user_cb(void *cb_ctx, const rnd_glyph_atom_t *a)
+{
+	font_draw_atom_user_cb_t *ctx = cb_ctx;
+	switch(a->type) {
+		case RND_GLYPH_LINE:
+			{
+				pcb_line_t newline = {0};
+				newline.type = PCB_OBJ_LINE;
+				newline.Point1.X = a->line.x1;
+				newline.Point1.Y = a->line.y1;
+				newline.Point2.X = a->line.x2;
+				newline.Point2.Y = a->line.y2;
+				newline.Thickness = a->line.thickness;
+				ctx->cb(ctx->cb_ctx, (pcb_any_obj_t *)&newline);
+			}
+			break;
+		case RND_GLYPH_ARC:
+			{
+				pcb_arc_t newarc = {0};
+				newarc.type = PCB_OBJ_ARC;
+				newarc.X = a->arc.cx;
+				newarc.Y = a->arc.cy;
+				newarc.StartAngle = a->arc.start;
+				newarc.Delta = a->arc.delta;
+				newarc.Height = newarc.Width = a->arc.r;
+				newarc.Thickness = a->arc.thickness;
+				ctx->cb(ctx->cb_ctx, (pcb_any_obj_t *)&newarc);
+			}
+			break;
+		case RND_GLYPH_POLY:
+			{
+				rnd_point_t *p;
+				pcb_poly_t po = {0};
+				rnd_point_t pt[MAX_SIMPLE_POLY_POINTS];
+				int n, half = a->poly.pts.used/2;
+
+				po.type = PCB_OBJ_POLY;
+				po.PointN = half;
+				po.Points = pt;
+				for(n = 0, p = po.Points; n < half; n++,p++) {
+					p->X = a->poly.pts.array[n];
+					p->Y = a->poly.pts.array[n+half];
+				}
+				ctx->cb(ctx->cb_ctx, (pcb_any_obj_t *)&po);
+			}
+			break;
 	}
+}
 
-	if ((info != NULL) && (info->xform != NULL) && (info->xform->bloat != 0)) {
-		rnd_polo_t *p, pp[MAX_SIMPLE_POLY_POINTS];
-		double a2, dv;
-		for(n = 0, p = pp; n < max; n++,p++) {
-			p->x = x[n];
-			p->y = y[n];
+static void font_draw_atom_xor(void *cb_ctx, const rnd_glyph_atom_t *a)
+{
+	switch(a->type) {
+		case RND_GLYPH_LINE:
+			rnd_render->draw_line(pcb_crosshair.GC, a->line.x1, a->line.y1, a->line.x2, a->line.y2);
+			break;
+		case RND_GLYPH_ARC:
+			rnd_render->draw_arc(pcb_crosshair.GC, a->arc.cx, a->arc.cy, a->arc.r, a->arc.r, a->arc.start, a->arc.delta);
+			break;
+		case RND_GLYPH_POLY:
+			{
+				int half = a->poly.pts.used/2;
+				rnd_render->fill_polygon(pcb_crosshair.GC, half, &a->poly.pts.array[0], &a->poly.pts.array[half]);
+			}
+			break;
+	}
+}
+
+typedef void (*rnd_draw_text_cb)(void *ctx, const rnd_glyph_atom_t *atom);
+
+RND_INLINE void pcb_text_draw_string_rnd(pcb_draw_info_t *info, rnd_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, rnd_coord_t min_line_width, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny, pcb_draw_text_cb cb, void *cb_ctx)
+{
+	font_draw_atom_user_cb_t ucb;
+	int poly_thin = info->xform->thin_draw || info->xform->wireframe;
+	rnd_draw_text_cb rcb;
+
+	if (cb == NULL) {
+		if (xordraw) {
+			rcb = font_draw_atom_xor;
+			x0 += xordx;
+			y0 += xordy;
+			poly_thin = 1;
 		}
-		rnd_polo_norms(pp, max);
-		a2 = rnd_polo_2area(pp, max);
-		if (a2 < 0)
-			dv = -0.5;
 		else
-			dv = 0.5;
-		rnd_polo_offs(info->xform->bloat*dv, pp, max);
-		for(n = 0, p = pp; n < max; n++,p++) {
-			x[n] = rnd_round(p->x);
-			y[n] = rnd_round(p->y);
-		}
+			rcb = font_draw_atom;
+		cb_ctx = info;
+	}
+	else {
+		ucb.cb = cb;
+		ucb.cb_ctx = cb_ctx;
+		rcb = font_draw_atom_user_cb;
+		cb_ctx = &ucb;
 	}
 
-	if (cb != NULL) {
-		pcb_poly_t po;
-		rnd_point_t pt[MAX_SIMPLE_POLY_POINTS];
-
-		memset(&po, 0, sizeof(po));
-		po.type = PCB_OBJ_POLY;
-		po.PointN = max;
-		po.Points = pt;
-		for(n = 0, p = po.Points; n < max; n++,p++) {
-			p->X = x[n];
-			p->Y = y[n];
-		}
-
-		cb(cb_ctx, (pcb_any_obj_t *)&po);
-		return;
-	}
-
-
-	if (xordraw || thindraw) {
-		rnd_hid_gc_t gc = xordraw ? pcb_crosshair.GC : pcb_draw_out.fgGC;
-		for(n = 1, p = poly->Points+1; n < max; n++,p++)
-			rnd_render->draw_line(gc, xordx + x[n-1], xordy + y[n-1], xordx + x[n], xordy + y[n]);
-		rnd_render->draw_line(gc, xordx + x[0], xordy + y[0], xordx + x[max-1], xordy + y[max-1]);
-	}
-	else
-		rnd_render->fill_polygon(pcb_draw_out.fgGC, poly->PointN, x, y);
+	rnd_font_draw_string(font, string, x0, y0, scx, scy, rotdeg, mirror, thickness, min_line_width, poly_thin, tiny, rcb, cb_ctx);
 }
 
-/* Very rough estimation on the full width of the text */
-rnd_coord_t pcb_text_width(pcb_font_t *font, double scx, const unsigned char *string)
+
+RND_INLINE void pcb_text_draw_string_(pcb_draw_info_t *info, rnd_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, rnd_coord_t min_line_width, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny, pcb_draw_text_cb cb, void *cb_ctx)
 {
-	rnd_coord_t w = 0;
-	const rnd_box_t *defaultsymbol;
-	if (string == NULL)
-		return 0;
-	defaultsymbol = &font->DefaultSymbol;
-	while(*string) {
-		/* draw lines if symbol is valid and data is present */
-		if (*string <= PCB_MAX_FONTPOSITION && font->Symbol[*string].Valid)
-			w += (font->Symbol[*string].Width + font->Symbol[*string].Delta);
-		else
-			w += (defaultsymbol->X2 - defaultsymbol->X1) * 6 / 5;
-		string++;
-	}
-	return rnd_round((double)w * scx);
-}
-
-rnd_coord_t pcb_text_height(pcb_font_t *font, double scy, const unsigned char *string)
-{
-	rnd_coord_t h;
-	if (string == NULL)
-		return 0;
-	h = font->MaxHeight;
-	while(*string != '\0') {
-		if (*string == '\n')
-			h += font->MaxHeight;
-		string++;
-	}
-	return rnd_round((double)h * scy);
-}
-
-int pcb_text_invalid_chars(pcb_board_t *pcb, pcb_font_t *FontPtr, pcb_text_t *Text)
-{
-	unsigned char *s, *rendered;
-	int ctr = 0;
-	pcb_symbol_t *symbol;
-
-	if (FontPtr == NULL)
-		FontPtr = pcb_font(pcb, Text->fid, 1);
-
-	symbol = FontPtr->Symbol;
-
-	rendered = pcb_text_render_str(Text);
-	if (rendered == NULL)
-		return 0;
-
-	for(s = rendered; *s != '\0'; s++)
-		if ((*s > PCB_MAX_FONTPOSITION) || (!symbol[*s].Valid))
-			ctr++;
-
-	pcb_text_free_str(Text, rendered);
-
-	return ctr;
+	pcb_text_draw_string_rnd(info, font, string, x0, y0, scx, scy, rotdeg, mirror, thickness, min_line_width, xordraw, xordx, xordy, tiny, cb, cb_ctx);
 }
 
 
-RND_INLINE void cheap_text_line(rnd_hid_gc_t gc, pcb_xform_mx_t mx, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2, rnd_coord_t xordx, rnd_coord_t xordy)
-{
-	rnd_coord_t tx1, ty1, tx2, ty2;
-
-	tx1 = rnd_round(pcb_xform_x(mx, x1, y1));
-	ty1 = rnd_round(pcb_xform_y(mx, x1, y1));
-	tx2 = rnd_round(pcb_xform_x(mx, x2, y2));
-	ty2 = rnd_round(pcb_xform_y(mx, x2, y2));
-
-	tx1 += xordx;
-	ty1 += xordy;
-	tx2 += xordx;
-	ty2 += xordy;
-
-	rnd_render->draw_line(gc, tx1, ty1, tx2, ty2);
-}
-
-
-/* Decreased level-of-detail: draw only a few lines for the whole text */
-RND_INLINE int draw_text_cheap(pcb_font_t *font, pcb_xform_mx_t mx, const unsigned char *string, double scx, double scy, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny)
-{
-	rnd_coord_t w, h = rnd_round((double)font->MaxHeight * scy);
-	if (tiny == PCB_TXT_TINY_HIDE) {
-		if (h <= rnd_render->coord_per_pix*6) /* <= 6 pixel high: unreadable */
-			return 1;
-	}
-	else if (tiny == PCB_TXT_TINY_CHEAP) {
-		if (h <= rnd_render->coord_per_pix*2) { /* <= 1 pixel high: draw a single line in the middle */
-			w = pcb_text_width(font, scx, string);
-			if (xordraw) {
-				cheap_text_line(pcb_crosshair.GC, mx, 0, h/2, w, h/2, xordx, xordy);
-			}
-			else {
-				rnd_hid_set_line_width(pcb_draw_out.fgGC, -1);
-				rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_square);
-				cheap_text_line(pcb_draw_out.fgGC, mx, 0, h/2, w, h/2, 0, 0);
-			}
-			return 1;
-		}
-		else if (h <= rnd_render->coord_per_pix*4) { /* <= 4 pixel high: draw a mirrored Z-shape */
-			w = pcb_text_width(font, scx, string);
-			if (xordraw) {
-				h /= 4;
-				cheap_text_line(pcb_crosshair.GC, mx, 0, h,   w, h,   xordx, xordy);
-				cheap_text_line(pcb_crosshair.GC, mx, 0, h,   w, h*3, xordx, xordy);
-				cheap_text_line(pcb_crosshair.GC, mx, 0, h*3, w, h*3, xordx, xordy);
-			}
-			else {
-				h /= 4;
-				rnd_hid_set_line_width(pcb_draw_out.fgGC, -1);
-				rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_square);
-				cheap_text_line(pcb_draw_out.fgGC, mx, 0, h,   w, h,   0, 0);
-				cheap_text_line(pcb_draw_out.fgGC, mx, 0, h,   w, h*3, 0, 0);
-				cheap_text_line(pcb_draw_out.fgGC, mx, 0, h*3, w, h*3, 0, 0);
-			}
-			return 1;
-		}
-	}
-	return 0;
-}
-
-RND_INLINE void pcb_text_draw_string_(pcb_draw_info_t *info, pcb_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, rnd_coord_t min_line_width, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny, pcb_draw_text_cb cb, void *cb_ctx)
-{
-	rnd_coord_t x = 0;
-	rnd_cardinal_t n;
-	pcb_xform_mx_t mx = PCB_XFORM_MX_IDENT;
-
-	pcb_xform_mx_translate(mx, x0, y0);
-	if (mirror != PCB_TXT_MIRROR_NO)
-		pcb_xform_mx_scale(mx, (mirror & PCB_TXT_MIRROR_X) ? -1 : 1, (mirror & PCB_TXT_MIRROR_Y) ? -1 : 1);
-	pcb_xform_mx_rotate(mx, rotdeg);
-	pcb_xform_mx_scale(mx, scx, scy);
-
-	/* Text too small at this zoom level: cheap draw */
-	if ((tiny != PCB_TXT_TINY_ACCURATE) && (cb == NULL)) {
-		if (draw_text_cheap(font, mx, string, scx, scy, xordraw, xordx, xordy, tiny))
-			return;
-	}
-
-	/* normal draw */
-	while (string && *string) {
-		/* draw lines if symbol is valid and data is present */
-		if (*string <= PCB_MAX_FONTPOSITION && font->Symbol[*string].Valid) {
-			pcb_line_t *line = font->Symbol[*string].Line;
-			pcb_line_t newline;
-			pcb_poly_t *p;
-			pcb_arc_t *a, newarc;
-			int poly_thin;
-
-			for (n = font->Symbol[*string].LineN; n; n--, line++) {
-				/* create one line, scale, move, rotate and swap it */
-				newline = *line;
-				newline.Point1.X = rnd_round(pcb_xform_x(mx, line->Point1.X+x, line->Point1.Y));
-				newline.Point1.Y = rnd_round(pcb_xform_y(mx, line->Point1.X+x, line->Point1.Y));
-				newline.Point2.X = rnd_round(pcb_xform_x(mx, line->Point2.X+x, line->Point2.Y));
-				newline.Point2.Y = rnd_round(pcb_xform_y(mx, line->Point2.X+x, line->Point2.Y));
-				newline.Thickness = rnd_round(newline.Thickness * (scx+scy) / 4.0);
-
-				if (newline.Thickness < min_line_width)
-					newline.Thickness = min_line_width;
-				if (thickness > 0)
-					newline.Thickness = thickness;
-				if (cb != NULL) {
-					newline.type = PCB_OBJ_LINE;
-					cb(cb_ctx, (pcb_any_obj_t *)&newline);
-				}
-				else if (xordraw)
-					rnd_render->draw_line(pcb_crosshair.GC, xordx + newline.Point1.X, xordy + newline.Point1.Y, xordx + newline.Point2.X, xordy + newline.Point2.Y);
-				else
-					pcb_line_draw_(info, &newline, 0);
-			}
-
-			/* draw the arcs */
-			for(a = arclist_first(&font->Symbol[*string].arcs); a != NULL; a = arclist_next(a)) {
-				newarc = *a;
-
-				newarc.X = rnd_round(pcb_xform_x(mx, a->X + x, a->Y));
-				newarc.Y = rnd_round(pcb_xform_y(mx, a->X + x, a->Y));
-				newarc.Height = newarc.Width = rnd_round(newarc.Height * scx);
-				newarc.Thickness = rnd_round(newarc.Thickness * (scx+scy) / 4.0);
-				newarc.StartAngle += rotdeg;
-				if (mirror) {
-					newarc.StartAngle = RND_SWAP_ANGLE(newarc.StartAngle);
-					newarc.Delta = RND_SWAP_DELTA(newarc.Delta);
-				}
-				if (newarc.Thickness < min_line_width)
-					newarc.Thickness = min_line_width;
-				if (thickness > 0)
-					newarc.Thickness = thickness;
-				if (cb != NULL) {
-					newarc.type = PCB_OBJ_ARC;
-					cb(cb_ctx, (pcb_any_obj_t *)&newarc);
-				}
-				else if (xordraw)
-					rnd_render->draw_arc(pcb_crosshair.GC, xordx + newarc.X, xordy + newarc.Y, newarc.Width, newarc.Height, newarc.StartAngle, newarc.Delta);
-				else
-					pcb_arc_draw_(info, &newarc, 0);
-			}
-
-			/* draw the polygons */
-			poly_thin = info->xform->thin_draw || info->xform->wireframe;
-			for(p = polylist_first(&font->Symbol[*string].polys); p != NULL; p = polylist_next(p))
-				draw_text_poly(info, p, mx, x, xordraw, poly_thin, xordx, xordy, cb, cb_ctx);
-
-			/* move on to next cursor position */
-			x += (font->Symbol[*string].Width + font->Symbol[*string].Delta);
-		}
-		else {
-			/* the default symbol is a filled box */
-			rnd_coord_t size = (font->DefaultSymbol.X2 - font->DefaultSymbol.X1) * 6 / 5;
-			rnd_coord_t px[4], py[4];
-
-			px[0] = rnd_round(pcb_xform_x(mx, font->DefaultSymbol.X1 + x, font->DefaultSymbol.Y1));
-			py[0] = rnd_round(pcb_xform_y(mx, font->DefaultSymbol.X1 + x, font->DefaultSymbol.Y1));
-			px[1] = rnd_round(pcb_xform_x(mx, font->DefaultSymbol.X2 + x, font->DefaultSymbol.Y1));
-			py[1] = rnd_round(pcb_xform_y(mx, font->DefaultSymbol.X2 + x, font->DefaultSymbol.Y1));
-			px[2] = rnd_round(pcb_xform_x(mx, font->DefaultSymbol.X2 + x, font->DefaultSymbol.Y2));
-			py[2] = rnd_round(pcb_xform_y(mx, font->DefaultSymbol.X2 + x, font->DefaultSymbol.Y2));
-			px[3] = rnd_round(pcb_xform_x(mx, font->DefaultSymbol.X1 + x, font->DefaultSymbol.Y2));
-			py[3] = rnd_round(pcb_xform_y(mx, font->DefaultSymbol.X1 + x, font->DefaultSymbol.Y2));
-
-			/* draw move on to next cursor position */
-			if ((cb == NULL) && (xordraw || (info->xform->thin_draw || info->xform->wireframe))) {
-				if (xordraw) {
-					rnd_render->draw_line(pcb_crosshair.GC, px[0] + xordx, py[0] + xordy, px[1] + xordx, py[1] + xordy);
-					rnd_render->draw_line(pcb_crosshair.GC, px[1] + xordx, py[1] + xordy, px[2] + xordx, py[2] + xordy);
-					rnd_render->draw_line(pcb_crosshair.GC, px[2] + xordx, py[2] + xordy, px[3] + xordx, py[3] + xordy);
-					rnd_render->draw_line(pcb_crosshair.GC, px[3] + xordx, py[3] + xordy, px[0] + xordx, py[0] + xordy);
-				}
-				else {
-					rnd_render->draw_line(pcb_draw_out.fgGC, px[0], py[0], px[1], py[1]);
-					rnd_render->draw_line(pcb_draw_out.fgGC, px[1], py[1], px[2], py[2]);
-					rnd_render->draw_line(pcb_draw_out.fgGC, px[2], py[2], px[3], py[3]);
-					rnd_render->draw_line(pcb_draw_out.fgGC, px[3], py[3], px[0], py[0]);
-				}
-			}
-			else {
-				if (cb != NULL) {
-					pcb_poly_t po;
-					rnd_point_t pt[4], *p;
-
-					memset(&po, 0, sizeof(po));
-					po.type = PCB_OBJ_POLY;
-					po.PointN = 4;
-					po.Points = pt;
-					for(n = 0, p = po.Points; n < po.PointN; n++,p++) {
-						p->X = px[n];
-						p->Y = py[n];
-					}
-					cb(cb_ctx, (pcb_any_obj_t *)&po);
-				}
-				else
-					rnd_render->fill_polygon(pcb_draw_out.fgGC, 4, px, py);
-			}
-			x += size;
-		}
-		string++;
-	}
-}
-
-void pcb_text_draw_string(pcb_draw_info_t *info, pcb_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, rnd_coord_t min_line_width, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny)
+void pcb_text_draw_string(pcb_draw_info_t *info, rnd_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, rnd_coord_t min_line_width, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy, pcb_text_tiny_t tiny)
 {
 	pcb_text_draw_string_(info, font, string, x0, y0, scx, scy, rotdeg, mirror, thickness, min_line_width, xordraw, xordx, xordy, tiny, NULL, NULL);
 }
 
-void pcb_text_draw_string_simple(pcb_font_t *font, const char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy)
+void pcb_text_draw_string_simple(rnd_font_t *font, const char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy)
 {
 	static rnd_xform_t xform = {0};
 	static pcb_draw_info_t info = {0};
@@ -1575,7 +1316,7 @@ void pcb_text_draw_string_simple(pcb_font_t *font, const char *string, rnd_coord
 }
 
 
-void pcb_text_decompose_string(pcb_draw_info_t *info, pcb_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, pcb_draw_text_cb cb, void *cb_ctx)
+void pcb_text_decompose_string(pcb_draw_info_t *info, rnd_font_t *font, const unsigned char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, pcb_draw_text_cb cb, void *cb_ctx)
 {
 	pcb_text_draw_string_(info, font, string, x0, y0, scx, scy, rotdeg, mirror, thickness, 0, 0, 0, 0, PCB_TXT_TINY_ACCURATE, cb, cb_ctx);
 }
@@ -1758,7 +1499,7 @@ static const char *text_cookie = "obj_text";
 
 /* Recursively update the text objects of data and subcircuits; returns non-zero
    if a redraw is needed */
-static int pcb_text_font_chg_data(pcb_data_t *data, pcb_font_id_t fid)
+static int pcb_text_font_chg_data(pcb_data_t *data, rnd_font_id_t fid)
 {
 	int need_redraw = 0;
 
