@@ -40,7 +40,7 @@ struct pcb_text_s {
 	int Scale;                    /* text scaling in percent */
 	double scale_x, scale_y;      /* optional; x and y direction scale (1 means original size); if 0, use Scale/100 */
 	rnd_coord_t X, Y;             /* origin */
-	pcb_font_id_t fid;
+	rnd_font_id_t fid;
 	char *TextString;             /* string */
 	rnd_coord_t thickness;        /* if non-zero, thickness of line/arc within the font */
 	rnd_coord_t clearance;        /* clearance around the object in polygon if flags have PCB_FLAG_CLEARLINE */
@@ -69,13 +69,13 @@ int pcb_text_old_scale(pcb_text_t *text, int *scale_out);
 pcb_text_t *pcb_text_alloc(pcb_layer_t * layer);
 pcb_text_t *pcb_text_alloc_id(pcb_layer_t *layer, long int id);
 void pcb_text_free(pcb_text_t * data);
-pcb_text_t *pcb_text_new(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, int Scale, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
+pcb_text_t *pcb_text_new(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, int Scale, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
 pcb_text_t *pcb_text_dup(pcb_layer_t *dst, pcb_text_t *src);
 pcb_text_t *pcb_text_dup_at(pcb_layer_t *dst, pcb_text_t *src, rnd_coord_t dx, rnd_coord_t dy);
 void *pcb_text_destroy(pcb_layer_t *Layer, pcb_text_t *Text);
 
 /* creates the text object on the layer without rtree or poly clipping administration */
-pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
+pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, double rot, pcb_text_mirror_t mirror, int Scale, double scx, double scy, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
 
 /* Create new text by bounding box: bbw and bbw are the expected bounding box
    width and height, scxy is the expected text width/height ratio; place the
@@ -83,19 +83,19 @@ pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X
    text will typically be smaller than the input bounding box, with wither
    bbox width or bbox height matching the original, but text aspect ratio kept
    and anchor point placed at X;Y. */
-pcb_text_t *pcb_text_new_by_bbox(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t bbw, rnd_coord_t bbh, rnd_coord_t anchx, rnd_coord_t anchy, double scxy, pcb_text_mirror_t mirror, double rot, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
+pcb_text_t *pcb_text_new_by_bbox(pcb_layer_t *Layer, rnd_font_t *PCBFont, rnd_coord_t X, rnd_coord_t Y, rnd_coord_t bbw, rnd_coord_t bbh, rnd_coord_t anchx, rnd_coord_t anchy, double scxy, pcb_text_mirror_t mirror, double rot, rnd_coord_t thickness, const char *TextString, pcb_flag_t Flags);
 
 
 /* Add objects without creating them or making any "sanity modifications" to them */
-void pcb_add_text_on_layer(pcb_layer_t *Layer, pcb_text_t *text, pcb_font_t *PCBFont);
+void pcb_add_text_on_layer(pcb_layer_t *Layer, pcb_text_t *text, rnd_font_t *PCBFont);
 
-void pcb_text_bbox(pcb_font_t *FontPtr, pcb_text_t *Text);
+void pcb_text_bbox(rnd_font_t *FontPtr, pcb_text_t *Text);
 void pcb_text_rotate90(pcb_text_t *Text, rnd_coord_t X, rnd_coord_t Y, unsigned Number);
 void pcb_text_rotate(pcb_text_t *Text, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina, double rotdeg);
 void pcb_text_scale(pcb_text_t *text, double sx, double sy, double sth);
 void pcb_text_flip_side(pcb_layer_t *layer, pcb_text_t *text, rnd_coord_t y_offs, rnd_bool undoable);
 void pcb_text_mirror_coords(pcb_text_t *text, rnd_coord_t y_offs, rnd_bool undoable); /* mirror the coords but do not mirror the text itself (no on-solder) */
-void pcb_text_set_font(pcb_text_t *text, pcb_font_id_t fid);
+void pcb_text_set_font(pcb_text_t *text, rnd_font_id_t fid);
 void pcb_text_update(pcb_layer_t *layer, pcb_text_t *text);
 
 void pcb_text_reg(pcb_layer_t *layer, pcb_text_t *text);
@@ -112,7 +112,7 @@ void pcb_text_flagchg_pre(pcb_text_t *Text, unsigned long flagbits, void **save)
 void pcb_text_flagchg_post(pcb_text_t *Text, unsigned long oldflagbits, void **save);
 
 /* Low level draw call for direct rendering on preview */
-void pcb_text_draw_string_simple(pcb_font_t *font, const char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy);
+void pcb_text_draw_string_simple(rnd_font_t *font, const char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy);
 
 /* Recalculate the bounding box of all dynamic text objects that are
    directly under data - useful e.g. on parent attr change */
@@ -126,7 +126,7 @@ rnd_bool pcb_text_old_direction(int *dir_out, double rot);
 rnd_coord_t pcb_text_min_thickness(const pcb_layer_t *layer);
 
 /* Return the number of invalid characters (with the given font) the text contains */
-int pcb_text_invalid_chars(pcb_board_t *pcb, pcb_font_t *FontPtr, pcb_text_t *Text);
+int pcb_text_invalid_chars(pcb_board_t *pcb, rnd_font_t *FontPtr, pcb_text_t *Text);
 
 /* hash and eq */
 int pcb_text_eq(const pcb_host_trans_t *tr1, const pcb_text_t *t1, const pcb_host_trans_t *tr2, const pcb_text_t *t2);
