@@ -28,7 +28,7 @@
  */
 
 #include "config.h"
-#include "actions.h"
+#include <librnd/core/actions.h>
 #include "board.h"
 #include "plug_footprint.h"
 
@@ -39,36 +39,36 @@ static fgw_error_t pcb_act_fp_rehash(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	const char *name = NULL;
 	pcb_fplibrary_t *l;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, fp_rehash, name = argv[1].val.str);
-	PCB_ACT_IRES(0);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, fp_rehash, name = argv[1].val.str);
+	RND_ACT_IRES(0);
 
 	if (name == NULL) {
-		pcb_fp_rehash(PCB_ACT_HIDLIB, NULL);
+		pcb_fp_rehash(RND_ACT_HIDLIB, NULL);
 		return 0;
 	}
 
 	l = pcb_fp_lib_search(&pcb_library, name);
 	if (l == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Can't find library path %s\n", name);
-		PCB_ACT_IRES(1);
+		rnd_message(RND_MSG_ERROR, "Can't find library path %s\n", name);
+		RND_ACT_IRES(1);
 		return 0;
 	}
 
-	if (l->type != LIB_DIR) {
-		pcb_message(PCB_MSG_ERROR, "Library path %s is not a directory\n", name);
-		PCB_ACT_IRES(1);
+	if (l->type != PCB_LIB_DIR) {
+		rnd_message(RND_MSG_ERROR, "Library path %s is not a directory\n", name);
+		RND_ACT_IRES(1);
 		return 0;
 	}
 
 	if (l->data.dir.backend == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Library path %s is not a top level directory of a fp_ plugin\n", name);
-		PCB_ACT_IRES(1);
+		rnd_message(RND_MSG_ERROR, "Library path %s is not a top level directory of a fp_ plugin\n", name);
+		RND_ACT_IRES(1);
 		return 0;
 	}
 
-	if (pcb_fp_rehash(PCB_ACT_HIDLIB, l) != 0) {
-		pcb_message(PCB_MSG_ERROR, "Failed to rehash %s\n", name);
-		PCB_ACT_IRES(1);
+	if (pcb_fp_rehash(RND_ACT_HIDLIB, l) != 0) {
+		rnd_message(RND_MSG_ERROR, "Failed to rehash %s\n", name);
+		RND_ACT_IRES(1);
 		return 0;
 	}
 
@@ -76,8 +76,11 @@ static fgw_error_t pcb_act_fp_rehash(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 
-pcb_action_t conf_plug_footprint_list[] = {
+static rnd_action_t plug_footprint_list[] = {
 	{"fp_rehash", pcb_act_fp_rehash, pcb_acth_fp_rehash, pcb_acts_fp_rehash}
 };
 
-PCB_REGISTER_ACTIONS_FUNC(conf_plug_footprint_list, NULL)
+void pcb_plug_footprint_act_init2(void)
+{
+	RND_REGISTER_ACTIONS(plug_footprint_list, NULL);
+}
