@@ -323,7 +323,7 @@ int pcb_parse_footprint(pcb_data_t *Ptr, const char *Filename, const char *fmt)
 	return res;
 }
 
-int pcb_parse_font(pcb_font_t *Ptr, const char *Filename)
+int pcb_parse_font(rnd_font_t *Ptr, const char *Filename)
 {
 	int res = -1;
 	RND_HOOK_CALL(pcb_plug_io_t, pcb_plug_io_chain, parse_font, res, == 0, (self, Ptr, Filename));
@@ -389,6 +389,15 @@ pcb_plug_io_t *pcb_io_find_writer(pcb_plug_iot_t typ, const char *fmt)
 						}
 					}
 				}
+				if (n->alternate_extension != NULL) {
+					int elen = strlen(n->alternate_extension);
+					if ((elen < fn_len) && (strcmp(end-elen, n->alternate_extension) == 0)) {
+						if (n->save_preference_prio > best_score) {
+							best_score = n->save_preference_prio;
+							best = n;
+						}
+					}
+				}
 			}
 			if (best != NULL)
 				return best;
@@ -451,7 +460,7 @@ static int pcb_write_data_subcs(pcb_plug_io_t *p, FILE *f, pcb_data_t *data, lon
 
 static int pcb_write_buffer(FILE *f, pcb_buffer_t *buff, const char *fmt, rnd_bool subc_only, long subc_idx)
 {
-	int res/*, newfmt = 0*/;
+	int res = -1/*, newfmt = 0*/;
 	pcb_plug_io_t *p = pcb_io_find_writer(subc_only ? PCB_IOT_FOOTPRINT : PCB_IOT_BUFFER, fmt);
 
 	if (p != NULL) {
@@ -517,7 +526,7 @@ int pcb_load_padstack(rnd_hidlib_t *hidlib, pcb_pstk_proto_t *proto, const char
 
 int pcb_write_footprint_data(FILE *f, pcb_data_t *e, const char *fmt, long subc_idx)
 {
-	int res, newfmt = 0;
+	int res = -1, newfmt = 0;
 	pcb_plug_io_t *p = e->loader;
 
 	if ((p == NULL) || ((fmt != NULL) && (*fmt != '\0'))) {
@@ -535,7 +544,7 @@ int pcb_write_footprint_data(FILE *f, pcb_data_t *e, const char *fmt, long subc_
 	return res;
 }
 
-int pcb_write_font(pcb_font_t *Ptr, const char *Filename, const char *fmt)
+int pcb_write_font(rnd_font_t *Ptr, const char *Filename, const char *fmt)
 {
 	int res/*, newfmt = 0*/;
 	pcb_plug_io_t *p = pcb_io_find_writer(PCB_IOT_FONT, fmt);
@@ -557,7 +566,7 @@ int pcb_write_font(pcb_font_t *Ptr, const char *Filename, const char *fmt)
 
 static int pcb_write_pcb(FILE *f, const char *old_filename, const char *new_filename, const char *fmt, rnd_bool emergency)
 {
-	int res, newfmt = 0;
+	int res = -1, newfmt = 0;
 	pcb_plug_io_t *p = PCB->Data->loader;
 
 	if ((p == NULL) || ((fmt != NULL) && (*fmt != '\0'))) {
