@@ -832,6 +832,20 @@ static rnd_r_dir_t text_sub_callback(const rnd_box_t * b, void *cl)
 	return RND_R_DIR_FOUND_CONTINUE;
 }
 
+/* To avoid re-clipping the whole poly when an object is removed:
+
+1. make a bounding box of the object + clearance you are removing
+
+2. put back copper covering our object-being-removed's whole clearance,
+without caring any other object's clearance
+
+3. then search all objects that may have clearance intersecting this
+rectangular area and subtract their clearance from the poly
+
+Step 3 is the trick implemented in this function. Where those other
+objects already cleared the poly, it won't make any diff, but where
+we have put back our clearance in step  2, it will remove some copper.
+*/
 static rnd_cardinal_t clearPoly(pcb_data_t *Data, pcb_layer_t *Layer, pcb_poly_t *polygon, const rnd_box_t *here, rnd_coord_t expand, int noop)
 {
 	rnd_cardinal_t r = 0;
@@ -873,6 +887,11 @@ static rnd_cardinal_t clearPoly(pcb_data_t *Data, pcb_layer_t *Layer, pcb_poly_t
 		r = 0;
 		info.accumulate = NULL;
 		info.batch_size = 0;
+
+		rnd_r_search(Data->padstack_tree, &region, NULL, padstack_sub_callback, &info, &seen);
+		subtract_accumulated(&info, polygon);
+		r += seen;
+
 		PCB_COPPER_GROUP_LOOP(Data, group);
 		{
 			rnd_r_search(layer->line_tree, &region, NULL, line_sub_callback, &info, &seen);
@@ -886,8 +905,6 @@ static rnd_cardinal_t clearPoly(pcb_data_t *Data, pcb_layer_t *Layer, pcb_poly_t
 			r += seen;
 		}
 		PCB_END_LOOP;
-		rnd_r_search(Data->padstack_tree, &region, NULL, padstack_sub_callback, &info, &seen);
-		r += seen;
 		subtract_accumulated(&info, polygon);
 	}
 	if (!noop)
