@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2015..2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2015..2022 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include "undo.h"
 #include "conf_core.h"
 #include "netlist.h"
+#include "event.h"
 
 static void rats_patch_remove(pcb_board_t *pcb, pcb_ratspatch_line_t * n, int do_free);
 
@@ -208,17 +209,17 @@ void pcb_ratspatch_append_optimize(pcb_board_t *pcb, pcb_rats_patch_op_t op, con
 	for (n = pcb->NetlistPatchLast; n != NULL; n = n->prev) {
 		if ((n->op == seek_op) && (strcmp(n->id, id) == 0)) {
 			switch (op) {
-			case RATP_CHANGE_ATTRIB:
-				if (strcmp(n->arg1.attrib_name, a1) != 0)
-					break;
-				rats_patch_remove(pcb, n, 1);
-				goto quit;
-			case RATP_ADD_CONN:
-			case RATP_DEL_CONN:
-				if (strcmp(n->arg1.net_name, a1) != 0)
-					break;
-				rats_patch_remove(pcb, n, 1);
-				goto quit;
+				case RATP_CHANGE_ATTRIB:
+					if (strcmp(n->arg1.attrib_name, a1) != 0)
+						break;
+					rats_patch_remove(pcb, n, 1);
+					goto quit;
+				case RATP_ADD_CONN:
+				case RATP_DEL_CONN:
+					if (strcmp(n->arg1.net_name, a1) != 0)
+						break;
+					rats_patch_remove(pcb, n, 1);
+					goto quit;
 			}
 		}
 	}
@@ -228,7 +229,7 @@ quit:;
 }
 
 /* Unlink n from the list; if do_free is non-zero, also free fields and n */
-static void rats_patch_remove(pcb_board_t *pcb, pcb_ratspatch_line_t * n, int do_free)
+static void rats_patch_remove(pcb_board_t *pcb, pcb_ratspatch_line_t *n, int do_free)
 {
 	/* if we are the first or last... */
 	if (n == pcb->NetlistPatches)
@@ -323,10 +324,63 @@ void pcb_ratspatch_make_edited(pcb_board_t *pcb)
 	pcb_netlist_init(&(pcb->netlist[PCB_NETLIST_EDITED]));
 	pcb_netlist_copy(pcb, &(pcb->netlist[PCB_NETLIST_EDITED]), &(pcb->netlist[PCB_NETLIST_INPUT]));
 
-	for (n = pcb->NetlistPatches; n != NULL; n = n->next)
+	for(n = pcb->NetlistPatches; n != NULL; n = n->next)
 		pcb_ratspatch_apply(pcb, n);
 }
 
+/* Returns non-zero if n is already done on pcb; useful after a forward annotation */
+int pcb_rats_patch_already_done(pcb_board_t *pcb, pcb_ratspatch_line_t *n)
+{
+	switch(n->op) {
+		case RATP_ADD_CONN:
+			if (pcb_net_is_term_on_net_by_name(pcb, &pcb->netlist[PCB_NETLIST_INPUT], n->arg1.net_name, n->id) == 1) {
+				rnd_message(RND_MSG_INFO, "rats patch: 'add connection' %s to %s is done on forward annotation, removing.\n", n->id, n->arg1.net_name);
+				return 1;
+			}
+			break;
+		case RATP_DEL_CONN:
+			if (pcb_net_is_term_on_net_by_name(pcb, &pcb->netlist[PCB_NETLIST_INPUT], n->arg1.net_name, n->id) == 0) {
+				rnd_message(RND_MSG_INFO, "rats patch: 'del connection' %s to %s is done on forward annotation, removing.\n", n->id, n->arg1.net_name);
+				return 1;
+			}
+			break;
+		case RATP_CHANGE_ATTRIB:
+			{
+				pcb_subc_t *subc = pcb_subc_by_refdes(pcb->Data, n->id);
+				if (subc != NULL) {
+					char *want = n->arg2.attrib_val;
+					char *av = pcb_attribute_get(&subc->Attributes, n->arg1.attrib_name);
+					if (((av == NULL) || (*av == '\0')) && ((want == NULL) || (*want == '\0'))) {
+						rnd_message(RND_MSG_INFO, "rats patch: attrib %s del from %s is done on forward annotation, removing.\n", n->arg1.attrib_name, n->id);
+						return 1;
+					}
+					if ((av != NULL) && (want != NULL) && (strcmp(av, want) == 0)) {
+						rnd_message(RND_MSG_INFO, "rats patch: attrib %s change for %s is done on forward annotation, removing.\n", n->arg1.attrib_name, n->id);
+						return 1;
+					}
+				}
+			}
+			break;
+	}
+	return 0;
+}
+
+int pcb_rats_patch_cleanup_patches(pcb_board_t *pcb)
+{
+	pcb_ratspatch_line_t *n, *next;
+	int cnt = 0;
+
+	for(n = pcb->NetlistPatches; n != NULL; n = next) {
+		next = n->next;
+		if (pcb_rats_patch_already_done(pcb, n)) {
+			rats_patch_remove(pcb, n, 1);
+			cnt++;
+		}
+	}
+
+	return cnt;
+}
+
 int pcb_rats_patch_export(pcb_board_t *pcb, pcb_ratspatch_line_t *pat, rnd_bool need_info_lines, void (*cb)(void *ctx, pcb_rats_patch_export_ev_t ev, const char *netn, const char *key, const char *val), void *ctx)
 {
 	pcb_ratspatch_line_t *n;
@@ -468,27 +522,27 @@ static int act_replace_footprint_dst(int op, pcb_subc_t **olds)
 	return 0;
 }
 
-static int act_replace_footprint_src(char *fpname, pcb_subc_t **news)
+static int act_replace_footprint_src(char **fpname, pcb_subc_t **news)
 {
 	int len, bidx;
 	const char *what, *what2;
 
-	if (fpname == NULL) {
-		fpname = rnd_hid_prompt_for(&PCB->hidlib, "Footprint name to use for replacement:", "", "Footprint");
-		if (fpname == NULL) {
+	if (*fpname == NULL) {
+		*fpname = rnd_hid_prompt_for(&PCB->hidlib, "Footprint name to use for replacement:", "", "Footprint");
+		if (*fpname == NULL) {
 			rnd_message(RND_MSG_ERROR, "No footprint name supplied\n");
 			return 1;
 		}
 	}
 	else
-		fpname = rnd_strdup(fpname);
+		*fpname = rnd_strdup(*fpname);
 
-	if (strcmp(fpname, "@buffer") != 0) {
+	if (strcmp(*fpname, "@buffer") != 0) {
 		/* check if the footprint is available */
 		bidx = PCB_MAX_BUFFER-1;
-		pcb_buffer_load_footprint(&pcb_buffers[bidx], fpname, NULL);
+		pcb_buffer_load_footprint(&pcb_buffers[bidx], *fpname, NULL);
 		what = "Footprint file ";
-		what2 = fpname;
+		what2 = *fpname;
 	}
 	else {
 		what = "Buffer";
@@ -569,7 +623,7 @@ static fgw_error_t pcb_act_ReplaceFootprint(fgw_arg_t *res, int argc, fgw_arg_t
 
 	/* fetch the name of the new footprint */
 	RND_ACT_MAY_CONVARG(2, FGW_STR, ReplaceFootprint, fpname = rnd_strdup(argv[2].val.str));
-	if (act_replace_footprint_src(fpname, &news) != 0) {
+	if (act_replace_footprint_src(&fpname, &news) != 0) {
 		RND_ACT_IRES(1);
 		return 0;
 	}
@@ -635,9 +689,19 @@ static rnd_action_t rats_patch_action_list[] = {
 	{"SavePatch", pcb_act_SavePatch, pcb_acth_SavePatch, pcb_acts_SavePatch}
 };
 
-void pcb_rats_patch_init2(void)
+static void rats_patch_netlist_chg(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
-	RND_REGISTER_ACTIONS(rats_patch_action_list, NULL);
+	pcb_rats_patch_cleanup_patches((pcb_board_t *)hidlib);
 }
 
 
+void pcb_rats_patch_init2(void)
+{
+	RND_REGISTER_ACTIONS(rats_patch_action_list, NULL);
+	rnd_event_bind(PCB_EVENT_NETLIST_CHANGED, rats_patch_netlist_chg, NULL, core_ratspatch_cookie);
+}
+
+void pcb_rats_patch_uninit(void)
+{
+	rnd_event_unbind_allcookie(core_ratspatch_cookie);
+}
