@@ -481,6 +481,9 @@ int pcb_route_apply_to_line(const pcb_route_t *p_route, pcb_layer_t *apply_to_li
 					if (exto != NULL)
 						pcb_extobj_float_geo(exto);
 
+					/* if the modified line can be merged with an existing line, do it */
+					pcb_line_mod_merge(apply_to_line, 1);
+
 					/* The existing line has been used so forget about it. */
 					apply_to_line = NULL;
 					applied = 1;
@@ -754,7 +757,7 @@ void pcb_route_draw(pcb_route_t *p_route, rnd_hid_gc_t GC)
  *---------------------------------------------------------*/
 void pcb_route_draw_drc(pcb_route_t *p_route, rnd_hid_gc_t GC)
 {
-	rnd_coord_t thickness = p_route->thickness + 2 * conf_core.design.bloat;
+	rnd_coord_t thickness = p_route->thickness + p_route->clearance;
 	int i;
 
 	rnd_render->set_color(GC, &conf_core.appearance.color.drc);
