@@ -71,8 +71,6 @@
 #include "obj_subc_parent.h"
 #include "obj_term.h"
 
-#include "brave.h"
-
 #define Locked pcb_undoing()
 
 /*** undo_old_str ***/
@@ -607,8 +605,7 @@ static rnd_bool UndoRemove(UndoListTypePtr Entry)
 	pcb_data_t *data = PCB->Data;
 	pcb_subc_t *subc = NULL;
 
-	if (!(pcb_brave & PCB_BRAVE_NOCLIPBATCH))
-		pcb_data_clip_inhibit_inc(PCB->Data);
+	pcb_data_clip_inhibit_inc(PCB->Data);
 
 	/* lookup entry by it's ID */
 	type = pcb_search_obj_by_id(pcb_removelist, &ptr1, &ptr2, &ptr3, Entry->ID, Entry->Kind);
@@ -625,15 +622,11 @@ static rnd_bool UndoRemove(UndoListTypePtr Entry)
 			pcb_extobj_float_geo(o);
 		}
 
-		if (!(pcb_brave & PCB_BRAVE_NOCLIPBATCH))
-			pcb_data_clip_inhibit_dec(PCB->Data, 1);
-
+		pcb_data_clip_inhibit_dec(PCB->Data, 1);
 		return rnd_true;
 	}
 
-	if (!(pcb_brave & PCB_BRAVE_NOCLIPBATCH))
-		pcb_data_clip_inhibit_dec(PCB->Data, 1);
-
+	pcb_data_clip_inhibit_dec(PCB->Data, 1);
 	return rnd_false;
 }
 
