@@ -5,6 +5,7 @@
 #include <librnd/core/unit.h>
 #include "attrib.h"
 #include <librnd/core/global_typedefs.h>
+#include <rnd_inclib/font/font.h>
 
 /* Elem=RouteStyle; init=0 */
 
@@ -14,7 +15,7 @@ typedef struct {
 	rnd_coord_t Thick;            /* line thickness */
 	rnd_coord_t textt;            /* text thickness */
 	int texts;                    /* text scale */
-	pcb_font_id_t fid;
+	rnd_font_id_t fid;
 	rnd_coord_t Clearance;        /* min. separation from other nets */
 	rnd_cardinal_t via_proto;     /* via padstack prototype ID */
 	int via_proto_set;            /* 1 if via_proto is set/valid, 0 if no via is configured */
