@@ -32,18 +32,18 @@
 #include "cam_compile.h"
 #include "layer_vis.h"
 #include "event.h"
-#include "safe_fs.h"
+#include <librnd/core/safe_fs.h>
 #include <genvector/genvector_impl.c>
 
 
 /* mkdir -p on arg - changes the string in arg */
-static int prefix_mkdir(char *arg, char **filename)
+static int prefix_mkdir(char *arg, char **filename, rnd_bool nomkdir)
 {
 	char *curr, *next, *end;
 	int res;
 
 		/* mkdir -p if there's a path sep in the prefix */
-		end = strrchr(arg, PCB_DIR_SEPARATOR_C);
+		end = strrchr(arg, RND_DIR_SEPARATOR_C);
 		if (end == NULL) {
 			if (filename != NULL)
 				*filename = arg;
@@ -56,12 +56,13 @@ static int prefix_mkdir(char *arg, char **filename)
 			*filename = end+1;
 
 		for(curr = arg; curr != NULL; curr = next) {
-			next = strrchr(curr, PCB_DIR_SEPARATOR_C);
+			next = strrchr(curr, RND_DIR_SEPARATOR_C);
 			if (next != NULL)
 				*next = '\0';
-			pcb_mkdir(&PCB->hidlib, arg, 0755);
+			if (!nomkdir)
+				rnd_mkdir(&PCB->hidlib, arg, 0755);
 			if (next != NULL) {
-				*next = PCB_DIR_SEPARATOR_C;
+				*next = RND_DIR_SEPARATOR_C;
 				next++;
 			}
 		}
@@ -81,7 +82,7 @@ static int cam_exec_inst(cam_ctx_t *ctx, pcb_cam_code_t *code)
 		case PCB_CAM_PARTIAL:
 			if (code->op.partial.arg != NULL) {
 				ctx->partial = 1;
-				pcb_actionva(&PCB->hidlib, "query", "setflag:exportsel", code->op.partial.arg, NULL);
+				rnd_actionva(&PCB->hidlib, "query", "setflag:exportsel", code->op.partial.arg, NULL);
 			}
 			else {
 				if (ctx->partial) {
@@ -93,7 +94,7 @@ static int cam_exec_inst(cam_ctx_t *ctx, pcb_cam_code_t *code)
 
 		case PCB_CAM_WRITE:
 			if (ctx->exporter == NULL) {
-				pcb_message(PCB_MSG_ERROR, "cam: no exporter selected before write\n");
+				rnd_message(RND_MSG_ERROR, "cam: no exporter selected before write\n");
 				return -1;
 			}
 
@@ -108,7 +109,7 @@ static int cam_exec_inst(cam_ctx_t *ctx, pcb_cam_code_t *code)
 			argc = ctx->argc;
 			argv = ctx->argv;
 			if (ctx->exporter->parse_arguments(ctx->exporter, &argc, &argv) != 0) {
-				pcb_message(PCB_MSG_ERROR, "cam: exporter '%s' refused the arguments\n", code->op.write.arg);
+				rnd_message(RND_MSG_ERROR, "cam: exporter '%s' refused the arguments\n", code->op.write.arg);
 				ctx->argv[0] = NULL;
 				ctx->argv[1] = NULL;
 				return -1;
@@ -145,25 +146,25 @@ static int cam_exec(cam_ctx_t *ctx)
 	int save_l_ons[PCB_MAX_LAYER], save_g_ons[PCB_MAX_LAYERGRP];
 	int ovr = 0, *old_ovr;
 
-	old_ovr = pcb_batched_ask_ovr_init(&PCB->hidlib, &ovr);
+	old_ovr = rnd_batched_ask_ovr_init(&PCB->hidlib, &ovr);
 
 	if (ctx->has_partial)
 		pcb_data_clear_flag(PCB->Data, PCB_FLAG_EXPORTSEL, 0, 0);
 
-	have_gui = (pcb_gui != NULL) && pcb_gui->gui;
+	have_gui = (rnd_gui != NULL) && rnd_gui->gui;
 	if (have_gui) {
 		pcb_hid_save_and_show_layer_ons(save_l_ons);
 		pcb_hid_save_and_show_layergrp_ons(save_g_ons);
 	}
 
-	pcb_event(&PCB->hidlib, PCB_EVENT_EXPORT_SESSION_BEGIN, NULL);
+	rnd_event(&PCB->hidlib, RND_EVENT_EXPORT_SESSION_BEGIN, NULL);
 	for(n = 0; n < ctx->code.used; n++) {
 		if (cam_exec_inst(ctx, &ctx->code.array[n]) != 0) {
 			res = 1;
 			break;
 		}
 	}
-	pcb_event(&PCB->hidlib, PCB_EVENT_EXPORT_SESSION_END, NULL);
+	rnd_event(&PCB->hidlib, RND_EVENT_EXPORT_SESSION_END, NULL);
 
 	if (ctx->partial) {
 		pcb_data_clear_flag(PCB->Data, PCB_FLAG_EXPORTSEL, 0, 0);
@@ -174,10 +175,10 @@ static int cam_exec(cam_ctx_t *ctx)
 		pcb_hid_restore_layer_ons(save_l_ons);
 		pcb_hid_restore_layergrp_ons(save_g_ons);
 		pcb_layervis_change_group_vis(&PCB->hidlib, currly, 1, 1);
-		pcb_event(&PCB->hidlib, PCB_EVENT_LAYERVIS_CHANGED, NULL);
+		rnd_event(&PCB->hidlib, PCB_EVENT_LAYERVIS_CHANGED, NULL);
 	}
 
-	pcb_batched_ask_ovr_uninit(&PCB->hidlib, old_ovr);
+	rnd_batched_ask_ovr_uninit(&PCB->hidlib, old_ovr);
 	return res;
 }
 
@@ -186,11 +187,11 @@ static int cam_compile_line(cam_ctx_t *ctx, char *cmd, char *arg, pcb_cam_code_t
 
 	if (strcmp(cmd, "desc") == 0) {
 		code->inst = PCB_CAM_DESC;
-		code->op.desc.arg = pcb_strdup(arg);
+		code->op.desc.arg = rnd_strdup(arg);
 	}
 	else if (strcmp(cmd, "write") == 0) {
 		code->inst = PCB_CAM_WRITE;
-		code->op.write.arg = pcb_strdup(arg);
+		code->op.write.arg = rnd_strdup(arg);
 	}
 	else if (strcmp(cmd, "partial") == 0) {
 		ctx->has_partial = 1;
@@ -198,7 +199,7 @@ static int cam_compile_line(cam_ctx_t *ctx, char *cmd, char *arg, pcb_cam_code_t
 		if ((arg == NULL) || (*arg == '\0'))
 			code->op.partial.arg = NULL;
 		else
-			code->op.partial.arg = pcb_strdup(arg);
+			code->op.partial.arg = rnd_strdup(arg);
 	}
 	else if (strcmp(cmd, "full") == 0) {
 		code->inst = PCB_CAM_PARTIAL;
@@ -215,14 +216,14 @@ static int cam_compile_line(cam_ctx_t *ctx, char *cmd, char *arg, pcb_cam_code_t
 			*curr = '\0';
 			curr++;
 		}
-		code->op.plugin.exporter = pcb_hid_find_exporter(arg);
+		code->op.plugin.exporter = rnd_hid_find_exporter(arg);
 		if (code->op.plugin.exporter == NULL) {
-			pcb_message(PCB_MSG_ERROR, "cam: can not find export plugin: '%s'\n", arg);
+			rnd_message(RND_MSG_ERROR, "cam: can not find export plugin: '%s'\n", arg);
 			return -1;
 		}
 		free(ctx->args);
 
-		curr = pcb_strdup(curr == NULL ? "" : curr);
+		curr = rnd_strdup(curr == NULL ? "" : curr);
 		for(maxa = 0, s = curr; *s != '\0'; s++)
 			if (isspace(*s))
 				maxa++;
@@ -242,14 +243,14 @@ static int cam_compile_line(cam_ctx_t *ctx, char *cmd, char *arg, pcb_cam_code_t
 			}
 			if (*curr == '\0')
 				continue;
-			code->op.plugin.argv[code->op.plugin.argc] = pcb_strdup(curr);
+			code->op.plugin.argv[code->op.plugin.argc] = rnd_strdup(curr);
 			code->op.plugin.argc++;
 			
 		}
 		code->op.plugin.argv[ctx->argc] = NULL;
 	}
 	else {
-		pcb_message(PCB_MSG_ERROR, "cam: syntax error (unknown instruction): '%s'\n", cmd);
+		rnd_message(RND_MSG_ERROR, "cam: syntax error (unknown instruction): '%s'\n", cmd);
 		return -1;
 	}
 	return 0;
@@ -257,7 +258,7 @@ static int cam_compile_line(cam_ctx_t *ctx, char *cmd, char *arg, pcb_cam_code_t
 
 static int cam_compile(cam_ctx_t *ctx, const char *script_in)
 {
-	char *arg, *curr, *next, *script = pcb_strdup(script_in);
+	char *arg, *curr, *next, *script = rnd_strdup(script_in);
 	int res = 0, r;
 
 	for(curr = script; curr != NULL; curr = next) {
