@@ -33,14 +33,14 @@
 
 #include "obj_line.h"
 #include "obj_arc.h"
-#include "math_helper.h"
-#include "compat_misc.h"
+#include <librnd/core/math_helper.h>
+#include <librnd/core/compat_misc.h>
 #include "search.h"
 
 /* Note about all intersection code: same basic algo as in find_geo.c -
    see comment for the algo description there */
 
-int pcb_intersect_cline_cline(pcb_line_t *Line1, pcb_line_t *Line2, pcb_box_t *ip, double offs[2])
+int pcb_intersect_cline_cline(pcb_line_t *Line1, pcb_line_t *Line2, rnd_box_t *ip, double offs[2])
 {
 	double s, r;
 	double line1_dx, line1_dy, line2_dx, line2_dy, point1_dx, point1_dy;
@@ -75,8 +75,8 @@ int pcb_intersect_cline_cline(pcb_line_t *Line1, pcb_line_t *Line2, pcb_box_t *i
 				s = 1.0;
 
 			if (ip != NULL) {
-				ip->X1 = pcb_round((double)Line1->Point1.X + r * line1_dx);
-				ip->Y1 = pcb_round((double)Line1->Point1.Y + r * line1_dy);
+				ip->X1 = rnd_round((double)Line1->Point1.X + r * line1_dx);
+				ip->Y1 = rnd_round((double)Line1->Point1.Y + r * line1_dy);
 				if (s == 1.0) {
 					ip->X2 = Line1->Point2.X;
 					ip->Y2 = Line1->Point2.Y;
@@ -102,8 +102,8 @@ int pcb_intersect_cline_cline(pcb_line_t *Line1, pcb_line_t *Line2, pcb_box_t *i
 	if (r >= 0.0 && r <= 1.0) {
 		if (s >= 0.0 && s <= 1.0) {
 			if (ip != NULL) {
-				ip->X1 = pcb_round((double)Line1->Point1.X + r * line1_dx);
-				ip->Y1 = pcb_round((double)Line1->Point1.Y + r * line1_dy);
+				ip->X1 = rnd_round((double)Line1->Point1.X + r * line1_dx);
+				ip->Y1 = rnd_round((double)Line1->Point1.Y + r * line1_dy);
 			}
 			if (offs != NULL)
 				offs[0] = r;
@@ -113,22 +113,22 @@ int pcb_intersect_cline_cline(pcb_line_t *Line1, pcb_line_t *Line2, pcb_box_t *i
 	}
 
 	/* intersection is at least on CD */
-	/* [removed this case since it always returns pcb_false --asp] */
+	/* [removed this case since it always returns rnd_false --asp] */
 	return 0;
 }
 
-void pcb_cline_offs(pcb_line_t *line, double offs, pcb_coord_t *dstx, pcb_coord_t *dsty)
+void pcb_cline_offs(pcb_line_t *line, double offs, rnd_coord_t *dstx, rnd_coord_t *dsty)
 {
 	double line_dx, line_dy;
 
 	line_dx = line->Point2.X - line->Point1.X;
 	line_dy = line->Point2.Y - line->Point1.Y;
 
-	*dstx = pcb_round((double)line->Point1.X + offs * line_dx);
-	*dsty = pcb_round((double)line->Point1.Y + offs * line_dy);
+	*dstx = rnd_round((double)line->Point1.X + offs * line_dx);
+	*dsty = rnd_round((double)line->Point1.Y + offs * line_dy);
 }
 
-double pcb_cline_pt_offs(pcb_line_t *line, pcb_coord_t px, pcb_coord_t py)
+double pcb_cline_pt_offs(pcb_line_t *line, rnd_coord_t px, rnd_coord_t py)
 {
 	double line_dx, line_dy, pt_dx, pt_dy;
 
@@ -141,7 +141,7 @@ double pcb_cline_pt_offs(pcb_line_t *line, pcb_coord_t px, pcb_coord_t py)
 	return (line_dx * pt_dx + line_dy * pt_dy) / (line_dx*line_dx + line_dy*line_dy);
 }
 
-static int line_ep(pcb_line_t *line, pcb_coord_t x, pcb_coord_t y)
+static int line_ep(pcb_line_t *line, rnd_coord_t x, rnd_coord_t y)
 {
 	if ((line->Point1.X == x) && (line->Point1.Y == y)) return 1;
 	if ((line->Point2.X == x) && (line->Point2.Y == y)) return 1;
@@ -170,10 +170,10 @@ do { \
 		return found; \
 } while(0)
 
-static int intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, pcb_box_t *ip, double offs[2], int oline)
+static int intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, rnd_box_t *ip, double offs[2], int oline)
 {
 	double dx, dy, dx1, dy1, l, d, r, r2, Radius;
-	pcb_coord_t ex, ey, ix, iy;
+	rnd_coord_t ex, ey, ix, iy;
 	int found = 0;
 
 	dx = Line->Point2.X - Line->Point1.X;
@@ -215,8 +215,8 @@ static int intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, pcb_box_t *ip,
 	r = (Radius + r2) / l;
 
 	if ((r >= 0) && (r <= 1)) {
-		ix = pcb_round(Line->Point1.X + r * dx);
-		iy = pcb_round(Line->Point1.Y + r * dy);
+		ix = rnd_round(Line->Point1.X + r * dx);
+		iy = rnd_round(Line->Point1.Y + r * dy);
 		if (!line_ep(Line, ix, iy) && pcb_is_point_on_arc(ix, iy, 1, Arc)) {
 			if (oline)
 				append(r, ix, iy);
@@ -227,8 +227,8 @@ static int intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, pcb_box_t *ip,
 
 	r = (Radius - r2) / l;
 	if ((r >= 0) && (r <= 1)) {
-		ix = pcb_round(Line->Point1.X + r * dx);
-		iy = pcb_round(Line->Point1.Y + r * dy);
+		ix = rnd_round(Line->Point1.X + r * dx);
+		iy = rnd_round(Line->Point1.Y + r * dy);
 		if (!line_ep(Line, ix, iy) && pcb_is_point_on_arc(ix, iy, 1, Arc)) {
 			if (oline)
 				append(r, ix, iy);
@@ -260,33 +260,33 @@ static int intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, pcb_box_t *ip,
 	return found;
 }
 
-int pcb_intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, pcb_box_t *ip, double offs[2])
+int pcb_intersect_cline_carc(pcb_line_t *Line, pcb_arc_t *Arc, rnd_box_t *ip, double offs[2])
 {
 	return intersect_cline_carc(Line, Arc, ip, offs, 1);
 }
 
-int pcb_intersect_carc_cline(pcb_arc_t *Arc, pcb_line_t *Line, pcb_box_t *ip, double offs[2])
+int pcb_intersect_carc_cline(pcb_arc_t *Arc, pcb_line_t *Line, rnd_box_t *ip, double offs[2])
 {
 	return intersect_cline_carc(Line, Arc, ip, offs, 0);
 }
 
 
-void pcb_carc_offs(pcb_arc_t *arc, double offs, pcb_coord_t *dstx, pcb_coord_t *dsty)
+void pcb_carc_offs(pcb_arc_t *arc, double offs, rnd_coord_t *dstx, rnd_coord_t *dsty)
 {
-	double ang = (arc->StartAngle + offs * arc->Delta) / PCB_RAD_TO_DEG;
+	double ang = (arc->StartAngle + offs * arc->Delta) / RND_RAD_TO_DEG;
 
 	*dstx = arc->X + cos(ang) * arc->Width;
 	*dsty = arc->Y - sin(ang) * arc->Height;
 }
 
-double pcb_carc_pt_offs(pcb_arc_t *arc, pcb_coord_t px, pcb_coord_t py)
+double pcb_carc_pt_offs(pcb_arc_t *arc, rnd_coord_t px, rnd_coord_t py)
 {
 	double dx, dy, ang, end;
 
 	/* won't work with elliptical arc - see also pcb_is_point_on_arc */
 	dy = (double)(py - arc->Y) / (double)arc->Height;
 	dx = (double)(px - arc->X) / (double)arc->Width;
-	ang = (-atan2(dy, dx)) * PCB_RAD_TO_DEG + 180;
+	ang = (-atan2(dy, dx)) * RND_RAD_TO_DEG + 180;
 	end = arc->StartAngle + arc->Delta;
 
 	/* normalize the angle: there are multiple ways an arc can cover the same
@@ -311,16 +311,16 @@ double pcb_carc_pt_offs(pcb_arc_t *arc, pcb_coord_t px, pcb_coord_t py)
 }
 
 
-static void get_arc_ends(pcb_coord_t *box, pcb_arc_t *arc)
+static void get_arc_ends(rnd_coord_t *box, pcb_arc_t *arc)
 {
-	box[0] = arc->X - arc->Width * cos(PCB_M180 * arc->StartAngle);
-	box[1] = arc->Y + arc->Height * sin(PCB_M180 * arc->StartAngle);
-	box[2] = arc->X - arc->Width * cos(PCB_M180 * (arc->StartAngle + arc->Delta));
-	box[3] = arc->Y + arc->Height * sin(PCB_M180 * (arc->StartAngle + arc->Delta));
+	box[0] = arc->X - arc->Width * cos(RND_M180 * arc->StartAngle);
+	box[1] = arc->Y + arc->Height * sin(RND_M180 * arc->StartAngle);
+	box[2] = arc->X - arc->Width * cos(RND_M180 * (arc->StartAngle + arc->Delta));
+	box[3] = arc->Y + arc->Height * sin(RND_M180 * (arc->StartAngle + arc->Delta));
 }
 
 /* reduce arc start angle and delta to 0..360 */
-static void normalize_angles(pcb_angle_t *sa, pcb_angle_t *d)
+static void normalize_angles(rnd_angle_t *sa, rnd_angle_t *d)
 {
 	if (*d < 0) {
 		*sa += *d;
@@ -328,13 +328,13 @@ static void normalize_angles(pcb_angle_t *sa, pcb_angle_t *d)
 	}
 	if (*d > 360) /* full circle */
 		*d = 360;
-	*sa = pcb_normalize_angle(*sa);
+	*sa = rnd_normalize_angle(*sa);
 }
 
 static int radius_crosses_arc(double x, double y, pcb_arc_t *arc)
 {
-	double alpha = atan2(y - arc->Y, -x + arc->X) * PCB_RAD_TO_DEG;
-	pcb_angle_t sa = arc->StartAngle, d = arc->Delta;
+	double alpha = atan2(y - arc->Y, -x + arc->X) * RND_RAD_TO_DEG;
+	rnd_angle_t sa = arc->StartAngle, d = arc->Delta;
 
 	normalize_angles(&sa, &d);
 	if (alpha < 0)
@@ -344,11 +344,11 @@ static int radius_crosses_arc(double x, double y, pcb_arc_t *arc)
 	return (sa + d - 360) >= alpha;
 }
 
-int pcb_intersect_carc_carc(pcb_arc_t *Arc1, pcb_arc_t *Arc2, pcb_box_t *ip, double offs[2])
+int pcb_intersect_carc_carc(pcb_arc_t *Arc1, pcb_arc_t *Arc2, rnd_box_t *ip, double offs[2])
 {
 	double x, y, dx, dy, r1, r2, a, d, l, dl;
-	pcb_coord_t pdx, pdy;
-	pcb_coord_t box[8];
+	rnd_coord_t pdx, pdy;
+	rnd_coord_t box[8];
 	int found = 0;
 
 	/* try the end points first */
@@ -361,7 +361,7 @@ int pcb_intersect_carc_carc(pcb_arc_t *Arc1, pcb_arc_t *Arc2, pcb_box_t *ip, dou
 
 	pdx = Arc2->X - Arc1->X;
 	pdy = Arc2->Y - Arc1->Y;
-	dl = pcb_distance(Arc1->X, Arc1->Y, Arc2->X, Arc2->Y);
+	dl = rnd_distance(Arc1->X, Arc1->Y, Arc2->X, Arc2->Y);
 
 	/* the original code used to do angle checks for concentric case here but
 	   those cases are already handled by the above endpoint checks. */
