@@ -33,15 +33,15 @@
 #include <genvector/gds_char.h>
 #include <genvector/vtp0.h>
 
-#include "hid_attrib.h"
-#include "hid_init.h"
-#include "plugins.h"
+#include <librnd/core/hid_attrib.h>
+#include <librnd/core/hid_init.h>
+#include <librnd/core/plugins.h>
 #include "event.h"
-#include "actions.h"
+#include <librnd/core/actions.h>
 #include "funchash_core.h"
 #include "search.h"
 #include "centgeo.h"
-#include "misc_util.h"
+#include <librnd/core/misc_util.h>
 #include "board.h"
 #include "data_it.h"
 #include "obj_line.h"
@@ -49,8 +49,8 @@
 #include "fields_sphash.h"
 #include "draw_wireframe.h"
 #include "conf_core.h"
-#include "conf_hid.h"
-#include "vtc0.h"
+#include <librnd/core/conf_hid.h>
+#include <librnd/core/vtc0.h>
 
 static const char *ddraft_cookie = "ddraft plugin";
 static int pcb_ddraft_tool;
@@ -90,28 +90,27 @@ static long do_trim_split(vtp0_t *edges, int kwobj, int trim)
 {
 	pcb_objtype_t type;
 	void *ptr1, *ptr2, *ptr3;
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	long res = 0;
 
 	switch(kwobj) {
 		case F_Object:
 			for(;;) {
-				x = PCB_MAX_COORD;
-				pcb_hid_get_coords("Select an object to cut or press esc", &x, &y, 1);
-				if (x == PCB_MAX_COORD)
+				int cr = rnd_hid_get_coords("Select an object to cut or press esc", &x, &y, 1);
+				if (cr < 0)
 					break;
 
 				type = pcb_search_screen(x, y, CUT_TYPES, &ptr1, &ptr2, &ptr3);
 				if (type == 0) {
-					pcb_message(PCB_MSG_ERROR, "Can't cut that object\n");
+					rnd_message(RND_MSG_ERROR, "Can't cut that object\n");
 					continue;
 				}
 				res += pcb_trim_split(edges, NULL, (pcb_any_obj_t *)ptr2, REMO_INVALID, x, y, trim);
-				pcb_gui->invalidate_all(pcb_gui);
+				rnd_gui->invalidate_all(rnd_gui);
 			}
 			break;
 		default:
-			pcb_message(PCB_MSG_ERROR, "Invalid second argument\n");
+			rnd_message(RND_MSG_ERROR, "Invalid second argument\n");
 			return -1;
 	}
 
@@ -126,25 +125,25 @@ static fgw_error_t pcb_act_trim_split(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	int kwcut = F_Object, kwobj = F_Object;
 	pcb_objtype_t type;
 	void *ptr1, *ptr2, *ptr3;
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	vtp0_t edges;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_KEYWORD, trim_split, kwcut = fgw_keyword(&argv[1]));
-	PCB_ACT_MAY_CONVARG(2, FGW_KEYWORD, trim_split, kwobj = fgw_keyword(&argv[2]));
+	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, trim_split, kwcut = fgw_keyword(&argv[1]));
+	RND_ACT_MAY_CONVARG(2, FGW_KEYWORD, trim_split, kwobj = fgw_keyword(&argv[2]));
 
 	vtp0_init(&edges);
 
 	if ((kwobj == kwcut) && (kwobj != F_Object)) {
-		pcb_message(PCB_MSG_ERROR, "Both cutting edge and objects to cut can't be '%s'\n", kwcut == F_Selected ? "selected" : "found");
+		rnd_message(RND_MSG_ERROR, "Both cutting edge and objects to cut can't be '%s'\n", kwcut == F_Selected ? "selected" : "found");
 		goto err;
 	}
 
 	switch(kwcut) {
 		case F_Object:
-			pcb_hid_get_coords("Select cutting edge object", &x, &y, 0);
+			rnd_hid_get_coords("Select cutting edge object", &x, &y, 0);
 			type = pcb_search_screen(x, y, EDGE_TYPES, &ptr1, &ptr2, &ptr3);
 			if (type == 0) {
-				pcb_message(PCB_MSG_ERROR, "Invalid cutting edge object\n");
+				rnd_message(RND_MSG_ERROR, "Invalid cutting edge object\n");
 				goto err;
 			}
 			vtp0_append(&edges, ptr2);
@@ -156,12 +155,12 @@ static fgw_error_t pcb_act_trim_split(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			list_by_flag(PCB->Data, &edges, EDGE_TYPES, PCB_FLAG_FOUND);
 			break;
 		default:
-			pcb_message(PCB_MSG_ERROR, "Invalid first argument\n");
+			rnd_message(RND_MSG_ERROR, "Invalid first argument\n");
 			goto err;
 	}
 
 	if (vtp0_len(&edges) < 1) {
-		pcb_message(PCB_MSG_ERROR, "No cutting edge found\n");
+		rnd_message(RND_MSG_ERROR, "No cutting edge found\n");
 		goto err;
 	}
 
@@ -169,12 +168,12 @@ static fgw_error_t pcb_act_trim_split(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (do_trim_split(&edges, kwobj, (*actname == 't')) < 0)
 		goto err;
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	vtp0_uninit(&edges);
 	return 0;
 
 	err:;
-	PCB_ACT_IRES(-1);
+	RND_ACT_IRES(-1);
 	vtp0_uninit(&edges);
 	return 0;
 }
@@ -199,16 +198,16 @@ static fgw_error_t pcb_act_split_idp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	for(n = 1; n < 3; n++) {
 		vect = (n == 1) ? &edges : &objs;
 
-		PCB_ACT_CONVARG(n, FGW_IDPATH, split_idp, idp = fgw_idpath(&argv[n]));
+		RND_ACT_CONVARG(n, FGW_IDPATH, split_idp, idp = fgw_idpath(&argv[n]));
 		if (idp == NULL)
 			goto invptr;
-		if (fgw_ptr_in_domain(&pcb_fgw, &argv[n], PCB_PTR_DOMAIN_IDPATH)) {
+		if (fgw_ptr_in_domain(&rnd_fgw, &argv[n], RND_PTR_DOMAIN_IDPATH)) {
 			obj = pcb_idpath2obj(PCB, idp);
 			if ((obj == NULL) || ((obj->type & PCB_OBJ_CLASS_REAL) == 0))
 				goto invptr;
 			vtp0_append(vect, obj);
 		}
-		else if (fgw_ptr_in_domain(&pcb_fgw, &argv[n], PCB_PTR_DOMAIN_IDPATH_LIST)) {
+		else if (fgw_ptr_in_domain(&rnd_fgw, &argv[n], RND_PTR_DOMAIN_IDPATH_LIST)) {
 			idpl = (pcb_idpath_list_t *)idp;
 			pcb_idpath_list_foreach(idpl, &it, idp) {
 				obj = pcb_idpath2obj(PCB, idp);
@@ -227,7 +226,7 @@ static fgw_error_t pcb_act_split_idp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* copy over the objects to an idpath_list that is then returned */
 	idpl = calloc(sizeof(pcb_idpath_list_t), 1);
-	fgw_ptr_reg(&pcb_fgw, res, PCB_PTR_DOMAIN_IDPATH_LIST, FGW_PTR | FGW_STRUCT, idpl);
+	fgw_ptr_reg(&rnd_fgw, res, RND_PTR_DOMAIN_IDPATH_LIST, FGW_PTR | FGW_STRUCT, idpl);
 	for(n = 0; n < vtp0_len(&newobjs); n++) {
 		idp = pcb_obj2idpath(newobjs.array[n]);
 		if (idp != NULL)
@@ -253,13 +252,13 @@ static fgw_error_t pcb_act_split_idp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 do { \
 	int n; \
 	if (argc-2 >= sizeof(arr) / sizeof(arr[0])) { \
-		pcb_message(PCB_MSG_ERROR, "constraint: Too many " msg "\n"); \
-		PCB_ACT_IRES(-1); \
+		rnd_message(RND_MSG_ERROR, "constraint: Too many " msg "\n"); \
+		RND_ACT_IRES(-1); \
 		return 0; \
 	} \
 	ctr = 0; \
 	for(n = 2; n < argc; n++) { \
-		PCB_ACT_CONVARG(n, fgw_type_, constraint, arr[ctr] = fgw_val_); \
+		RND_ACT_CONVARG(n, fgw_type_, constraint, arr[ctr] = fgw_val_); \
 		ctr++; \
 	} \
 } while(0)
@@ -271,9 +270,9 @@ static fgw_error_t pcb_act_constraint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	char *stype = NULL;
 	int type;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, constraint, stype = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, constraint, stype = argv[1].val.str);
 	if (stype == NULL) {
-		PCB_ACT_IRES(constraint_gui());
+		RND_ACT_IRES(constraint_gui());
 		return 0;
 	}
 	type = ddraft_fields_sphash(stype);
@@ -288,12 +287,12 @@ static fgw_error_t pcb_act_constraint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			break;
 		case ddraft_fields_line_angle_mod:
 			cons.line_angle_mod = 0;
-			PCB_ACT_MAY_CONVARG(2, FGW_DOUBLE, constraint, cons.line_angle_mod = argv[2].val.nat_double);
+			RND_ACT_MAY_CONVARG(2, FGW_DOUBLE, constraint, cons.line_angle_mod = argv[2].val.nat_double);
 			cons_changed();
 			break;
 		case ddraft_fields_move_angle_mod:
 			cons.move_angle_mod = 0;
-			PCB_ACT_MAY_CONVARG(2, FGW_DOUBLE, constraint, cons.move_angle_mod = argv[2].val.nat_double);
+			RND_ACT_MAY_CONVARG(2, FGW_DOUBLE, constraint, cons.move_angle_mod = argv[2].val.nat_double);
 			cons_changed();
 			break;
 		case ddraft_fields_line_length:
@@ -306,12 +305,12 @@ static fgw_error_t pcb_act_constraint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			break;
 		case ddraft_fields_line_length_mod:
 			cons.line_length_mod = 0;
-			PCB_ACT_MAY_CONVARG(2, FGW_COORD, constraint, cons.line_length_mod = fgw_coord(&argv[2]));
+			RND_ACT_MAY_CONVARG(2, FGW_COORD, constraint, cons.line_length_mod = fgw_coord(&argv[2]));
 			cons_changed();
 			break;
 		case ddraft_fields_move_length_mod:
 			cons.move_length_mod = 0;
-			PCB_ACT_MAY_CONVARG(2, FGW_COORD, constraint, cons.move_length_mod = fgw_coord(&argv[2]));
+			RND_ACT_MAY_CONVARG(2, FGW_COORD, constraint, cons.move_length_mod = fgw_coord(&argv[2]));
 			cons_changed();
 			break;
 
@@ -320,13 +319,13 @@ static fgw_error_t pcb_act_constraint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			cons_changed();
 			break;
 		case ddraft_fields_SPHASH_INVALID:
-			pcb_message(PCB_MSG_ERROR, "constraint: invalid field '%s'\n", stype);
-			PCB_ACT_IRES(-1);
+			rnd_message(RND_MSG_ERROR, "constraint: invalid field '%s'\n", stype);
+			RND_ACT_IRES(-1);
 			return 0;
 			break;
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -337,21 +336,21 @@ static fgw_error_t pcb_act_perp_paral(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	const char *actname = argv[0].val.func->name;
 	pcb_objtype_t type;
 	void *ptr1, *ptr2, *ptr3;
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	double dx, dy;
 	pcb_line_t *line;
 
-	pcb_hid_get_coords("Select target object", &x, &y, 0);
+	rnd_hid_get_coords("Select target object", &x, &y, 0);
 	type = pcb_search_screen(x, y, EDGE_TYPES, &ptr1, &ptr2, &ptr3);
 
 	if (type != PCB_OBJ_LINE) {
-		pcb_hid_get_coords("Select target object", &x, &y, 1);
+		rnd_hid_get_coords("Select target object", &x, &y, 1);
 		type = pcb_search_screen(x, y, EDGE_TYPES, &ptr1, &ptr2, &ptr3);
 	}
 
 	if (type != PCB_OBJ_LINE) {
-		pcb_message(PCB_MSG_ERROR, "%s: target object must be a line\n", actname);
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "%s: target object must be a line\n", actname);
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
@@ -359,19 +358,19 @@ static fgw_error_t pcb_act_perp_paral(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	dx = line->Point2.X - line->Point1.X;
 	dy = line->Point2.Y - line->Point1.Y;
 	if ((dx == 0.0) && (dy == 0.0)) {
-		pcb_message(PCB_MSG_ERROR, "%s: target line must be longer than 0\n", actname);
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "%s: target line must be longer than 0\n", actname);
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
 	cons.line_angle_len = 2;
-	cons.line_angle[0] = atan2(dy, dx) * PCB_RAD_TO_DEG;
+	cons.line_angle[0] = atan2(dy, dx) * RND_RAD_TO_DEG;
 	if (actname[1] == 'e') /* perp */
 		cons.line_angle[0] += 90;
 	cons.line_angle[1] = fmod(cons.line_angle[0]+180, 360);
 	cons_changed();
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -382,7 +381,7 @@ static fgw_error_t pcb_act_tang(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	pcb_objtype_t type;
 	void *ptr1, *ptr2, *ptr3;
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	double d, r, base;
 	pcb_route_object_t *line;
 	pcb_arc_t *arc;
@@ -390,8 +389,8 @@ static fgw_error_t pcb_act_tang(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	if (((pcb_crosshair.AttachedLine.State != PCB_CH_STATE_SECOND) && (pcb_crosshair.AttachedLine.State != PCB_CH_STATE_THIRD)) || (pcb_crosshair.Route.size < 1)) {
 		err_nonline:;
-		pcb_message(PCB_MSG_ERROR, "tang: must be in line drawing mode with the first point already set\n");
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "tang: must be in line drawing mode with the first point already set\n");
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
@@ -400,60 +399,60 @@ static fgw_error_t pcb_act_tang(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		goto err_nonline;
 
 
-	pcb_hid_get_coords("Select target arc", &x, &y, 0);
+	rnd_hid_get_coords("Select target arc", &x, &y, 0);
 	type = pcb_search_screen(x, y, EDGE_TYPES, &ptr1, &ptr2, &ptr3);
 
 	if (type != PCB_OBJ_ARC) {
-		pcb_hid_get_coords("Select target arc", &x, &y, 1);
+		rnd_hid_get_coords("Select target arc", &x, &y, 1);
 		type = pcb_search_screen(x, y, EDGE_TYPES, &ptr1, &ptr2, &ptr3);
 	}
 
 	if (type != PCB_OBJ_ARC) {
-		pcb_message(PCB_MSG_ERROR, "tang: target object must be an arc\n");
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "tang: target object must be an arc\n");
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
 	arc = (pcb_arc_t *)ptr2;
 	if (fabs((double)(arc->Height - arc->Width)) > 100) {
-		pcb_message(PCB_MSG_ERROR, "tang: elliptical arcs are not supported (%$mm != %$mm)\n", arc->Height, arc->Width);
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "tang: elliptical arcs are not supported (%$mm != %$mm)\n", arc->Height, arc->Width);
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
-	d = pcb_distance(arc->X, arc->Y, line->point1.X, line->point1.Y);
+	d = rnd_distance(arc->X, arc->Y, line->point1.X, line->point1.Y);
 	r = arc->Width;
 
 	if (d <= r) {
-		pcb_message(PCB_MSG_ERROR, "tang: line must start outside of the circle\n");
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "tang: line must start outside of the circle\n");
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
 	base = atan2(arc->Y - line->point1.Y, arc->X - line->point1.X);
 
 	cons.line_angle_len = 2;
-	cons.line_angle[0] = (base + asin(r / d)) * PCB_RAD_TO_DEG;
-	cons.line_angle[1] = (base + asin(-r / d)) * PCB_RAD_TO_DEG;
+	cons.line_angle[0] = (base + asin(r / d)) * RND_RAD_TO_DEG;
+	cons.line_angle[1] = (base + asin(-r / d)) * RND_RAD_TO_DEG;
 	cons_changed();
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-void ddraft_tool_draw_attached(pcb_hidlib_t *hl)
+void ddraft_tool_draw_attached(rnd_hidlib_t *hl)
 {
 	int n;
-	pcb_render->set_line_cap(pcb_crosshair.GC, pcb_cap_round);
-	pcb_render->set_line_width(pcb_crosshair.GC, 1);
-	pcb_render->set_color(pcb_crosshair.GC, pcb_color_grey33);
+	rnd_render->set_line_cap(pcb_crosshair.GC, rnd_cap_round);
+	rnd_render->set_line_width(pcb_crosshair.GC, 1);
+	rnd_render->set_color(pcb_crosshair.GC, rnd_color_grey33);
 	for(n = 0; n < vtc0_len(&pcb_ddraft_attached.annot_lines); n += 4) {
-		pcb_coord_t *c = &pcb_ddraft_attached.annot_lines.array[n];
-		pcb_render->draw_line(pcb_crosshair.GC, c[0], c[1], c[2], c[3]);
+		rnd_coord_t *c = &pcb_ddraft_attached.annot_lines.array[n];
+		rnd_render->draw_line(pcb_crosshair.GC, c[0], c[1], c[2], c[3]);
 	}
 
 	if (pcb_ddraft_attached.line_valid) {
-		pcb_render->set_color(pcb_crosshair.GC, &PCB_CURRLAYER(PCB)->meta.real.color);
+		rnd_render->set_color(pcb_crosshair.GC, &PCB_CURRLAYER(PCB)->meta.real.color);
 		pcb_draw_wireframe_line(pcb_crosshair.GC,
 			pcb_ddraft_attached.line.Point1.X, pcb_ddraft_attached.line.Point1.Y, pcb_ddraft_attached.line.Point2.X, pcb_ddraft_attached.line.Point2.Y,
 			conf_core.design.line_thickness, 0);
@@ -462,7 +461,7 @@ void ddraft_tool_draw_attached(pcb_hidlib_t *hl)
 
 #include "cli.c"
 
-static pcb_action_t ddraft_action_list[] = {
+static rnd_action_t ddraft_action_list[] = {
 	{"trim", pcb_act_trim_split, pcb_acth_trim_split, pcb_acts_trim_split},
 	{"split", pcb_act_trim_split, pcb_acth_trim_split, pcb_acts_trim_split},
 	{"pcbsplit", pcb_act_split_idp, pcb_acth_split_idp, pcb_acts_split_idp},
@@ -501,9 +500,9 @@ static const char *ddraft_xpm[] = {
 "     ..... ....      ",
 "                     "};
 
-static pcb_tool_t tool_ddraft = {
+static rnd_tool_t tool_ddraft = {
 	"ddraft", "2 dimensional drafting",
-	NULL, 1000, ddraft_xpm, PCB_TOOL_CURSOR_NAMED(NULL), 1,
+	NULL, 1000, ddraft_xpm, RND_TOOL_CURSOR_NAMED(NULL), 1,
 	NULL,
 	NULL,
 	NULL,
@@ -512,23 +511,24 @@ static pcb_tool_t tool_ddraft = {
 	ddraft_tool_draw_attached,
 	NULL,
 	NULL,
-	pcb_false
+	NULL, /* escape */
+	rnd_false
 };
 
 
-static void mode_confchg(conf_native_t *cfg, int arr_idx)
+static void mode_confchg(rnd_conf_native_t *cfg, int arr_idx)
 {
 	static int ddraft_tool_selected = 0;
 
-	if (pcbhl_conf.editor.mode == pcb_ddraft_tool) {
+	if (rnd_conf.editor.mode == pcb_ddraft_tool) {
 		if (!ddraft_tool_selected) {
 			ddraft_tool_selected = 1;
-			pcb_cli_enter("ddraft", "ddraft");
-			pcb_gui->open_command(pcb_gui);
+			rnd_cli_enter("ddraft", "ddraft");
+			rnd_gui->open_command(rnd_gui);
 		}
 	}
 	else if (ddraft_tool_selected) {
-		pcb_cli_leave();
+		rnd_cli_leave();
 		ddraft_tool_selected = 0;
 	}
 }
@@ -537,33 +537,31 @@ int pplg_check_ver_ddraft(int ver_needed) { return 0; }
 
 void pplg_uninit_ddraft(void)
 {
-	pcb_conf_hid_unreg(ddraft_cookie);
-	pcb_event_unbind_allcookie(ddraft_cookie);
-	pcb_remove_actions_by_cookie(ddraft_cookie);
-	pcb_tool_unreg_by_cookie(ddraft_cookie);
+	rnd_conf_hid_unreg(ddraft_cookie);
+	rnd_event_unbind_allcookie(ddraft_cookie);
+	rnd_remove_actions_by_cookie(ddraft_cookie);
+	rnd_tool_unreg_by_cookie(ddraft_cookie);
 }
 
-static const conf_hid_callbacks_t conf_cbs_adl = { NULL, cons_gui_confchg, NULL, NULL };
-static const conf_hid_callbacks_t conf_cbs_mode = { NULL, mode_confchg, NULL, NULL };
+static const rnd_conf_hid_callbacks_t conf_cbs_adl = { NULL, cons_gui_confchg, NULL, NULL };
+static const rnd_conf_hid_callbacks_t conf_cbs_mode = { NULL, mode_confchg, NULL, NULL };
 
 int pplg_init_ddraft(void)
 {
-	conf_native_t *cn;
-	conf_hid_id_t confid;
+	rnd_conf_native_t *cn;
+	rnd_conf_hid_id_t confid;
 
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
-	PCB_REGISTER_ACTIONS(ddraft_action_list, ddraft_cookie)
-	pcb_event_bind(PCB_EVENT_DRAW_CROSSHAIR_CHATT, cnst_enforce, NULL, ddraft_cookie);
+	RND_REGISTER_ACTIONS(ddraft_action_list, ddraft_cookie)
+	rnd_event_bind(PCB_EVENT_DRAW_CROSSHAIR_CHATT, cnst_enforce, NULL, ddraft_cookie);
 
-	pcb_tool_reg(&tool_ddraft, ddraft_cookie);
-	pcb_ddraft_tool = pcb_tool_lookup(tool_ddraft.name);
+	pcb_ddraft_tool = rnd_tool_reg(&tool_ddraft, ddraft_cookie);
 
-
-	confid = pcb_conf_hid_reg(ddraft_cookie, NULL);
-	cn = pcb_conf_get_field("editor/all_direction_lines");
-	pcb_conf_hid_set_cb(cn, confid, &conf_cbs_adl);
-	cn = pcb_conf_get_field("editor/mode");
-	pcb_conf_hid_set_cb(cn, confid, &conf_cbs_mode);
+	confid = rnd_conf_hid_reg(ddraft_cookie, NULL);
+	cn = rnd_conf_get_field("editor/all_direction_lines");
+	rnd_conf_hid_set_cb(cn, confid, &conf_cbs_adl);
+	cn = rnd_conf_get_field("editor/mode");
+	rnd_conf_hid_set_cb(cn, confid, &conf_cbs_mode);
 	return 0;
 }
