@@ -135,14 +135,14 @@ static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 
-static void print_font(pcb_font_t *f, const char *prefix)
+static void print_font(rnd_font_t *f, const char *prefix)
 {
 	int n, g = 0, gletter = 0, gdigit = 0;
 	const char *name;
 
 	/* count valid glyphs and classes */
 	for(n = 0; n < PCB_MAX_FONTPOSITION + 1; n++) {
-		if (f->Symbol[n].Valid) {
+		if (f->glyph[n].valid) {
 			g++;
 			if (isalpha(n)) gletter++;
 			if (isdigit(n)) gdigit++;
@@ -150,7 +150,7 @@ static void print_font(pcb_font_t *f, const char *prefix)
 	}
 
 	name = f->name == NULL ? "<anon>" : f->name;
-	rnd_printf("%s: %d %s; dim: %$$mm * %$$mm glyphs: %d (letter: %d, digit: %d)\n", prefix, f->id, name, f->MaxWidth, f->MaxHeight, g, gletter, gdigit);
+	rnd_printf("%s: %d %s; dim: %$$mm * %$$mm glyphs: %d (letter: %d, digit: %d)\n", prefix, f->id, name, f->max_width, f->max_height, g, gletter, gdigit);
 }
 
 static const char dump_fonts_syntax[] = "dumpfonts()\n";
