@@ -1,8 +1,10 @@
 /* Open a padstack library dialog box for a subc (or for the board if subc_id
    is 0). If modal, returns the selected prototype or PCB_PADSTACK_INVALID when
    nothing is selected or the operation cancelled. In non-modal mode return
-   0 on success and PCB_PADSTACK_INVALID on error. */
-rnd_cardinal_t pcb_dlg_pstklib(pcb_board_t *pcb, long subc_id, rnd_bool modal, const char *hint);
+   0 on success and PCB_PADSTACK_INVALID on error. Id presel is not
+   PCB_PADSTACK_INVALID, preselect the table row named in presel. */
+rnd_cardinal_t pcb_dlg_pstklib(pcb_board_t *pcb, long subc_id, rnd_bool modal, rnd_cardinal_t presel, const char *hint);
+
 
 extern const char pcb_acts_pstklib[];
 extern const char pcb_acth_pstklib[];
