@@ -360,7 +360,7 @@ static void mark_grp(rnd_coord_t y, unsigned int accept_mask, mark_grp_loc_t loc
 
 	g = get_group_coords(y, &y1, &y2);
 
-	if ((g >= 0) && ((pcb_layergrp_flags(PCB, g) & accept_mask) & accept_mask)) {
+	if ((g >= 0) && (pcb_layergrp_flags(PCB, g) & accept_mask)) {
 		gactive = g;
 		switch(loc) {
 			case MARK_GRP_FRAME:
@@ -502,7 +502,10 @@ TODO("layer: handle multiple outline layers")
 
 		rnd_render->set_color(gc, color);
 		dhrect(0, y, GROUP_WIDTH_MM, y+th,  1, 0.5,  stepf, stepb, OMIT_LEFT | OMIT_RIGHT);
-		dtext_bg(gc, 5, y, 200, 0, g->name, &COLOR_BG, &COLOR_ANNOT);
+		{
+			const char *name = g->name == NULL ? "<unnamed group>" : g->name;
+			dtext_bg(gc, 5, y, 200, 0, name, &COLOR_BG, &COLOR_ANNOT);
+		}
 		thick = pcb_attribute_get(&g->Attributes, "thickness");
 		if (thick != NULL)
 			dtext_bg(gc, 45, y, 200, 0, thick, &COLOR_BG, &COLOR_ANNOT);
@@ -766,6 +769,7 @@ static rnd_bool mouse_csect(rnd_hid_mouse_ev_t kind, rnd_coord_t x, rnd_coord_t
 			else if (drag_addgrp) {
 				if (gactive >= 0) {
 					pcb_layergrp_t *g;
+					pcb_layergrp_inhibit_inc();
 					pcb_undo_freeze_serial();
 					g = pcb_layergrp_insert_after(PCB, gactive);
 					g->name = NULL;
@@ -779,6 +783,8 @@ static rnd_bool mouse_csect(rnd_hid_mouse_ev_t kind, rnd_coord_t x, rnd_coord_t
 					pcb_layergrp_undoable_created(g);
 					pcb_undo_unfreeze_serial();
 					pcb_undo_inc_serial();
+					pcb_layergrp_inhibit_dec();
+					pcb_layergrp_notify(PCB);
 				}
 				drag_addgrp = 0;
 				gactive = -1;
