@@ -398,7 +398,7 @@ TODO("subc: subc-in-subc")
 
 /*** export hid administration and API/glu ***/
 
-static rnd_export_opt_t ipcd356_options[] = {
+static const rnd_export_opt_t ipcd356_options[] = {
 /* %start-doc options "8 IPC-D-356 Netlist Export"
 @ftable @code
 @item --netlist-file <string>
@@ -410,11 +410,11 @@ Name of the IPC-D-356 Netlist output file.
 	 "netlistfile",
 	 "Name of the IPC-D-356 Netlist output file",
 	 RND_HATT_STRING,
-	 0, 0, {0, 0, 0}, 0, 0},
+	 0, 0, {0, 0, 0}, 0},
 #define HA_ipcd356_filename 0
 
 	{"cam", "CAM instruction",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_cam 1
 
 };
@@ -423,11 +423,11 @@ Name of the IPC-D-356 Netlist output file.
 
 static rnd_hid_attr_val_t ipcd356_values[NUM_OPTIONS];
 
-static rnd_export_opt_t *ipcd356_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *ipcd356_get_export_options(rnd_hid_t *hid, int *n)
 {
-	char **val = ipcd356_options[HA_ipcd356_filename].value;
-	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &ipcd356_options[HA_ipcd356_filename], ".net");
+	const char *val = ipcd356_values[HA_ipcd356_filename].str;
+	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(PCB->hidlib.filename, &ipcd356_values[HA_ipcd356_filename], ".net");
 
 	if (n != NULL)
 		*n = NUM_OPTIONS;
@@ -495,6 +495,7 @@ int pplg_init_export_ipcd356(void)
 	ipcd356_hid.argument_array = ipcd356_values;
 
 	rnd_hid_register_hid(&ipcd356_hid);
+	rnd_hid_load_defaults(&ipcd356_hid, ipcd356_options, NUM_OPTIONS);
 
 	rnd_export_register_opts2(&ipcd356_hid, ipcd356_options, sizeof(ipcd356_options) / sizeof(ipcd356_options[0]), ipcd356_cookie, 0);
 	return 0;
