@@ -150,7 +150,7 @@ static rnd_bool to_hz(const char *s, double *out)
 {
 	const rnd_unit_t *u;
 	double d;
-	if (!rnd_get_value_unit(s, NULL, 0, &d, &u))
+	if ((s == NULL) || (!rnd_get_value_unit(s, NULL, 0, &d, &u)))
 		return rnd_false;
 	if (u->family != RND_UNIT_FREQ)
 		return rnd_false;
