@@ -1,7 +1,10 @@
-extern const char *ps_cookie;
+/* required by lpr */
 extern rnd_hid_t ps_hid;
 extern void ps_hid_export_to_file(FILE *, rnd_hid_attr_val_t *, rnd_xform_t *);
-extern void ps_start_file(FILE *);
+void ps_ps_init(rnd_hid_t * hid);
+
+/* required for ps<->eps cross call */
 extern void hid_eps_init();
 extern void hid_eps_uninit();
-void ps_ps_init(rnd_hid_t * hid);
+extern const char *ps_cookie;
+
