@@ -68,40 +68,40 @@ static rnd_hid_t stat_hid;
 
 const char *stat_cookie = "stat HID";
 
-rnd_export_opt_t stat_attribute_list[] = {
+static const rnd_export_opt_t stat_attribute_list[] = {
 	/* other HIDs expect this to be first.  */
 
 	{"outfile", "Output file name",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_statfile 0
 
 	{"board_id", "Short name of the board so it can be identified for updates",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_board_id 1
 
 	{"orig", "This design started its life in pcb-rnd",
-	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0},
 #define HA_orig 2
 
 	{"lht_built", "This design was already in lihata when real boards got built",
-	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0},
 #define HA_lht_built 3
 
 
 	{"built", "how many actual/physical boards got built",
-	 RND_HATT_INTEGER, 0, 1000000, {0, 0, 0}, 0, 0},
+	 RND_HATT_INTEGER, 0, 1000000, {0, 0, 0}, 0},
 #define HA_built 4
 
 	{"first_ver", "the version of pcb-rnd you first used on this board",
-	 RND_HATT_STRING, 0, 0, {0, NULL, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, NULL, 0}, 0},
 #define HA_first_ver 5
 
 	{"license", "license of the design",
-	 RND_HATT_STRING, 0, 0, {0, NULL, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, NULL, 0}, 0},
 #define HA_license 6
 
 	{"cam", "CAM instruction",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_cam 7
 
 };
@@ -110,13 +110,13 @@ rnd_export_opt_t stat_attribute_list[] = {
 
 static rnd_hid_attr_val_t stat_values[NUM_OPTIONS];
 
-static rnd_export_opt_t *stat_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *stat_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = ".stat.lht";
-	char **val = stat_attribute_list[HA_statfile].value;
+	const char *val = stat_values[HA_statfile].str;
 
-	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &stat_attribute_list[HA_statfile], suffix);
+	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(PCB->hidlib.filename, &stat_values[HA_statfile], suffix);
 
 	if (n)
 		*n = NUM_OPTIONS;
@@ -388,10 +388,10 @@ int pplg_check_ver_export_stat(int ver_needed) { return 0; }
 
 void pplg_uninit_export_stat(void)
 {
-	free((char *)stat_attribute_list[HA_first_ver].default_val.str);
-	free((char *)stat_attribute_list[HA_license].default_val.str);
-	stat_attribute_list[HA_first_ver].default_val.str = NULL;
-	stat_attribute_list[HA_license].default_val.str = NULL;
+	free((char *)stat_values[HA_first_ver].str);
+	free((char *)stat_values[HA_license].str);
+	stat_values[HA_first_ver].str = NULL;
+	stat_values[HA_license].str = NULL;
 	rnd_export_remove_opts_by_cookie(stat_cookie);
 	rnd_hid_remove_hid(&stat_hid);
 }
@@ -416,10 +416,12 @@ int pplg_init_export_stat(void)
 
 	stat_hid.usage = stat_usage;
 
-	stat_attribute_list[HA_first_ver].default_val.str = rnd_strdup(PCB_VERSION);
-	stat_attribute_list[HA_license].default_val.str = rnd_strdup("proprietary/private");
 
 	rnd_hid_register_hid(&stat_hid);
+	rnd_hid_load_defaults(&stat_hid, stat_attribute_list, NUM_OPTIONS);
+
+	stat_values[HA_first_ver].str = rnd_strdup(PCB_VERSION);
+	stat_values[HA_license].str = rnd_strdup("proprietary/private");
 
 	return 0;
 }
