@@ -47,11 +47,11 @@
 #include "../lib_polyhelp/topoly.h"
 #include "../lib_polyhelp/triangulate.h"
 
-static rnd_hid_t stl_hid;
+static rnd_hid_t stl_hid, amf_hid, proj_hid;
 const char *stl_cookie = "export_stl HID";
 
 static const rnd_export_opt_t stl_attribute_list[] = {
-	{"outfile", "STL output file",
+	{"outfile", "STL/AMF output file",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_stlfile 0
 
@@ -60,11 +60,11 @@ static const rnd_export_opt_t stl_attribute_list[] = {
 #define HA_models 1
 
 	{"min-drill", "minimum circular hole diameter to render (smaller ones are not drawn)",
-	 RND_HATT_COORD, 0, 0, {0, 0, 0}, 0},
+	 RND_HATT_COORD, 0, RND_COORD_MAX, {0, 0, 0}, 0},
 #define HA_mindrill 2
 
 	{"min-slot-line", "minimum thickness of padstakc slots specified as lines (smaller ones are not drawn)",
-	 RND_HATT_COORD, 0, 0, {0, 0, 0}, 0},
+	 RND_HATT_COORD, 0, RND_COORD_MAX, {0, 0, 0}, 0},
 #define HA_minline 3
 
 	{"slot-poly", "draw cutouts for slots specified as padstack polygons",
@@ -76,7 +76,7 @@ static const rnd_export_opt_t stl_attribute_list[] = {
 #define HA_cutouts 5
 
 	{"override-thickness", "override calculated board thickness (when non-zero)",
-	 RND_HATT_COORD, 0, 0, {1, 0, 0}, 0},
+	 RND_HATT_COORD, 0, RND_COORD_MAX, {1, 0, 0}, 0},
 #define HA_ovrthick 6
 
 	{"z-center", "when true: z=0 is the center of board cross section, instead of being at the bottom side",
@@ -92,66 +92,6 @@ static const rnd_export_opt_t stl_attribute_list[] = {
 
 static rnd_hid_attr_val_t stl_values[NUM_OPTIONS];
 
-static const rnd_export_opt_t *stl_get_export_options(rnd_hid_t *hid, int *n)
-{
-	const char *suffix = ".stl";
-	const char *val = stl_values[HA_stlfile].str;
-
-	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
-		pcb_derive_default_filename(PCB->hidlib.filename, &stl_values[HA_stlfile], suffix);
-
-	if (n)
-		*n = NUM_OPTIONS;
-	return stl_attribute_list;
-}
-
-static void stl_print_horiz_tri(FILE *f, fp2t_triangle_t *t, int up, rnd_coord_t z)
-{
-	fprintf(f, "	facet normal 0 0 %d\n", up ? 1 : -1);
-	fprintf(f, "		outer loop\n");
-
-	if (up) {
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[0]->X, (rnd_coord_t)t->Points[0]->Y, z);
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[1]->X, (rnd_coord_t)t->Points[1]->Y, z);
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[2]->X, (rnd_coord_t)t->Points[2]->Y, z);
-	}
-	else {
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[2]->X, (rnd_coord_t)t->Points[2]->Y, z);
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[1]->X, (rnd_coord_t)t->Points[1]->Y, z);
-		rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", (rnd_coord_t)t->Points[0]->X, (rnd_coord_t)t->Points[0]->Y, z);
-	}
-
-	fprintf(f, "		endloop\n");
-	fprintf(f, "	endfacet\n");
-}
-
-static void stl_print_vert_tri(FILE *f, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2, rnd_coord_t z0, rnd_coord_t z1)
-{
-	double vx, vy, nx, ny, len;
-
-	vx = x2 - x1; vy = y2 - y1;
-	len = sqrt(vx*vx + vy*vy);
-	if (len == 0) return;
-	vx /= len; vy /= len;
-	nx = -vy; ny = vx;
-
-	fprintf(f, "	facet normal %f %f 0\n", nx, ny);
-	fprintf(f, "		outer loop\n");
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x2, y2, z1);
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x1, y1, z1);
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x1, y1, z0);
-	fprintf(f, "		endloop\n");
-	fprintf(f, "	endfacet\n");
-
-	fprintf(f, "	facet normal %f %f 0\n", nx, ny);
-	fprintf(f, "		outer loop\n");
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x2, y2, z1);
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x1, y1, z0);
-	rnd_fprintf(f, "			vertex %.09mm %.09mm %.09mm\n", x2, y2, z0);
-	fprintf(f, "		endloop\n");
-	fprintf(f, "	endfacet\n");
-}
-
 static long pa_len(const rnd_polyarea_t *pa)
 {
 	rnd_pline_t *pl;
@@ -216,12 +156,22 @@ static int pstk_points(pcb_board_t *pcb, pcb_pstk_t *pstk, pcb_layer_t *layer, f
 			case PCB_PSSH_POLY:
 				{
 					int n;
+					rnd_coord_t px, py;
+
 					for(n = 0; n < shp->data.poly.len; n++) {
-						fp2t_point_t *pt = fp2t_push_point(tri);
-						pt->X = pstk->x + shp->data.poly.x[n];
-						pt->Y = maxy - (pstk->y + shp->data.poly.y[n]);
+						rnd_coord_t x = pstk->x + shp->data.poly.x[n], y = maxy - (pstk->y + shp->data.poly.y[n]);
+						fp2t_point_t *pt;
+						
+						if ((n > 0) && (px == x) && (py == y))
+							continue;
+
+						pt = fp2t_push_point(tri);
+						pt->X = x;
+						pt->Y = y;
 						vtd0_append(contours, pt->X);
 						vtd0_append(contours, pt->Y);
+						px = x;
+						py = y;
 					}
 					fp2t_add_hole(tri);
 					vtd0_append(contours, HUGE_VAL);
@@ -359,9 +309,100 @@ static void add_holes_cutout(fp2t_t *tri, pcb_board_t *pcb, rnd_coord_t maxy, vt
 	}
 }
 
-#include "stl_models.c"
+typedef struct stl_facet_s stl_facet_t;
 
-int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t maxy, rnd_coord_t z0, rnd_coord_t z1)
+struct stl_facet_s {
+	double n[3];
+	double vx[3], vy[3], vz[3];
+	stl_facet_t *next;
+};
+RND_INLINE void v_transform(double dst[3], double src[3], double mx[16]);
+
+static void stl_triangle_normal(double *dx, double *dy, double *dz, double x1, double y1, double z1, double x2, double y2, double z2, double x3, double y3, double z3)
+{
+	double len;
+
+	*dx = (y2-y1)*(z3-z1) - (y3-y1)*(z2-z1);
+	*dy = (z2-z1)*(x3-x1) - (x2-x1)*(z3-z1);
+	*dz = (x2-x1)*(y3-y1) - (x3-x1)*(y2-y1);
+
+	len = sqrt((*dx) * (*dx) + (*dy) * (*dy) + (*dz) * (*dz));
+	if (len == 0) return;
+
+	*dx /= len;
+	*dy /= len;
+	*dz /= len;
+}
+
+static void stl_facet_normal(stl_facet_t *t)
+{
+	stl_triangle_normal(
+		&t->n[0], &t->n[1], &t->n[2],
+		t->vx[0], t->vy[0], t->vz[0],
+		t->vx[1], t->vy[1], t->vz[1],
+		t->vx[2], t->vy[2], t->vz[2]
+		);
+}
+
+#include "verthash.c"
+
+typedef struct {
+	/* output */
+	const char *suffix;
+	void (*print_horiz_tri)(FILE *f, fp2t_triangle_t *t, int up, rnd_coord_t z);
+	void (*print_vert_tri)(FILE *f, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2, rnd_coord_t z0, rnd_coord_t z1);
+	void (*print_facet)(FILE *f, stl_facet_t *head, double mx[16], double mxn[16]);
+	void (*new_obj)(float r, float g, float b);
+	void (*print_header)(FILE *f);
+	void (*print_footer)(FILE *f);
+
+	/* model load */
+	const char *attr_model_name;
+	const char *attr_xlate, *attr_xlate_old;
+	const char *attr_rotate, *attr_rotate_old;
+	stl_facet_t *(*model_load)(rnd_hidlib_t *hl, FILE *f, const char *fn);
+} stl_fmt_t;
+
+static const rnd_export_opt_t *stl_get_export_options_(rnd_hid_t *hid, int *n, const stl_fmt_t *fmt)
+{
+	const char *suffix = fmt->suffix;
+	const char *val = stl_values[HA_stlfile].str;
+
+	if ((PCB != NULL) && ((val == NULL) || (*val == '\0')))
+		pcb_derive_default_filename(PCB->hidlib.filename, &stl_values[HA_stlfile], suffix);
+
+	if (n)
+		*n = NUM_OPTIONS;
+	return stl_attribute_list;
+}
+
+#include "exp_fmt_stl.c"
+#include "exp_fmt_amf.c"
+#include "exp_fmt_proj.c"
+
+static const stl_fmt_t *fmt_all[] = {&fmt_amf, &fmt_stl, &fmt_proj, NULL};
+
+#include "stl_models.c"
+#include "model_load_stl.c"
+#include "model_load_amf.c"
+
+
+static const rnd_export_opt_t *stl_get_export_options(rnd_hid_t *hid, int *n)
+{
+	return stl_get_export_options_(hid, n, &fmt_stl);
+}
+
+static const rnd_export_opt_t *amf_get_export_options(rnd_hid_t *hid, int *n)
+{
+	return stl_get_export_options_(hid, n, &fmt_amf);
+}
+
+static const rnd_export_opt_t *proj_get_export_options(rnd_hid_t *hid, int *n)
+{
+	return stl_get_export_options_(hid, n, &fmt_proj);
+}
+
+static int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t maxy, rnd_coord_t z0, rnd_coord_t z1, const stl_fmt_t *fmt)
 {
 	pcb_dynf_t df;
 	pcb_poly_t *brdpoly;
@@ -376,6 +417,7 @@ int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t max
 	long contlen;
 	rnd_vnode_t *vn;
 	rnd_pline_t *pl;
+	int first_vert = 1;
 
 	if ((pcb_layer_list(PCB, PCB_LYT_COPPER | PCB_LYT_TOP, &lid, 1) != 1) && (pcb_layer_list(PCB, PCB_LYT_COPPER | PCB_LYT_BOTTOM, &lid, 1) != 1)) {
 		rnd_message(RND_MSG_ERROR, "A top or bottom copper layer is required for stl export\n");
@@ -433,12 +475,13 @@ int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t max
 
 	fp2t_triangulate(&tri);
 
-	fprintf(f, "solid pcb\n");
+	fmt->print_header(f);
+	fmt->new_obj(0, 0.4, 0);
 
 	/* write the top and bottom plane */
 	for(n = 0; n < tri.TriangleCount; n++) {
-		stl_print_horiz_tri(f, tri.Triangles[n], 0, z0);
-		stl_print_horiz_tri(f, tri.Triangles[n], 1, z1);
+		fmt->print_horiz_tri(f, tri.Triangles[n], 0, z0);
+		fmt->print_horiz_tri(f, tri.Triangles[n], 1, z1);
 	}
 
 	/* write the vertical side */
@@ -446,7 +489,6 @@ int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t max
 		if (contours.array[cn] == HUGE_VAL) {
 			double cx, cy, px, py;
 			long n, pn;
-/*			rnd_trace("contour: %ld..%ld\n", cn_start, cn);*/
 			for(n = cn-2; n >= cn_start; n-=2) {
 				pn = n-2;
 				if (pn < cn_start)
@@ -454,17 +496,21 @@ int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t max
 				px = contours.array[pn], py = contours.array[pn+1];
 				cx = contours.array[n], cy = contours.array[n+1];
 /*				rnd_trace(" [%ld <- %ld] c:%f;%f p:%f;%f\n", n, pn, cx/1000000.0, cy/1000000.0, px/1000000.0, py/1000000.0);*/
-				stl_print_vert_tri(f, cx, cy, px, py, z0, z1);
+				if (first_vert)
+					fmt->print_vert_tri(f, cx, cy, px, py, z0, z1);
+				else
+					fmt->print_vert_tri(f, cx, cy, px, py, z1, z0);
 			}
 			cn += 2;
 			cn_start = cn;
+			first_vert = 0;
 		}
 	}
 
 	if (options[HA_models].lng)
-		stl_models_print(PCB, f, maxy, z0, z1);
+		stl_models_print(PCB, f, maxy, z0, z1, fmt);
 
-	fprintf(f, "endsolid\n");
+	fmt->print_footer(f);
 
 	vtp0_uninit(&cutouts);
 	for(n = 0; n < cutouts.used; n++)
@@ -476,7 +522,7 @@ int stl_hid_export_to_file(FILE *f, rnd_hid_attr_val_t *options, rnd_coord_t max
 	return 0;
 }
 
-static void stl_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+static void stl_do_export_(rnd_hid_t *hid, rnd_hid_attr_val_t *options, const stl_fmt_t *fmt)
 {
 	const char *filename;
 	pcb_cam_t cam;
@@ -484,7 +530,7 @@ static void stl_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	rnd_coord_t thick;
 
 	if (!options) {
-		stl_get_export_options(hid, 0);
+		stl_get_export_options_(hid, 0, fmt);
 		options = stl_values;
 	}
 
@@ -509,14 +555,29 @@ static void stl_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	}
 
 	if (options[HA_zcent].lng)
-		stl_hid_export_to_file(f, options, PCB->hidlib.size_y, -thick/2, +thick/2);
+		stl_hid_export_to_file(f, options, PCB->hidlib.size_y, -thick/2, +thick/2, fmt);
 	else
-		stl_hid_export_to_file(f, options, PCB->hidlib.size_y, 0, thick);
+		stl_hid_export_to_file(f, options, PCB->hidlib.size_y, 0, thick, fmt);
 
 	fclose(f);
 	pcb_cam_end(&cam);
 }
 
+static void stl_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+{
+	stl_do_export_(hid, options, &fmt_stl);
+}
+
+static void amf_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+{
+	stl_do_export_(hid, options, &fmt_amf);
+}
+
+static void proj_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
+{
+	stl_do_export_(hid, options, &fmt_proj);
+}
+
 static int stl_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
 	rnd_export_register_opts2(hid, stl_attribute_list, sizeof(stl_attribute_list) / sizeof(stl_attribute_list[0]), stl_cookie, 0);
@@ -539,6 +600,7 @@ void pplg_uninit_export_stl(void)
 {
 	rnd_remove_actions_by_cookie(stl_cookie);
 	rnd_hid_remove_hid(&stl_hid);
+	rnd_hid_remove_hid(&amf_hid);
 }
 
 int pplg_init_export_stl(void)
@@ -564,5 +626,25 @@ int pplg_init_export_stl(void)
 	rnd_hid_register_hid(&stl_hid);
 	rnd_hid_load_defaults(&stl_hid, stl_attribute_list, NUM_OPTIONS);
 
+
+	memcpy(&amf_hid, &stl_hid, sizeof(rnd_hid_t));
+	amf_hid.name = "amf";
+	amf_hid.description = "export board outline in 3-dimensional AMF";
+	amf_hid.get_export_options = amf_get_export_options;
+	amf_hid.do_export = amf_do_export;
+
+	rnd_hid_register_hid(&amf_hid);
+	rnd_hid_load_defaults(&amf_hid, stl_attribute_list, NUM_OPTIONS);
+
+
+	memcpy(&proj_hid, &stl_hid, sizeof(rnd_hid_t));
+	proj_hid.name = "projector";
+	proj_hid.description = "export board outline as a projector(1) object for 3d rendering";
+	proj_hid.get_export_options = proj_get_export_options;
+	proj_hid.do_export = proj_do_export;
+
+	rnd_hid_register_hid(&proj_hid);
+	rnd_hid_load_defaults(&proj_hid, stl_attribute_list, NUM_OPTIONS);
+
 	return 0;
 }
