@@ -24,13 +24,13 @@
 
 const char *export_vfs_mc_cookie = "export_vfs_mc HID";
 
-static rnd_export_opt_t export_vfs_mc_options[] = {
+static const rnd_export_opt_t export_vfs_mc_options[] = {
 	{"cmd", "mc command",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_export_vfs_mc_cmd 0
 
 	{"qpath", "query path",
-	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_export_vfs_mc_qpath 1
 };
 
@@ -38,7 +38,7 @@ static rnd_export_opt_t export_vfs_mc_options[] = {
 
 static rnd_hid_attr_val_t export_vfs_mc_values[NUM_OPTIONS];
 
-static rnd_export_opt_t *export_vfs_mc_get_export_options(rnd_hid_t *hid, int *n)
+static const rnd_export_opt_t *export_vfs_mc_get_export_options(rnd_hid_t *hid, int *n)
 {
 	if (n)
 		*n = NUM_OPTIONS;
@@ -168,5 +168,7 @@ int pplg_init_export_vfs_mc(void)
 	export_vfs_mc_hid.usage = export_vfs_mc_usage;
 
 	rnd_hid_register_hid(&export_vfs_mc_hid);
+	rnd_hid_load_defaults(&export_vfs_mc_hid, export_vfs_mc_options, NUM_OPTIONS);
+
 	return 0;
 }
