@@ -1,12 +1,12 @@
 #ifndef PCB_VENDOR_CONF_H
 #define PCB_VENDOR_CONF_H
 
-#include "conf.h"
+#include <librnd/core/conf.h>
 
 typedef struct {
 	const struct {
 		const struct {
-			CFT_LIST templates;
+			RND_CFT_LIST templates;
 		} export_xy;
 	} plugins;
 } conf_xy_t;
