@@ -300,7 +300,7 @@ fgw_error_t pcb_act_LoadLtspiceFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadLtspiceFrom, fname = argv[1].val.str);
 
 	if (!fname || !*fname) {
-		fname = rnd_gui->fileselect(rnd_gui, "Load ltspice net+asc file pair...",
+		fname = rnd_hid_fileselect(rnd_gui, "Load ltspice net+asc file pair...",
 																"Picks a ltspice mentor net or asc file to load.\n",
 																default_file, ".asc", NULL, "ltspice", RND_HID_FSD_READ, NULL);
 		if (fname == NULL)
@@ -336,7 +336,7 @@ static int ltspice_support_prio(pcb_plug_import_t *ctx, unsigned int aspects, co
 		return 0; /* only pure netlist import is supported */
 
 	gen_filenames(args[0], &fname_net, &fname_asc);
-	if (!rnd_file_readable(fname_net))
+	if (!rnd_file_readable(&PCB->hidlib, fname_net))
 		goto quit;
 
 	f = rnd_fopen(&PCB->hidlib, fname_asc, "r");
