@@ -37,6 +37,7 @@
 #include "conf_core.h"
 #include <librnd/core/error.h>
 #include "data.h"
+#include "undo.h"
 #include "rats_patch.h"
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/paths.h>
@@ -134,7 +135,7 @@ static int ReadNetlist(const char *filename)
 			else {
 				if (kind == 1 && strchr(temp, '-') == NULL) {
 					kind++;
-					rnd_attribute_put(&net->Attributes, "style", temp);
+					pcb_attribute_put(&net->Attributes, "style", temp);
 				}
 				else {
 					pcb_net_term_get_by_pinname(net, temp, PCB_NETA_ALLOC);
@@ -169,11 +170,18 @@ static int netlist_support_prio(pcb_plug_import_t *ctx, unsigned int aspects, co
 
 static int netlist_import(pcb_plug_import_t *ctx, unsigned int aspects, const char **fns, int numfns)
 {
+	int res;
 	if (numfns != 1) {
 		rnd_message(RND_MSG_ERROR, "import_netlist: requires exactly 1 input file name\n");
 		return -1;
 	}
-	return ReadNetlist(fns[0]);
+
+	pcb_undo_freeze_serial();
+	res = ReadNetlist(fns[0]);
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
+
+	return res;
 }
 
 int pplg_check_ver_import_netlist(int ver_needed) { return 0; }
