@@ -187,7 +187,7 @@ fgw_error_t pcb_act_LoadtinycadFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadtinycadFrom, fname = argv[1].val.str);
 
 	if (!fname || !*fname) {
-		fname = rnd_gui->fileselect(rnd_gui, "Load tinycad netlist file...",
+		fname = rnd_hid_fileselect(rnd_gui, "Load tinycad netlist file...",
 																"Picks a tinycad netlist file to load.\n",
 																default_file, ".net", NULL, "tinycad", RND_HID_FSD_READ, NULL);
 		if (fname == NULL)
