@@ -32,17 +32,17 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "plug_io.h"
 #include "write.h"
 #include "read.h"
-#include "actions.h"
+#include <librnd/core/actions.h>
 
 #include "board.h"
 #include "conf_core.h"
 #include "buffer.h"
-#include "hid.h"
-#include "compat_misc.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/compat_misc.h>
 
 static pcb_plug_io_t io_autotrax;
 static const char *autotrax_cookie = "autotrax IO";
@@ -67,19 +67,20 @@ int pplg_check_ver_io_autotrax(int ver_needed) { return 0; }
 
 void pplg_uninit_io_autotrax(void)
 {
-	pcb_remove_actions_by_cookie(autotrax_cookie);
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_autotrax);
+	rnd_remove_actions_by_cookie(autotrax_cookie);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_autotrax);
 }
 
 int pplg_init_io_autotrax(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	io_autotrax.plugin_data = NULL;
 	io_autotrax.fmt_support_prio = io_autotrax_fmt;
 	io_autotrax.test_parse = io_autotrax_test_parse;
 	io_autotrax.parse_pcb = io_autotrax_read_pcb;
 	io_autotrax.parse_footprint = NULL;
+	io_autotrax.map_footprint = NULL;
 	io_autotrax.parse_font = NULL;
 	io_autotrax.write_buffer = NULL;
 	io_autotrax.write_pcb = io_autotrax_write_pcb;
@@ -90,7 +91,7 @@ int pplg_init_io_autotrax(void)
 	io_autotrax.fp_extension = ".PCB";
 	io_autotrax.mime_type = "application/x-autotrax-pcb";
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_autotrax);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_autotrax);
 
 	return 0;
 }
