@@ -903,6 +903,7 @@ static int eagle_read_wire(read_state_t * st, trnode_t * subtree, void *obj, int
 }
 
 typedef enum {
+	EAGLE_PSH_NONE,    /* for holes */
 	EAGLE_PSH_SQUARE,
 	EAGLE_PSH_ROUND,
 	EAGLE_PSH_OCTAGON,
@@ -923,6 +924,9 @@ TODO("{clearance} need to establish how paste clearance, if any, is defined and
 	rnd_coord_t paste_gap = 0;
 
 	switch (shape) {
+		case EAGLE_PSH_NONE:
+			shapes[0].layer_mask = 0;
+			break;
 		case EAGLE_PSH_SQUARE:
 			shapes[0].layer_mask = PCB_LYT_TOP | PCB_LYT_MASK;
 			shapes[0].comb = PCB_LYC_SUB | PCB_LYC_AUTO;
@@ -1091,7 +1095,7 @@ TODO("{clearance} this should be coming from the eagle file")
 	return 0;
 }
 
-static int eagle_read_pad_or_hole(read_state_t *st, trnode_t *subtree, void *obj, int type, int hole)
+static int eagle_read_pad_or_hole(read_state_t *st, trnode_t *subtree, void *obj, int type, int is_hole)
 {
 	eagle_loc_t loc = type;
 	rnd_coord_t x, y, drill, diax, diay, clr, mask;
@@ -1100,7 +1104,7 @@ static int eagle_read_pad_or_hole(read_state_t *st, trnode_t *subtree, void *obj
 	pcb_data_t *data;
 	eagle_pstk_shape_t sh = EAGLE_PSH_ROUND; /* if nothing is said, round is used by eagle */
 	int roundness = 0;
-	int rot = 0, onbottom = 0, plated = 1;
+	int rot = 0, onbottom = 0, plated = is_hole ? 0 : 1;
 
 	switch(loc) {
 		case IN_SUBC:
@@ -1116,7 +1120,8 @@ static int eagle_read_pad_or_hole(read_state_t *st, trnode_t *subtree, void *obj
 	y = eagle_get_attrc(st, subtree, "y", 0);
 	drill = eagle_get_attrc(st, subtree, "drill", 0);
 	diax = eagle_get_attrc(st, subtree, "diameter", drill * (1.0+st->rv_pad_top*2.0));
-	shape = eagle_get_attrs(st, subtree, "shape", 0);
+	if (!is_hole)
+		shape = eagle_get_attrs(st, subtree, "shape", 0);
 
 	clr = conf_core.design.clearance; /* eagle doesn't seem to support per via clearance */
 	mask = (loc == IN_SUBC) ? conf_core.design.clearance : 0; /* board vias don't have mask */
@@ -1128,7 +1133,9 @@ static int eagle_read_pad_or_hole(read_state_t *st, trnode_t *subtree, void *obj
 	TODO("{plating} check how to determine plated");
 	TODO("bin: test the binary numbers for offset and long: shape = {square, round, octagon, long, offset} binary");
 	diay = diax;
-	if (shape != NULL) {
+	if (is_hole)
+		sh = EAGLE_PSH_NONE;
+	else if (shape != NULL) {
 		if ((strcmp(shape, "octagon") == 0) || (strcmp(shape, "2") == 0))
 			sh = EAGLE_PSH_OCTAGON;
 		else if ((strcmp(shape, "square") == 0) || (strcmp(shape, "0") == 0))
@@ -1796,7 +1803,7 @@ static int eagle_read_design_rules(read_state_t *st)
 			else if (strcmp(name, "rvPadInner") == 0) st->rv_pad_inner = eagle_get_attrd(st, n, "value", 0);
 			else if (strcmp(name, "rvPadBottom") == 0) st->rv_pad_bottom = eagle_get_attrd(st, n, "value", 0);
 		}
-		if ((st->rv_pad_top != st->rv_pad_inner) || (st->rv_pad_top != st->rv_pad_inner))
+		if ((st->rv_pad_top != st->rv_pad_inner) || (st->rv_pad_bottom != st->rv_pad_inner))
 			rnd_message(RND_MSG_WARNING, "top/inner/bottom default pad sizes differ - using top size only\n");
 	}
 	return 0;
@@ -2131,6 +2138,16 @@ static int io_eagle_parse_footprint_any(read_state_t *st, pcb_plug_io_t *ctx, pc
 	if (npkg != NULL)
 		res = eagle_read_package(st, npkg);
 
+	if (res == 0) {
+		pcb_subc_t *subc = st->fp_parent_data->subc.lst.first;
+		if (subc != NULL) {
+			pcb_undo_freeze_add();
+			pcb_data_mirror(st->fp_data, -PCB->hidlib.size_y, PCB_TXM_COORD | PCB_TXM_ROT, 0, 0);
+			pcb_undo_unfreeze_add();
+			pcb_subc_create_aux(subc, 0, 0, 0, 0);
+		}
+	}
+
 	error:;
 	st_uninit(st);
 	return res;
