@@ -82,7 +82,7 @@ fgw_error_t pcb_act_LoadhypFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadhypFrom, fname = argv[1].val.str);
 
 	if ((fname == NULL) || (*fname == '\0')) {
-		fname = rnd_gui->fileselect(rnd_gui,
+		fname = rnd_hid_fileselect(rnd_gui,
 			"Load .hyp file...", "Picks a hyperlynx file to load.\n", "default.hyp",
 			".hyp", NULL, "hyp", RND_HID_FSD_READ, NULL);
 	}
