@@ -28,7 +28,7 @@
  */
 
 #include "config.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "plug_io.h"
 #include "write.h"
 
@@ -52,18 +52,19 @@ int pplg_check_ver_io_kicad_legacy(int ver_needed) { return 0; }
 void pplg_uninit_io_kicad_legacy(void)
 {
 	/* Runs once when the plugin is unloaded. TODO: free plugin-globals here. */
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_kicad_legacy);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_kicad_legacy);
 }
 
 int pplg_init_io_kicad_legacy(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	/* register the IO hook */
 	io_kicad_legacy.plugin_data = NULL;
 	io_kicad_legacy.fmt_support_prio = io_kicad_legacy_fmt;
 	io_kicad_legacy.parse_pcb = NULL;
 	io_kicad_legacy.parse_footprint = NULL;
+	io_kicad_legacy.map_footprint = NULL;
 	io_kicad_legacy.parse_font = NULL;
 	io_kicad_legacy.write_buffer = NULL;
 	io_kicad_legacy.write_subcs_head = io_kicad_legacy_write_subcs_head;
@@ -78,7 +79,7 @@ int pplg_init_io_kicad_legacy(void)
 	io_kicad_legacy.mime_type = "application/x-kicad-pcbnew";
 
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_kicad_legacy);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_kicad_legacy);
 
 	/* TODO: Alloc plugin-globals here. */
 
