@@ -107,8 +107,9 @@ int pplg_init_io_lihata(void)
 	plug_io_lihata_v7.default_fmt = "lihata";
 	plug_io_lihata_v7.description = "lihata board v7";
 	plug_io_lihata_v7.save_preference_prio = 198;
-	plug_io_lihata_v7.default_extension = ".lht";
-	plug_io_lihata_v7.fp_extension = ".lht";
+	plug_io_lihata_v7.default_extension = ".rp";
+	plug_io_lihata_v7.alternate_extension = ".lht";
+	plug_io_lihata_v7.fp_extension = ".rf";
 	plug_io_lihata_v7.mime_type = "application/x-pcbrnd-board";
 	plug_io_lihata_v7.save_as_subd_init = io_lihata_save_as_subd_init;
 	plug_io_lihata_v7.save_as_subd_uninit = io_lihata_save_as_subd_uninit;
