@@ -30,7 +30,7 @@
 extern conf_io_lihata_t conf_io_lihata;
 extern pcb_plug_io_t plug_io_lihata_v1, plug_io_lihata_v2, plug_io_lihata_v3,
                      plug_io_lihata_v4, plug_io_lihata_v5, plug_io_lihata_v6,
-                     plug_io_lihata_v7;
+                     plug_io_lihata_v7, plug_io_lihata_v8;
 
 /* The one extedit and other code should cross-call */
 extern pcb_plug_io_t *plug_io_lihata_default;
