@@ -37,6 +37,7 @@
 #include "config.h"
 #include "board.h"
 #include "data.h"
+#include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
 #include "plug_io.h"
 #include "flag_str.h"
@@ -457,6 +458,11 @@ static int parse_meta(lht_read_t *rctx, pcb_board_t *pcb, lht_node_t *nd)
 		err |= parse_coord(&pcb->hidlib.size_y, hash_get(grp, "y", 0));
 		err |= parse_coord_conf(rctx, "design/poly_isle_area", hash_get(grp, "isle_area_nm2", 1));
 		err |= parse_double(&pcb->ThermScale, hash_get(grp, "thermal_scale", 1));
+		if (pcb->ThermScale < 0.01) {
+			lht_node_t *ts = hash_get(grp, "thermal_scale", 1);
+			if (ts != NULL)
+				iolht_error(ts, "Your thermal_scale is too small. This will probably cause problems in calculating thermals.\n");
+		}
 		if (err != 0)
 			return -1;
 	}
@@ -2150,104 +2156,18 @@ static pcb_data_t *parse_data(lht_read_t *rctx, pcb_board_t *pcb, pcb_data_t *ds
 	return dt;
 }
 
-static int parse_symbol(pcb_symbol_t *sym, lht_node_t *nd)
-{
-	lht_node_t *grp, *obj, *n;
-	lht_dom_iterator_t it;
-	int err = 0;
 
-	err |= parse_coord(&sym->Width,  hash_get(nd, "width", 0));
-	err |= parse_coord(&sym->Height, hash_get(nd, "height", 0));
-	err |= parse_coord(&sym->Delta,  hash_get(nd, "delta", 0));
+#define PARSE_COORD(dst, src)       parse_coord(dst, src)
+#define PARSE_DOUBLE(dst, src)      parse_double(dst, src)
+#define HASH_GET(hash, name)        hash_get(hash, name, 0)
+#define LHT_ERROR                   iolht_error
 
-	grp = lht_dom_hash_get(nd, "objects");
-	for(obj = lht_dom_first(&it, grp); obj != NULL; obj = lht_dom_next(&it)) {
-		rnd_coord_t x1, y1, x2, y2, th, r;
-		double sa, da;
+#include <rnd_inclib/font/font_lht.h>
 
-		if (strncmp(obj->name, "line.", 5) == 0) {
-			err |= parse_coord(&x1, hash_get(obj, "x1", 0));
-			err |= parse_coord(&y1, hash_get(obj, "y1", 0));
-			err |= parse_coord(&x2, hash_get(obj, "x2", 0));
-			err |= parse_coord(&y2, hash_get(obj, "y2", 0));
-			err |= parse_coord(&th, hash_get(obj, "thickness", 0));
-			if (err != 0)
-				return -1;
-			pcb_font_new_line_in_sym(sym, x1, y1, x2, y2, th);
-		}
-		else if (strncmp(obj->name, "simplearc.", 10) == 0) {
-			err |= parse_coord(&x1,  hash_get(obj, "x", 0));
-			err |= parse_coord(&y1,  hash_get(obj, "y", 0));
-			err |= parse_coord(&r,   hash_get(obj, "r", 0));
-			err |= parse_coord(&th,  hash_get(obj, "thickness", 0));
-			err |= parse_double(&sa, hash_get(obj, "astart", 0));
-			err |= parse_double(&da, hash_get(obj, "adelta", 0));
-			if (err != 0)
-				return -1;
-			pcb_font_new_arc_in_sym(sym, x1, y1, r, sa, da, th);
-		}
-		else if (strncmp(obj->name, "simplepoly.", 11) == 0) {
-			int len;
-			pcb_poly_t *sp;
-			if (obj->type != LHT_LIST) {
-				iolht_error(obj, "Symbol error: simplepoly is not a list! (ignoring this poly)\n");
-				continue;
-			}
-			for(len = 0, n = obj->data.list.first; n != NULL; len++, n = n->next) ;
-			if ((len % 2 != 0) || (len < 6)) {
-				iolht_error(obj, "Symbol error: sumplepoly has wrong number of points (%d, expected an even integer >= 6)! (ignoring this poly)\n", len);
-				continue;
-			}
-			sp = pcb_font_new_poly_in_sym(sym, len/2);
-			for(len = 0, n = obj->data.list.first; n != NULL; len++, n = n->next) {
-				parse_coord(&x1, n);
-				n = n->next;
-				parse_coord(&y1, n);
-				sp->Points[len].X = x1;
-				sp->Points[len].Y = y1;
-			}
-		}
-	}
-
-	sym->Valid = 1;
-	return 0;
-}
-
-static int parse_font(pcb_font_t *font, lht_node_t *nd)
-{
-	lht_node_t *grp, *sym;
-	lht_dom_iterator_t it;
-	int err = 0;
-
-	if (nd->type != LHT_HASH)
-		return iolht_error(nd, "font must be a hash\n");
-
-	err |= parse_coord(&font->MaxHeight, hash_get(nd, "cell_height", 0));
-	err |= parse_coord(&font->MaxWidth,  hash_get(nd, "cell_width", 0));
-
-	grp = lht_dom_hash_get(nd, "symbols");
-
-	for(sym = lht_dom_first(&it, grp); sym != NULL; sym = lht_dom_next(&it)) {
-		int chr;
-		if (sym->type != LHT_HASH)
-			continue;
-		if (*sym->name == '&') {
-			char *end;
-			chr = strtol(sym->name+1, &end, 16);
-			if (*end != '\0') {
-				iolht_error(sym, "Ignoring symbol with invalid symbol name '%s'.\n", sym->name);
-				continue;
-			}
-		}
-		else
-			chr = *sym->name;
-		if ((chr >= 0) && (chr < sizeof(font->Symbol) / sizeof(font->Symbol[0]))) {
-			parse_symbol(font->Symbol+chr, sym);
-		}
-	}
-
-	return err;
-}
+#undef PARSE_COORD
+#undef PARSE_DOUBLE
+#undef PARSE_HASH_GET
+#undef LHT_ERROR
 
 static int parse_fontkit(pcb_fontkit_t *fk, lht_node_t *nd)
 {
@@ -2260,7 +2180,7 @@ static int parse_fontkit(pcb_fontkit_t *fk, lht_node_t *nd)
 	pcb_fontkit_reset (fk);
 
 	for(n = lht_dom_first(&it, nd); n != NULL; n = lht_dom_next(&it)) {
-		pcb_font_t *f;
+		rnd_font_t *f;
 
 		if (strcmp(n->name, "geda_pcb") != 0) {
 			char *end;
@@ -2272,12 +2192,12 @@ static int parse_fontkit(pcb_fontkit_t *fk, lht_node_t *nd)
 				return iolht_error(nd, "Failed to allocate font id %d (name '%s').\n", id, n->name);
 		}
 		else {
-			pcb_font_free (&fk->dflt);
+			rnd_font_free(&fk->dflt);
 			fk->dflt.id = 0; /* restore default font's ID */
 			f = &fk->dflt;
 		}
 
-		if (parse_font(f, n) != 0)
+		if (rnd_font_lht_parse_font(f, n) != 0)
 			return -1;
 	}
 
@@ -2491,7 +2411,7 @@ static int parse_netlist_patch(pcb_board_t *pcb, lht_node_t *patches)
 		else if (strcmp(np->name, "change_attrib") == 0) {
 			nkey = lht_dom_hash_get(np, "key");
 			if ((nkey == NULL) || (nkey->type != LHT_TEXT) || (*nkey->data.text.value == '\0'))
-				return iolht_error(nval, "netlist patch attrib key must be a non-empty string (change_attrib)\n");
+				return iolht_error(nkey, "netlist patch attrib key must be a non-empty string (change_attrib)\n");
 			nval = lht_dom_hash_get(np, "val");
 			if ((nval == NULL) || (nval->type != LHT_TEXT))
 				return iolht_error(nval, "netlist patch attrib value must be a non-empty string (change_attrib)\n");
@@ -2692,6 +2612,21 @@ int io_lihata_parse_pcb(pcb_plug_io_t *ctx, pcb_board_t *Ptr, const char *Filena
 			pcb_data_clip_polys(sc->data);
 		}
 	}
+	else if ((doc->root->type == LHT_LIST) && (strncmp(doc->root->name, "pcb-rnd-font-v", 14) == 0)) {
+		res = 0;
+		if (rnd_actionva(&Ptr->hidlib, "loadfontfrom", Filename, "1", NULL) != 0) {
+			rnd_message(RND_MSG_ERROR, "io_lihata: failed to load font file '%s' for editing\n", Filename);
+			res = -1;
+		}
+		else {
+			rnd_conf_set(RND_CFR_DESIGN, "design/text_font_id", 0, "1", RND_POL_OVERWRITE);
+			if (rnd_actionva(&Ptr->hidlib, "fontedit", "inplace", NULL) != 0) {
+				rnd_message(RND_MSG_ERROR, "io_lihata: failed to start the font editor\n");
+				res = -1;
+			}
+		}
+
+	}
 	else {
 		iolht_error(doc->root, "Error loading '%s': neither a board nor a subcircuit\n", Filename);
 		res = -1;
@@ -2806,6 +2741,8 @@ void test_parse_ev(lht_parse_t *ctx, lht_event_t ev, lht_node_type_t nt, const c
 			*state = TPS_GOOD;
 		else if ((nt == LHT_LIST) && (strncmp(name, "pcb-rnd-subcircuit-v", 20) == 0))
 			*state = TPS_GOOD;
+		else if ((nt == LHT_LIST) && (strncmp(name, "pcb-rnd-font-v", 14) == 0))
+			*state = TPS_GOOD;
 		else if ((nt == LHT_HASH) && (strncmp(name, "pcb-rnd-padstack-v", 18) == 0))
 			*state = TPS_GOOD;
 		else
@@ -2844,7 +2781,7 @@ int io_lihata_test_parse(pcb_plug_io_t *plug_ctx, pcb_plug_iot_t typ, const char
 	return (state == TPS_GOOD);
 }
 
-int io_lihata_parse_font(pcb_plug_io_t *ctx, pcb_font_t *Ptr, const char *Filename)
+int io_lihata_parse_font(pcb_plug_io_t *ctx, rnd_font_t *Ptr, const char *Filename)
 {
 	int res;
 	char *errmsg = NULL, *realfn;
@@ -2867,8 +2804,10 @@ int io_lihata_parse_font(pcb_plug_io_t *ctx, pcb_font_t *Ptr, const char *Filena
 			rnd_message(RND_MSG_ERROR, "Not a font lihata.\n");
 		res = -1;
 	}
-	else
-		res = parse_font(Ptr, doc->root->data.list.first);
+	else {
+		TODO("font: remove this whole function and call rnd_font_load(Ptr, Filanem, pcb_io_err_inhibit) instead");
+		res = rnd_font_lht_parse_font(Ptr, doc->root->data.list.first);
+	}
 
 	free(errmsg);
 	lht_dom_uninit(doc);
