@@ -364,42 +364,6 @@ static lht_node_t *build_line(pcb_line_t *line, int local_id, rnd_coord_t dx, rn
 	return obj;
 }
 
-static lht_node_t *build_simplearc(pcb_arc_t *arc, int local_id)
-{
-	char buff[128];
-	lht_node_t *obj;
-
-	sprintf(buff, "simplearc.%ld", (local_id >= 0 ? local_id : arc->ID));
-	obj = lht_dom_node_alloc(LHT_HASH, buff);
-	lht_dom_hash_put(obj, build_textf("x", CFMT, arc->X));
-	lht_dom_hash_put(obj, build_textf("y", CFMT, arc->Y));
-	lht_dom_hash_put(obj, build_textf("r", CFMT, arc->Height));
-	lht_dom_hash_put(obj, build_textf("astart", "%f", arc->StartAngle));
-	lht_dom_hash_put(obj, build_textf("adelta", "%f", arc->Delta));
-	lht_dom_hash_put(obj, build_textf("thickness", CFMT, arc->Thickness));
-
-	return obj;
-}
-
-
-static lht_node_t *build_simplepoly(pcb_poly_t *poly, int local_id)
-{
-	char buff[128];
-	lht_node_t *obj;
-	rnd_point_t *pnt;
-	int n;
-
-	sprintf(buff, "simplepoly.%ld", (local_id >= 0 ? local_id : poly->ID));
-	obj = lht_dom_node_alloc(LHT_LIST, buff);
-
-	for(n = 0, pnt = poly->Points; n < poly->PointN; n++,pnt++) {
-		lht_dom_list_append(obj, build_textf(NULL, CFMT, pnt->X));
-		lht_dom_list_append(obj, build_textf(NULL, CFMT, pnt->Y));
-	}
-	return obj;
-}
-
-
 static lht_node_t *build_rat(pcb_rat_t *rat)
 {
 	char buff[128];
@@ -1395,34 +1359,83 @@ static lht_node_t *build_data(pcb_data_t *data)
 	return ndt;
 }
 
-static lht_node_t *build_symbol(pcb_symbol_t *sym, const char *name)
+static lht_node_t *build_glyph_line(rnd_glyph_line_t *line, long local_id)
+{
+	char buff[128];
+	lht_node_t *obj;
+
+	sprintf(buff, "line.%ld", local_id);
+	obj = lht_dom_node_alloc(LHT_HASH, buff);
+
+	lht_dom_hash_put(obj, build_textf("thickness", CFMT, line->thickness));
+	lht_dom_hash_put(obj, build_textf("x1", CFMT, line->x1));
+	lht_dom_hash_put(obj, build_textf("y1", CFMT, line->y1));
+	lht_dom_hash_put(obj, build_textf("x2", CFMT, line->x2));
+	lht_dom_hash_put(obj, build_textf("y2", CFMT, line->y2));
+
+	return obj;
+}
+
+static lht_node_t *build_glyph_arc(rnd_glyph_arc_t *arc, long local_id)
+{
+	char buff[128];
+	lht_node_t *obj;
+
+	sprintf(buff, "simplearc.%ld", local_id);
+	obj = lht_dom_node_alloc(LHT_HASH, buff);
+	lht_dom_hash_put(obj, build_textf("x", CFMT, arc->cx));
+	lht_dom_hash_put(obj, build_textf("y", CFMT, arc->cy));
+	lht_dom_hash_put(obj, build_textf("r", CFMT, arc->r));
+	lht_dom_hash_put(obj, build_textf("astart", "%f", arc->start));
+	lht_dom_hash_put(obj, build_textf("adelta", "%f", arc->delta));
+	lht_dom_hash_put(obj, build_textf("thickness", CFMT, arc->thickness));
+
+	return obj;
+}
+
+static lht_node_t *build_glyph_poly(rnd_glyph_poly_t *poly, long local_id)
+{
+	char buff[128];
+	lht_node_t *obj;
+	int n, h = poly->pts.used/2;
+	rnd_coord_t *px, *py;
+
+	sprintf(buff, "simplepoly.%ld", local_id);
+	obj = lht_dom_node_alloc(LHT_LIST, buff);
+
+	for(n = 0, px = &poly->pts.array[0], py = &poly->pts.array[h]; n < h; n++,px++,py++) {
+		lht_dom_list_append(obj, build_textf(NULL, CFMT, *px));
+		lht_dom_list_append(obj, build_textf(NULL, CFMT, *py));
+	}
+	return obj;
+}
+
+
+static lht_node_t *build_glyph(rnd_glyph_t *g, const char *name)
 {
 	lht_node_t *lst, *ndt;
-	pcb_line_t *li;
-	pcb_poly_t *poly;
-	pcb_arc_t *arc;
+	rnd_glyph_atom_t *a;
 	int n;
 
 	ndt = lht_dom_node_alloc(LHT_HASH, name);
-	lht_dom_hash_put(ndt, build_textf("width", CFMT, sym->Width));
-	lht_dom_hash_put(ndt, build_textf("height", CFMT, sym->Height));
-	lht_dom_hash_put(ndt, build_textf("delta", CFMT, sym->Delta));
+	lht_dom_hash_put(ndt, build_textf("width", CFMT, g->width));
+	lht_dom_hash_put(ndt, build_textf("height", CFMT, g->height));
+	lht_dom_hash_put(ndt, build_textf("delta", CFMT, g->xdelta));
 
 	lst = lht_dom_node_alloc(LHT_LIST, "objects");
 	lht_dom_hash_put(ndt, lst);
-	for(n = 0, li = sym->Line; n < sym->LineN; n++, li++)
-		lht_dom_list_append(lst, build_line(li, n, 0, 0, 1));
-
-	for(arc = arclist_first(&sym->arcs); arc != NULL; arc = arclist_next(arc), n++)
-		lht_dom_list_append(lst, build_simplearc(arc, n));
-
-	for(poly = polylist_first(&sym->polys); poly != NULL; poly = polylist_next(poly), n++)
-		lht_dom_list_append(lst, build_simplepoly(poly, n));
+	for(n = 0, a = g->atoms.array; n < g->atoms.used; n++,a++) {
+		switch(a->type) {
+			case RND_GLYPH_LINE: lht_dom_list_append(lst, build_glyph_line(&a->line, n)); break;
+			case RND_GLYPH_ARC:  lht_dom_list_append(lst, build_glyph_arc(&a->arc, n)); break;
+			case RND_GLYPH_POLY: lht_dom_list_append(lst, build_glyph_poly(&a->poly, n)); break;
+		}
+	}
 
 	return ndt;
 }
 
-static lht_node_t *build_font(pcb_font_t *font)
+static lht_node_t *build_font_rnd(rnd_font_t *font)
 {
 	lht_node_t *syms, *ndt;
 	char *sid, sidbuff[64];
@@ -1437,32 +1450,39 @@ static lht_node_t *build_font(pcb_font_t *font)
 
 	ndt = lht_dom_node_alloc(LHT_HASH, sid);
 
-	lht_dom_hash_put(ndt, build_textf("cell_height", CFMT, font->MaxHeight));
-	lht_dom_hash_put(ndt, build_textf("cell_width", CFMT, font->MaxWidth));
+	lht_dom_hash_put(ndt, build_textf("cell_height", CFMT, font->max_height));
+	lht_dom_hash_put(ndt, build_textf("cell_width", CFMT, font->max_width));
 	lht_dom_hash_put(ndt, build_textf("id", "%ld", font->id));
 	if (font->name != NULL)
 		lht_dom_hash_put(ndt, build_text("name", font->name));
-/*	lht_dom_hash_put(ndt, build_symbol(&font->DefaultSymbol)); */
-
 
 	syms = lht_dom_node_alloc(LHT_HASH, "symbols");
 	lht_dom_hash_put(ndt, syms);
-	for(n = 0; n < PCB_MAX_FONTPOSITION + 1; n++) {
+	for(n = 0; n < RND_FONT_MAX_GLYPHS + 1; n++) {
 		char sname[32];
-		if (!font->Symbol[n].Valid)
+		if (!font->glyph[n].valid)
 			continue;
-		if ((n <= 32) || (n > 126) || (n == '&') || (n == '#') || (n == '{') || (n == '}') || (n == '/') || (n == ':') || (n == ';') || (n == '=') || (n == '\\') || (n == ':')) {
+		if ((n <= 32) || (n > 126) || (n == '&') || (n == '#') || (n == '{') || (n == '}') || (n == '/') || (n == ':') || (n == ';') || (n == '=') || (n == '\\')) {
 			sprintf(sname, "&%02x", n);
 		}
 		else {
 			sname[0] = n;
 			sname[1] = '\0';
 		}
-		lht_dom_hash_put(syms, build_symbol(&font->Symbol[n], sname));
+		lht_dom_hash_put(syms, build_glyph(&font->glyph[n], sname));
 	}
+
 	return ndt;
 }
 
+#include "brave.h"
+
+static lht_node_t *build_font(rnd_font_t *font)
+{
+	return build_font_rnd(font);
+}
+
+
 static lht_node_t *build_fontkit(pcb_fontkit_t *fk)
 {
 	lht_node_t *ndt, *frt;
@@ -1932,7 +1952,7 @@ int io_lihata_write_pcb_v8(pcb_plug_io_t *ctx, FILE * FP, const char *old_filena
 	return io_lihata_write_pcb(ctx, FP, old_filename, new_filename, emergency, 8);
 }
 
-int io_lihata_write_font(pcb_plug_io_t *ctx, pcb_font_t *font, const char *Filename)
+int io_lihata_write_font(pcb_plug_io_t *ctx, rnd_font_t *font, const char *Filename)
 {
 	FILE *f;
 	int res;
@@ -2104,7 +2124,7 @@ void *io_lihata_save_as_subd_init(const pcb_plug_io_t *ctx, rnd_hid_dad_subdialo
 {
 	io_lihata_save_t *save = calloc(sizeof(io_lihata_save_t), 1);
 
-	if (type == PCB_IOT_PCB) {
+	if (type & PCB_IOT_PCB) {
 		RND_DAD_BEGIN_HBOX(sub->dlg);
 			RND_DAD_BEGIN_VBOX(sub->dlg); /* left column */
 				RND_DAD_BEGIN_HBOX(sub->dlg);
