@@ -324,30 +324,51 @@ static void WritePCBDataHeader(FILE * FP)
 	}
 }
 
-/* writes font data of non empty symbols */
-static void WritePCBFontData(FILE * FP)
+static void WritePCBFontData_rnd(FILE * FP)
 {
 	rnd_cardinal_t i, j;
-	pcb_line_t *line;
-	pcb_font_t *font;
+	rnd_font_t *font = pcb_font(PCB, 0, 1);
+	int warned = 0;
 
-	for (font = pcb_font(PCB, 0, 1), i = 0; i <= PCB_MAX_FONTPOSITION; i++) {
-		if (!font->Symbol[i].Valid)
+	if (PCB->fontkit.fonts.used > 0)
+		pcb_io_incompat_save(PCB->Data, NULL, "font", "Can't save multiple fonts", "Only the default font is saved, all text objecst will use the default font.");
+
+	for(i = 0; i <= RND_FONT_MAX_GLYPHS; i++) {
+		rnd_glyph_atom_t *a;
+
+		if (!font->glyph[i].valid)
 			continue;
 
 		if (isprint(i))
-			rnd_fprintf(FP, "Symbol['%c' %[0]]\n(\n", i, font->Symbol[i].Delta);
+			rnd_fprintf(FP, "Symbol['%c' %[0]]\n(\n", i, font->glyph[i].xdelta);
 		else
-			rnd_fprintf(FP, "Symbol[%i %[0]]\n(\n", i, font->Symbol[i].Delta);
+			rnd_fprintf(FP, "Symbol[%i %[0]]\n(\n", i, font->glyph[i].xdelta);
 
-		line = font->Symbol[i].Line;
-		for (j = font->Symbol[i].LineN; j; j--, line++)
-			rnd_fprintf(FP, "\tSymbolLine[%[0] %[0] %[0] %[0] %[0]]\n",
-									line->Point1.X, line->Point1.Y, line->Point2.X, line->Point2.Y, line->Thickness);
+		for(a = font->glyph[i].atoms.array, j = font->glyph[i].atoms.used; j; j--, a++) {
+			switch(a->type) {
+				case RND_GLYPH_LINE:
+					rnd_fprintf(FP, "\tSymbolLine[%[0] %[0] %[0] %[0] %[0]]\n",
+						a->line.x1, a->line.y1, a->line.x2, a->line.y2, a->line.thickness);
+					break;
+				default:
+					if (!warned) {
+						pcb_io_incompat_save(PCB->Data, NULL, "font", "Font glyph contain non-line atoms in default font", "Use a line-only default font");
+						warned = 1;
+					}
+			}
+		}
 		fputs(")\n", FP);
 	}
 }
 
+#include "brave.h"
+
+static void WritePCBFontData(FILE *FP)
+{
+	WritePCBFontData_rnd(FP);
+}
+
+
 static void WriteViaData(FILE * FP, pcb_data_t *Data)
 {
 	gdl_iterator_t it;
@@ -783,7 +804,7 @@ int io_pcb_WritePCB(pcb_plug_io_t *ctx, FILE * FP, const char *old_filename, con
 /*** functions for loading elements-as-pcb ***/
 extern pcb_board_t *yyPCB;
 extern pcb_data_t *yyData;
-extern pcb_font_t *yyFont;
+extern	rnd_font_t *yyRndFont;
 extern int yyElemFixLayers;
 
 void PreLoadElementPCB()
@@ -792,7 +813,7 @@ void PreLoadElementPCB()
 	if (!yyPCB)
 		return;
 
-	yyFont = &yyPCB->fontkit.dflt;
+	yyRndFont = &yyPCB->fontkit.dflt;
 	yyData = yyPCB->Data;
 	PCB_SET_PARENT(yyData, board, yyPCB);
 	yyData->LayerN = 0;
@@ -1049,7 +1070,7 @@ extern	pcb_subc_t *yysubc;
 extern	rnd_coord_t yysubc_ox, yysubc_oy;
 
 pcb_subc_t *io_pcb_element_new(pcb_data_t *Data, pcb_subc_t *subc,
-	pcb_font_t *PCBFont, pcb_flag_t Flags, char *Description, char *NameOnPCB,
+	rnd_font_t *PCBFont, pcb_flag_t Flags, char *Description, char *NameOnPCB,
 	char *Value, rnd_coord_t TextX, rnd_coord_t TextY, unsigned int Direction,
 	int TextScale, pcb_flag_t TextFlags, rnd_bool uniqueName)
 {
