@@ -41,13 +41,78 @@
 #include "obj_poly.h"
 #include <librnd/core/vtc0.h>
 #include "plug_io.h"
+#include "obj_pstk_inlines.h"
 
-int tedax_layer_fsave(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *layname, FILE *f)
+#include "common_inlines.h"
+
+#define LAYERNET(obj) if (nmap != NULL) tedax_finsert_layernet_tags(f, nmap, (pcb_any_obj_t *)obj)
+
+static void tedax_layer_fsave_pstk_polys(pcb_board_t *pcb, pcb_data_t *data, pcb_layer_t *ly, FILE *f)
+{
+	PCB_PADSTACK_LOOP(data) {
+		pcb_pstk_shape_t *shp = pcb_pstk_shape_at(pcb, padstack, ly);
+		if ((shp != NULL) && (shp->shape == PCB_PSSH_POLY)) {
+			int n;
+			fprintf(f, "begin polyline v1 pstk_%p_%p\n", (void *)padstack, (void *)ly);
+			for(n = 0; n < shp->data.poly.len; n++)
+				rnd_fprintf(f, " v %.06mm %.06mm\n", shp->data.poly.x[n], shp->data.poly.y[n]);
+			fprintf(f, "end polyline\n");
+		}
+	}
+	PCB_END_LOOP;
+
+	PCB_SUBC_LOOP(data) {
+		tedax_layer_fsave_pstk_polys(pcb, subc->data, ly, f);
+	}
+	PCB_END_LOOP;
+}
+
+static void tedax_layer_fsave_pstk_shape(pcb_board_t *pcb, pcb_data_t *data, pcb_layer_t *ly, FILE *f, pcb_netmap_t *nmap)
+{
+	PCB_PADSTACK_LOOP(data) {
+		pcb_pstk_shape_t *shp = pcb_pstk_shape_at(pcb, padstack, ly);
+		if (shp == NULL)
+			continue;
+		switch(shp->shape) {
+			case PCB_PSSH_HSHADOW: /* no shape drawn */ break;
+			case PCB_PSSH_LINE:
+				rnd_fprintf(f, " line");
+				LAYERNET(padstack);
+				rnd_fprintf(f, " %.06mm %.06mm %.06mm %.06mm %.06mm %.06mm\n",
+					padstack->x + shp->data.line.x1, padstack->y + shp->data.line.y1,
+					padstack->x + shp->data.line.x2, padstack->y + shp->data.line.y2,
+					shp->data.line.thickness, PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, padstack) ? (rnd_coord_t)rnd_round(padstack->Clearance/2) : 0);
+				break;
+			case PCB_PSSH_CIRC:
+				rnd_fprintf(f, " line");
+				LAYERNET(padstack);
+				rnd_fprintf(f, " %.06mm %.06mm %.06mm %.06mm %.06mm %.06mm\n",
+					padstack->x + shp->data.circ.x, padstack->y + shp->data.circ.y,
+					padstack->x + shp->data.circ.x, padstack->y + shp->data.circ.y,
+					shp->data.circ.dia, PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, padstack) ? (rnd_coord_t)rnd_round(padstack->Clearance/2) : 0);
+				break;
+			case PCB_PSSH_POLY:
+				rnd_fprintf(f, " poly");
+				LAYERNET(padstack);
+				rnd_fprintf(f, " pstk_%p_%p %.06mm %.06mm\n", (void *)padstack, (void *)ly, padstack->x, padstack->y);
+				break;
+		}
+	}
+	PCB_END_LOOP;
+
+	PCB_SUBC_LOOP(data) {
+		tedax_layer_fsave_pstk_shape(pcb, subc->data, ly, f, nmap);
+	}
+	PCB_END_LOOP;
+}
+
+int tedax_layer_fsave(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *layname, FILE *f, pcb_netmap_t *nmap)
 {
 	char lntmp[64];
 	int lno;
 	rnd_pline_t *pl;
 	long plid;
+	const char *blockid = ((nmap == NULL) ? "layer" : "layernet");
 	pcb_layergrp_t *g = pcb_get_layergrp(pcb, gid);
 
 	if (g == NULL)
@@ -80,15 +145,31 @@ int tedax_layer_fsave(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *layna
 				fprintf(f, "end polyline\n");
 			}
 		} PCB_END_LOOP;
+
+		if (nmap != NULL) { /* text objets have to be approximated with a rectangular polygon "keepout" */
+			PCB_TEXT_LOOP(ly) {
+				fprintf(f, "begin polyline v1 txlay_%ld\n", text->ID);
+				rnd_fprintf(f, " v %.06mm %.06mm\n", text->bbox_naked.X1, text->bbox_naked.Y1);
+				rnd_fprintf(f, " v %.06mm %.06mm\n", text->bbox_naked.X1, text->bbox_naked.Y2);
+				rnd_fprintf(f, " v %.06mm %.06mm\n", text->bbox_naked.X2, text->bbox_naked.Y2);
+				rnd_fprintf(f, " v %.06mm %.06mm\n", text->bbox_naked.X2, text->bbox_naked.Y1);
+				fprintf(f, "end polyline\n");
+			} PCB_END_LOOP;
+
+			if (lno == 0)
+				tedax_layer_fsave_pstk_polys(pcb, pcb->Data, ly, f);
+		}
 	}
 
-	fprintf(f, "begin layer v1 %s\n", layname);
+	fprintf(f, "begin %s v1 %s\n", blockid, layname);
 	for(lno = 0; lno < g->len; lno++) {
 		pcb_layer_t *ly = pcb_get_layer(pcb->Data, g->lid[lno]);
 		if (ly == NULL)
 			continue;
 		PCB_LINE_LOOP(ly) {
-			rnd_fprintf(f, " line %.06mm %.06mm %.06mm %.06mm %.06mm %.06mm\n",
+			rnd_fprintf(f, " line");
+			LAYERNET(line);
+			rnd_fprintf(f, " %.06mm %.06mm %.06mm %.06mm %.06mm %.06mm\n",
 				line->Point1.X, line->Point1.Y, line->Point2.X, line->Point2.Y,
 				line->Thickness, PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, line) ? rnd_round(line->Clearance/2) : 0);
 		} PCB_END_LOOP;
@@ -101,8 +182,9 @@ int tedax_layer_fsave(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *layna
 			pcb_arc_get_end(arc, 0, &sx, &sy);
 			pcb_arc_get_end(arc, 1, &ex, &ey);
 			clr = PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, arc) ? rnd_round(arc->Clearance/2) : 0;
-
-			rnd_fprintf(f, " arc %.06mm %.06mm %.06mm %f %f %.06mm %.06mm ",
+			rnd_fprintf(f, " arc");
+			LAYERNET(arc);
+			rnd_fprintf(f, " %.06mm %.06mm %.06mm %f %f %.06mm %.06mm ",
 				arc->X, arc->Y, arc->Width, arc->StartAngle, arc->Delta, arc->Thickness, clr);
 			rnd_fprintf(f, "%.06mm %.06mm %.06mm %.06mm\n", sx, sy, ex, ey);
 		} PCB_END_LOOP;
@@ -111,26 +193,40 @@ int tedax_layer_fsave(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *layna
 			for(gfx = gfxlist_first(&ly->Gfx); gfx != NULL; gfx = gfxlist_next(gfx))
 				pcb_io_incompat_save(pcb->Data, (pcb_any_obj_t *)gfx, "gfx", "gfx can not be exported", "please use the lihata board format");
 		}
-		PCB_TEXT_LOOP(ly) {
-			int scale;
-			if (pcb_text_old_scale(text, &scale) != 0)
-				pcb_io_incompat_save(pcb->Data, (pcb_any_obj_t *)text, "text-scale", "file format does not support different x and y direction text scale - using average scale", "Use the scale field, set scale_x and scale_y to 0");
-			if (text->mirror_x)
-				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text-mirror-x", "file format does not support different mirroring text in the x direction", "do not mirror, or mirror in the y direction (with the ONSOLDER flag)");
-			rnd_fprintf(f, " text %.06mm %.06mm %.06mm %.06mm %d %f %.06mm ",
-				text->bbox_naked.X1, text->bbox_naked.Y1, text->bbox_naked.X2, text->bbox_naked.Y2,
-				scale, text->rot, PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, text) ? 1 : 0);
-			tedax_fprint_escape(f, text->TextString);
-			fputc('\n', f);
-		} PCB_END_LOOP;
+
+		if (nmap == NULL) {
+			PCB_TEXT_LOOP(ly) {
+				int scale;
+				if (pcb_text_old_scale(text, &scale) != 0)
+					pcb_io_incompat_save(pcb->Data, (pcb_any_obj_t *)text, "text-scale", "file format does not support different x and y direction text scale - using average scale", "Use the scale field, set scale_x and scale_y to 0");
+				if (text->mirror_x)
+					pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text-mirror-x", "file format does not support different mirroring text in the x direction", "do not mirror, or mirror in the y direction (with the ONSOLDER flag)");
+				rnd_fprintf(f, " text %.06mm %.06mm %.06mm %.06mm %d %f %.06mm ",
+					text->bbox_naked.X1, text->bbox_naked.Y1, text->bbox_naked.X2, text->bbox_naked.Y2,
+					scale, text->rot, PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, text) ? 1 : 0);
+				tedax_fprint_escape(f, text->TextString);
+				fputc('\n', f);
+			} PCB_END_LOOP;
+		}
+		else {
+			PCB_TEXT_LOOP(ly) {
+				rnd_fprintf(f, " poly");
+				LAYERNET(text);
+				rnd_fprintf(f, " txlay_%ld 0 0\n", text->ID);
+			} PCB_END_LOOP;
+		}
 
 		PCB_POLY_LOOP(ly) {
-			for(pl = polygon->NoHoles, plid = 0; pl != NULL; pl = pl->next, plid++)
-				rnd_fprintf(f, " poly pllay_%ld_%ld_%ld 0 0\n", gid, polygon->ID, plid);
+			for(pl = polygon->NoHoles, plid = 0; pl != NULL; pl = pl->next, plid++) {
+				rnd_fprintf(f, " poly");
+				LAYERNET(polygon);
+				rnd_fprintf(f, " pllay_%ld_%ld_%ld 0 0\n", gid, polygon->ID, plid);
+			}
 		} PCB_END_LOOP;
-
+		if (lno == 0)
+			tedax_layer_fsave_pstk_shape(pcb, pcb->Data, ly, f, nmap);
 	}
-	fprintf(f, "end layer\n");
+	fprintf(f, "end %s\n", blockid);
 	return 0;
 }
 
@@ -145,7 +241,7 @@ int tedax_layer_save(pcb_board_t *pcb, rnd_layergrp_id_t gid, const char *laynam
 		return -1;
 	}
 	fprintf(f, "tEDAx v1\n");
-	res = tedax_layer_fsave(pcb, gid, layname, f);
+	res = tedax_layer_fsave(pcb, gid, layname, f, NULL);
 	fclose(f);
 	return res;
 }
