@@ -200,6 +200,17 @@ int tedax_route_req_save(pcb_board_t *pcb, const char *fn, int cfg_argc, fgw_arg
 		continue; \
 	}
 
+
+#define PARSE_DOUBLE(dst, src) \
+	do { \
+		char *end; \
+		dst = strtod(src, &end); \
+		if (*end != '\0') { \
+			rnd_message(RND_MSG_ERROR, "External autorouter: invalid decimal '%s'\n", src); \
+			continue; \
+		} \
+	} while(0)
+
 int tedax_route_res_fload(FILE *fn, const char *blk_id, int silent)
 {
 	char line[520];
@@ -275,6 +286,21 @@ int tedax_route_res_fload(FILE *fn, const char *blk_id, int silent)
 				if (line != NULL)
 					pcb_undo_add_obj_to_create(PCB_OBJ_LINE, ly, line, line);
 			}
+			else if ((argc == 16) && (strcmp(argv[2], "arc") == 0)) {
+				rnd_coord_t cx, cy, r, th, cl;
+				double sa, da;
+				pcb_arc_t *arc;
+				PARSE_COORD(cx, argv[5]);
+				PARSE_COORD(cy, argv[6]);
+				PARSE_COORD(r, argv[7]);
+				PARSE_DOUBLE(sa, argv[8]);
+				PARSE_DOUBLE(da, argv[9]);
+				PARSE_COORD(th, argv[10]);
+				PARSE_COORD(cl, argv[11]);
+				arc = pcb_arc_new(ly, cx, cy, r, r, sa, da, th, cl, pcb_flag_make(PCB_FLAG_CLEARLINE | PCB_FLAG_AUTO), 1);
+				if (arc != NULL)
+					pcb_undo_add_obj_to_create(PCB_OBJ_ARC, ly, arc, arc);
+			}
 			else
 				rnd_message(RND_MSG_ERROR, "External autorouter: can't add object type '%s' with %d args\n", argv[2], argc);
 			cnt_add++;
@@ -331,9 +357,9 @@ do { \
 	cfg->min_val = -HUGE_VAL; cfg->max_val = HUGE_VAL; \
 	v = strtod(s, &end); \
 	if (*end == ':') { \
-		cfg->min_val = strtod(s, &end); \
+		cfg->min_val = strtod(end+1, &end); \
 		if (*end == ':') \
-			cfg->max_val = strtod(s, &end); \
+			cfg->max_val = strtod(end+1, &end); \
 	} \
 } while(0)
 
@@ -390,6 +416,8 @@ void *tedax_route_conf_keys_fload(FILE *fn, const char *blk_id, int silent)
 				case RND_HATT_COORD:
 					LOAD_MINMAX(argv[3]);
 					cfg->default_val.crd = RND_MM_TO_COORD(v);
+					cfg->min_val = RND_MM_TO_COORD(cfg->min_val);
+					cfg->max_val = RND_MM_TO_COORD(cfg->max_val);
 					break;
 				case RND_HATT_STRING:
 					cfg->default_val.str = rnd_strdup(argv[3]);
