@@ -28,28 +28,28 @@
 
 #include "board.h"
 #include "conf_core.h"
-#include "safe_fs.h"
+#include <librnd/core/safe_fs.h>
 
-static pcb_hidval_t infobar_timer;
+static rnd_hidval_t infobar_timer;
 static int infobar_timer_active = 0;
 static double last_interval = -2;
 static double last_date = -1;
 static int infobar_gui_inited = 0;
 
-static void pcb_infobar_brdchg_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void pcb_infobar_brdchg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
-	pcb_actionva(hidlib, "InfoBarFileChanged", "close", NULL);
+	rnd_actionva(hidlib, "InfoBarFileChanged", "close", NULL);
 	if ((hidlib != NULL) && (hidlib->filename != NULL))
-		last_date = pcb_file_mtime(NULL, PCB->hidlib.filename);
+		last_date = rnd_file_mtime(NULL, PCB->hidlib.filename);
 	else
 		last_date = -1;
 }
 
 
-static void infobar_tick(pcb_hidval_t user_data)
+static void infobar_tick(rnd_hidval_t user_data)
 {
 	if (conf_core.rc.file_changed_interval > 0) {
-		infobar_timer = pcb_gui->add_timer(pcb_gui, infobar_tick, (conf_core.rc.file_changed_interval * 1000.0), user_data);
+		infobar_timer = rnd_gui->add_timer(rnd_gui, infobar_tick, (conf_core.rc.file_changed_interval * 1000.0), user_data);
 		last_interval = conf_core.rc.file_changed_interval;
 		infobar_timer_active = 1;
 	}
@@ -58,28 +58,28 @@ static void infobar_tick(pcb_hidval_t user_data)
 
 	if (infobar_timer_active) { /* check for file change */
 		if ((PCB != NULL) && (PCB->hidlib.filename != NULL)) {
-			double last_chg = pcb_file_mtime(NULL, PCB->hidlib.filename);
+			double last_chg = rnd_file_mtime(NULL, PCB->hidlib.filename);
 			if (last_chg > last_date) {
 				last_date = last_chg;
-				pcb_actionva(&PCB->hidlib, "InfoBarFileChanged", "open", NULL);
+				rnd_actionva(&PCB->hidlib, "InfoBarFileChanged", "open", NULL);
 			}
 		}
 	}
 }
 
-static void pcb_infobar_update_conf(conf_native_t *cfg, int arr_idx)
+static void pcb_infobar_update_conf(rnd_conf_native_t *cfg, int arr_idx)
 {
 	if ((!infobar_gui_inited) || (last_interval == conf_core.rc.file_changed_interval))
 		return;
-	if ((infobar_timer_active) && (pcb_gui != NULL) && (pcb_gui->stop_timer != NULL)) {
-		pcb_gui->stop_timer(pcb_gui, infobar_timer);
+	if ((infobar_timer_active) && (rnd_gui != NULL) && (rnd_gui->stop_timer != NULL)) {
+		rnd_gui->stop_timer(rnd_gui, infobar_timer);
 		infobar_timer_active = 0;
 	}
 	infobar_tick(infobar_timer);
 }
 
 
-static void pcb_infobar_gui_init_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void pcb_infobar_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	infobar_gui_inited = 1;
 	pcb_infobar_brdchg_ev(hidlib, NULL, 0, NULL); /* this may have happened ebfore plugin init if file was specified on the CLI and is already loaded - pick up file data from memory */
@@ -87,11 +87,11 @@ static void pcb_infobar_gui_init_ev(pcb_hidlib_t *hidlib, void *user_data, int a
 		infobar_tick(infobar_timer);
 }
 
-static void pcb_infobar_fn_chg_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void pcb_infobar_fn_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	if ((PCB != NULL) && (PCB->hidlib.filename != NULL)) {
-		last_date = pcb_file_mtime(NULL, PCB->hidlib.filename);
-		pcb_actionva(hidlib, "InfoBarFileChanged", "close", NULL);
+		last_date = rnd_file_mtime(NULL, PCB->hidlib.filename);
+		rnd_actionva(hidlib, "InfoBarFileChanged", "close", NULL);
 	}
 }
 
