@@ -31,9 +31,9 @@
 #include "funchash_core.h"
 #include "layer.h"
 
-static int (*gui_set_layer_group)(pcb_hid_t *hid, pcb_layergrp_id_t group, const char *purpose, int purpi, pcb_layer_id_t layer, unsigned int flags, int is_empty, pcb_xform_t **xform);
+static int (*gui_set_layer_group)(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform);
 
-static int common_set_layer_group(pcb_hid_t *hid, pcb_layergrp_id_t group, const char *purpose, int purpi, pcb_layer_id_t layer, unsigned int flags, int is_empty, pcb_xform_t **xform)
+static int common_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	int idx = group;
 	if (idx >= 0 && idx < pcb_max_group(PCB)) {
@@ -77,7 +77,7 @@ static int common_set_layer_group(pcb_hid_t *hid, pcb_layergrp_id_t group, const
 	return 0;
 }
 
-static int pcbui_set_layer_group(pcb_hid_t *hid, pcb_layergrp_id_t group, const char *purpose, int purpi, pcb_layer_id_t layer, unsigned int flags, int is_empty, pcb_xform_t **xform)
+static int pcbui_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, const char *purpose, int purpi, rnd_layer_id_t layer, unsigned int flags, int is_empty, rnd_xform_t **xform)
 {
 	int res;
 
@@ -90,10 +90,10 @@ static int pcbui_set_layer_group(pcb_hid_t *hid, pcb_layergrp_id_t group, const
 	return common_set_layer_group(hid, group, purpose, purpi, layer, flags, is_empty, xform);
 }
 
-static void pcb_rendering_gui_init_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void pcb_rendering_gui_init_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	/* hook in our dispatcher */
-	gui_set_layer_group = pcb_gui->set_layer_group;
-	pcb_gui->set_layer_group = pcbui_set_layer_group;
+	gui_set_layer_group = rnd_gui->set_layer_group;
+	rnd_gui->set_layer_group = pcbui_set_layer_group;
 }
 
