@@ -55,7 +55,7 @@ static rst_ctx_t rst;
 static void rst_install_menu(void)
 {
 	rnd_menu_prop_t props;
-	char act[256], chk[256], *path, *end;
+	char act[256], chk[256], accel[256], *path, *end, *acc;
 	int idx;
 	size_t len = 0;
 
@@ -71,9 +71,13 @@ static void rst_install_menu(void)
 	memset(&props, 0,sizeof(props));
 	props.action = act;
 	props.checked = chk;
+	props.accel = accel;
 	props.update_on = "";
 	props.cookie = "lib_hid_pcbui route styles";
 
+	strcpy(accel, "<key>r;<key>.");
+	acc = accel + 12;
+
 	/* prepare for appending the strings at the end of the path, "under" the anchor */
 	*end = '/';
 	end++;
@@ -85,6 +89,12 @@ static void rst_install_menu(void)
 		char *sep;
 		sprintf(act, "RouteStyle(%d)", idx+1); /* for historical reasons this action counts from 1 */
 		sprintf(chk, "ChkRst(%d)", idx);
+		if (idx < 9) {
+			*acc = '1' + idx;
+			props.accel = accel;
+		}
+		else
+			props.accel = NULL;
 		strcpy(end, PCB->RouteStyle.array[idx].name);
 		for(sep = end; *sep !='\0'; sep++) /* do not allow '/' in layer name, that would kill the menu system */
 			if (*sep == '/')
@@ -133,7 +143,7 @@ static void rst_update(rnd_hidlib_t *hidlib)
 
 	if (rst.sub_inited) {
 		int n, target;
-		target = pcb_lookup_route_style_pen_bestfit(PCB);
+		target = rstdlg_lookup_route_style_pen_bestfit(PCB);
 		for(n = 0; n < vtroutestyle_len(&PCB->RouteStyle); n++) {
 			rnd_hid_attr_val_t hv;
 
@@ -166,7 +176,7 @@ static void rst_select_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t
 	}
 	if (ridx < 0)
 		return;
-	pcb_use_route_style(&(PCB->RouteStyle.array[ridx]));
+	pcb_use_route_style_idx(PCB, ridx);
 	rst_force_update_chk_and_dlg();
 }
 
@@ -180,8 +190,9 @@ static void rst_edit_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *a
 static void rst_new_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	int target = pcb_route_style_new(PCB, "new style", 1);
-	pcb_use_route_style(&(PCB->RouteStyle.array[target]));
+	pcb_use_route_style_idx(PCB, target);
 	pcb_dlg_rstdlg(target);
+	rst_updated(NULL); /* get the new style selected in the route style selector */
 }
 
 static void rst_del_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
