@@ -33,23 +33,23 @@
 #include "board.h"
 #include "data.h"
 #include "draw.h"
-#include "error.h"
+#include <librnd/core/error.h>
 #include "event.h"
 #include "plug_io.h"
 #include "find.h"
 #include "polygon.h"
 #include "search.h"
 #include "undo.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "netlist.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
 #include "obj_common.h"
 #include "obj_subc_parent.h"
 
 #include "pcb-mincut/graph.h"
 #include "pcb-mincut/solve.h"
 
-#include "conf.h"
+#include <librnd/core/conf.h>
 #include "rats_mincut_conf.h"
 conf_mincut_t conf_mincut;
 
@@ -111,7 +111,7 @@ static int proc_short_cb(pcb_find_t *fctx, pcb_any_obj_t *curr, pcb_any_obj_t *f
 /* returns 0 on succes */
 static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int *cancel)
 {
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	short_conn_t *n, **lut_by_oid, **lut_by_gid, *next;
 	int gids;
 	gr_t *g;
@@ -166,12 +166,12 @@ static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int
 		}
 		if (parent != NULL) {
 			if (parent->refdes == NULL)
-				s = pcb_strdup_printf("%s #%ld \\nof #%ld", typ, n->to->ID, parent->ID);
+				s = rnd_strdup_printf("%s #%ld \\nof #%ld", typ, n->to->ID, parent->ID);
 			else
-				s = pcb_strdup_printf("%s #%ld \\nof %s", typ, n->to->ID, parent->refdes);
+				s = rnd_strdup_printf("%s #%ld \\nof %s", typ, n->to->ID, parent->refdes);
 		}
 		else
-			s = pcb_strdup_printf("%s #%ld", typ, n->to->ID);
+			s = rnd_strdup_printf("%s #%ld", typ, n->to->ID);
 
 		g->node2name[n->gid] = s;
 		if ((o->term == NULL) && (o->type != PCB_OBJ_RAT))
@@ -185,8 +185,8 @@ static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int
 	if (nonterms < 1)
 		bad_gr = 1;
 
-	g->node2name[0] = pcb_strdup("S");
-	g->node2name[1] = pcb_strdup("T");
+	g->node2name[0] = rnd_strdup("S");
+	g->node2name[1] = rnd_strdup("T");
 
 	/* calculate how many edges each node has and the max edge count */
 	maxedges = 0;
@@ -240,7 +240,7 @@ static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int
 					}
 				}
 				else
-					pcb_message(PCB_MSG_WARNING, "Ignoring subcircuit %ld connecting to a net because it has no refdes;\nplease use the nonetlist flag on the subcircuit to suppress this warning\n", sc->ID);
+					rnd_message(RND_MSG_WARNING, "Ignoring subcircuit %ld connecting to a net because it has no refdes;\nplease use the nonetlist flag on the subcircuit to suppress this warning\n", sc->ID);
 			}
 		}
 
@@ -282,7 +282,7 @@ static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int
 #endif
 
 	if (!bad_gr) {
-		solution = pcb_mincut_solve(g, pcb_hid_progress, cancel);
+		solution = pcb_mincut_solve(g, rnd_hid_progress, cancel);
 		if (cancel)
 			return 1;
 
@@ -323,7 +323,7 @@ static int proc_short(pcb_any_obj_t *term, pcb_net_t *Snet, pcb_net_t *Tnet, int
 	return bad_gr;
 }
 
-static void pcb_mincut_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void pcb_mincut_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	int *handled, *cancel;
 	pcb_any_obj_t *term;
@@ -335,22 +335,22 @@ static void pcb_mincut_ev(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_e
 	if (argc < 5)
 		return;
 
-	if ((argv[4].type != PCB_EVARG_PTR) || (argv[5].type != PCB_EVARG_PTR))
+	if ((argv[4].type != RND_EVARG_PTR) || (argv[5].type != RND_EVARG_PTR))
 		return;
 	handled = (int *)argv[4].d.p;
 	cancel = (int *)argv[5].d.p;
 	if (*handled || *cancel)
 		return;
 
-	if (argv[2].type != PCB_EVARG_PTR)
+	if (argv[2].type != RND_EVARG_PTR)
 		return;
 	term = (pcb_any_obj_t *)argv[2].d.p;
 
-	if (argv[1].type != PCB_EVARG_PTR)
+	if (argv[1].type != RND_EVARG_PTR)
 		return;
 	Snet = (pcb_net_t *)argv[1].d.p;
 
-	if (argv[3].type != PCB_EVARG_PTR)
+	if (argv[3].type != RND_EVARG_PTR)
 		return;
 	Tnet = (pcb_net_t *)argv[3].d.p;
 
@@ -363,18 +363,18 @@ int pplg_check_ver_mincut(int ver_needed) { return 0; }
 
 void pplg_uninit_mincut(void)
 {
-	pcb_conf_unreg_fields("plugins/mincut/");
-	pcb_event_unbind_allcookie(pcb_mincut_cookie);
+	rnd_conf_unreg_fields("plugins/mincut/");
+	rnd_event_unbind_allcookie(pcb_mincut_cookie);
 }
 
 int pplg_init_mincut(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
-	pcb_event_bind(PCB_EVENT_NET_INDICATE_SHORT, pcb_mincut_ev, NULL, pcb_mincut_cookie);
+	rnd_event_bind(PCB_EVENT_NET_INDICATE_SHORT, pcb_mincut_ev, NULL, pcb_mincut_cookie);
 
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
-	pcb_conf_reg_field(conf_mincut, field,isarray,type_name,cpath,cname,desc,flags);
+	rnd_conf_reg_field(conf_mincut, field,isarray,type_name,cpath,cname,desc,flags);
 #include "rats_mincut_conf_fields.h"
 	return 0;
 }
