@@ -245,6 +245,7 @@ static void map_poly(pcb_propedit_t *ctx, pcb_poly_t *poly)
 static void map_pstk(pcb_propedit_t *ctx, pcb_pstk_t *ps)
 {
 	pcb_pstk_proto_t *proto;
+	rnd_layergrp_id_t gid;
 
 	map_add_prop(ctx, "p/padstack/xmirror", rnd_coord_t, ps->xmirror);
 	map_add_prop(ctx, "p/padstack/smirror", rnd_coord_t, ps->smirror);
@@ -265,6 +266,26 @@ static void map_pstk(pcb_propedit_t *ctx, pcb_pstk_t *ps)
 		map_add_prop(ctx, "p/padstack/x", rnd_coord_t, ps->x);
 		map_add_prop(ctx, "p/padstack/y", rnd_coord_t, ps->y);
 	}
+
+
+	for(gid = 0; gid < ctx->pcb->LayerGroups.len; gid++) {
+		int n;
+		pcb_layergrp_t *g = &ctx->pcb->LayerGroups.grp[gid];
+
+		if (!(g->ltype & PCB_LYT_COPPER))
+			continue;
+		for(n = 0; n < g->len; n++) {
+			rnd_layer_id_t lid = g->lid[n];
+			int th = lid < ps->thermals.used ? ps->thermals.shape[lid] : 0;
+			char tmp[256], val[8];
+
+			sprintf(tmp, "p/padstack/thermal/lid/%ld", lid);
+			pcb_thermal_bits2chars(val, th);
+			map_add_prop(ctx, tmp, String, rnd_strdup(val));
+		}
+	}
+
+
 }
 
 static void map_subc(pcb_propedit_t *ctx, pcb_subc_t *msubc)
@@ -305,10 +326,37 @@ static void map_subc(pcb_propedit_t *ctx, pcb_subc_t *msubc)
 	}
 }
 
-static void map_any(pcb_propedit_t *ctx, pcb_any_obj_t *o)
+static long pcb_propsel_do(pcb_board_t *pcb, pcb_data_t *data, int data_in_subc, void *ctx, long (*cb)(void *ctx, pcb_any_obj_t *o, const void *udata), const void *udata)
 {
+	pcb_any_obj_t *o;
+	pcb_data_it_t it;
+	long res = 0;
+
+	TODO("TODO#28: should be rtree based for recursion");
+	for(o = pcb_data_first(&it, data, PCB_OBJ_CLASS_REAL); o != NULL; o = pcb_data_next(&it)) {
+		if (data_in_subc) {
+			if (!pcb_subc_part_editable(pcb, o))
+				continue; /* subc lock: skip any selected object within a subc */
+		}
+		else {
+			if (o->type == PCB_OBJ_SUBC) {
+				pcb_subc_t *subc = (pcb_subc_t *)o;
+				res += pcb_propsel_do(pcb, subc->data, 1, ctx, cb, udata); /* recurse to subcircuits on the first (board) level */
+			}
+		}
+
+		if (PCB_FLAG_TEST(PCB_FLAG_SELECTED, o))
+			res += cb(ctx, o, udata);
+	}
+
+	return res;
+}
+
+static long map_any(void *ctx_, pcb_any_obj_t *o, const void *udata)
+{
+	pcb_propedit_t *ctx = ctx_;
 	if (o == NULL)
-		return;
+		return 0;
 	switch(o->type) {
 		case PCB_OBJ_ARC:  map_arc(ctx, (pcb_arc_t *)o); break;
 		case PCB_OBJ_GFX:  map_gfx(ctx, (pcb_gfx_t *)o); break;
@@ -317,8 +365,9 @@ static void map_any(pcb_propedit_t *ctx, pcb_any_obj_t *o)
 		case PCB_OBJ_TEXT: map_text(ctx, (pcb_text_t *)o); break;
 		case PCB_OBJ_SUBC: map_subc(ctx, (pcb_subc_t *)o); break;
 		case PCB_OBJ_PSTK: map_pstk(ctx, (pcb_pstk_t *)o); break;
-		default: break;
+		default: return 0;
 	}
+	return 1;
 }
 
 void pcb_propsel_map_core(pcb_propedit_t *ctx)
@@ -333,7 +382,7 @@ void pcb_propsel_map_core(pcb_propedit_t *ctx)
 		map_layergrp(ctx, pcb_get_layergrp(ctx->pcb, ctx->layergrps.array[n]));
 
 	for(idp = pcb_idpath_list_first(&ctx->objs); idp != NULL; idp = pcb_idpath_list_next(idp))
-		map_any(ctx, pcb_idpath2obj_in(ctx->data, idp));
+		map_any(ctx, pcb_idpath2obj_in(ctx->data, idp), NULL);
 
 	if (ctx->nets_inited) {
 		htsp_entry_t *e;
@@ -341,14 +390,8 @@ void pcb_propsel_map_core(pcb_propedit_t *ctx)
 			map_net(ctx, e->key);
 	}
 
-	if (ctx->selection) {
-		pcb_any_obj_t *o;
-		pcb_data_it_t it;
-		TODO("TODO#28: should be rtree based for recursion");
-		for(o = pcb_data_first(&it, ctx->data, PCB_OBJ_CLASS_REAL); o != NULL; o = pcb_data_next(&it))
-			if (PCB_FLAG_TEST(PCB_FLAG_SELECTED, o))
-				map_any(ctx, o);
-	}
+	if (ctx->selection)
+		pcb_propsel_do(ctx->pcb, ctx->data, 0, ctx, map_any, NULL);
 
 	if (ctx->board)
 		map_board(ctx, ctx->pcb);
@@ -823,6 +866,24 @@ static void set_poly(pcb_propset_ctx_t *st, pcb_poly_t *poly)
 	}
 }
 
+static void set_pstk_thermal(pcb_propset_ctx_t *st, pcb_pstk_t *ps, const char *pn)
+{
+	rnd_layer_id_t lid;
+	char *end;
+	pcb_thermal_t t;
+
+	if (strncmp(pn, "lid/", 4) != 0) return;
+	pn+=4;
+
+	lid = strtol(pn, &end, 10);
+	if (*end != '\0') return;
+
+	if (pcb_thermal_chars2bits(&t, st->s) != 0) return;
+
+	pcb_pstk_set_thermal(ps, lid, t, 1);
+	DONE;
+}
+
 static void set_pstk(pcb_propset_ctx_t *st, pcb_pstk_t *ps)
 {
 	const char *pn = st->name + 11;
@@ -847,6 +908,10 @@ static void set_pstk(pcb_propset_ctx_t *st, pcb_pstk_t *ps)
 	if (strncmp(st->name, "p/padstack/", 11) == 0) {
 		pcb_opctx_t op;
 
+		if (strncmp(pn, "thermal/", 8) == 0) {
+			set_pstk_thermal(st, ps, pn+8);
+			return;
+		}
 		if (st->c_valid && (strcmp(pn, "clearance") == 0) &&
 		    pcb_chg_obj_clear_size(PCB_OBJ_PSTK, ps, ps, NULL, st->c*2, st->c_absolute)) DONE;
 		if (st->d_valid && (strcmp(pn, "rotation") == 0)) {
@@ -954,10 +1019,11 @@ static void set_subc(pcb_propset_ctx_t *st, pcb_subc_t *ssubc)
 	}
 }
 
-static void set_any(pcb_propset_ctx_t *ctx, pcb_any_obj_t *o)
+static long set_any(void *ctx_, pcb_any_obj_t *o, const void *udata)
 {
+	pcb_propset_ctx_t *ctx = ctx_;
 	if (o == NULL)
-		return;
+		return 0;
 	switch(o->type) {
 		case PCB_OBJ_ARC:  set_arc(ctx, (pcb_arc_t *)o); break;
 		case PCB_OBJ_GFX:  set_gfx(ctx, (pcb_gfx_t *)o); break;
@@ -966,8 +1032,9 @@ static void set_any(pcb_propset_ctx_t *ctx, pcb_any_obj_t *o)
 		case PCB_OBJ_TEXT: set_text(ctx, (pcb_text_t *)o); break;
 		case PCB_OBJ_SUBC: set_subc(ctx, (pcb_subc_t *)o); break;
 		case PCB_OBJ_PSTK: set_pstk(ctx, (pcb_pstk_t *)o); break;
-		default: break;
+		default: return 0;
 	}
+	return 1;
 }
 
 int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sctx)
@@ -993,7 +1060,7 @@ int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sc
 		pcb_any_obj_t *obj = pcb_idpath2obj_in(ctx->data, idp);
 		if (obj == NULL) /* workaround: idp sometimes points into the buffer */
 			obj = pcb_idpath2obj(PCB, idp);
-		set_any(sctx, obj);
+		set_any(sctx, obj, NULL);
 	}
 
 	if (ctx->nets_inited) {
@@ -1005,14 +1072,8 @@ int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sc
 			pcb_ratspatch_make_edited(sctx->pcb);
 	}
 
-	if (ctx->selection) {
-		pcb_any_obj_t *o;
-		pcb_data_it_t it;
-		TODO("TODO#28: should be rtree based for recursion");
-		for(o = pcb_data_first(&it, ctx->data, PCB_OBJ_CLASS_REAL); o != NULL; o = pcb_data_next(&it))
-			if (PCB_FLAG_TEST(PCB_FLAG_SELECTED, o))
-				set_any(sctx, o);
-	}
+	if (ctx->selection)
+		pcb_propsel_do(ctx->pcb, ctx->data, 0, sctx, set_any, NULL);
 
 	if (ctx->board)
 		set_board(sctx, ctx->pcb);
@@ -1105,7 +1166,7 @@ static long del_net(pcb_propedit_t *ctx, const char *netname, const char *key)
 	return 1;
 }
 
-static long del_any(void *ctx, pcb_any_obj_t *o, const char *key)
+static long del_any(void *ctx, pcb_any_obj_t *o, const void *key)
 {
 	return del_attr(ctx, &o->Attributes, key);
 }
@@ -1144,14 +1205,8 @@ int pcb_propsel_del(pcb_propedit_t *ctx, const char *key)
 			pcb_ratspatch_make_edited(ctx->pcb);
 	}
 
-	if (ctx->selection) {
-		pcb_any_obj_t *o;
-		pcb_data_it_t it;
-		TODO("TODO#28: should be rtree based for recursion");
-		for(o = pcb_data_first(&it, ctx->data, PCB_OBJ_CLASS_REAL); o != NULL; o = pcb_data_next(&it))
-			if (PCB_FLAG_TEST(PCB_FLAG_SELECTED, o))
-				del_cnt += del_any(ctx, o, key);
-	}
+	if (ctx->selection)
+		del_cnt += pcb_propsel_do(ctx->pcb, ctx->data, 0, ctx, del_any, key);
 
 	if (ctx->board)
 		del_cnt += del_board(&ctx, ctx->pcb, key);
