@@ -32,7 +32,7 @@
 #include "config.h"
 
 #define REPORT_TYPES \
-	(PCB_OBJ_PSTK | PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_POLY | \
+	(PCB_OBJ_PSTK | PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_POLY | PCB_OBJ_GFX | \
 	 PCB_OBJ_ARC | PCB_OBJ_RAT | PCB_OBJ_POLY_POINT | \
 	 PCB_OBJ_LINE_POINT | PCB_OBJ_SUBC_PART | PCB_OBJ_SUBC)
 
