@@ -159,7 +159,7 @@ static void *shn_render_cb(void *ctx, pcb_any_obj_t *obj)
 	const char *netname;
 	pcb_draw_info_t *info = ctx;
 	rnd_coord_t x, y, dx, dy;
-	pcb_font_t *font;
+	rnd_font_t *font;
 	double rot, vx, vy, nx, ny, len, lscale;
 	shn_net_t *shn = NULL;
 	htshn_entry_t *e;
