@@ -1,7 +1,7 @@
 /* gsch2pcb-rnd
  *
  *  Original version: Bill Wilson    billw@wt.net
- *  rnd-version: (C) 2015..2016,2020 Tibor 'Igor2' Palinkas
+ *  rnd-version: (C) 2015..2016,2020,2021 Tibor 'Igor2' Palinkas
  *
  *  This program is free software which I release under the GNU General Public
  *  License. You may redistribute and/or modify this program under the terms
@@ -56,12 +56,7 @@
 static const char *want_method_default = "import";
 
 #define CONF_USER_DIR "~/" DOT_PCB_RND
-const char *rnd_conf_userdir_path;
-const char *rnd_pcphl_conf_user_path;
-const char *rnd_conf_sysdir_path;
-const char *rnd_conf_sys_path;
 
-const char *rnd_app_package = "gsch2pcb-rnd";
 
 gdl_list_t pcb_element_list; /* initialized to 0 */
 gadl_list_t schematics, extra_gnetlist_arg_list, extra_gnetlist_list;
@@ -376,7 +371,7 @@ void free_strlist(gadl_list_t *lst)
 void require_gnetlist_backend(const char *dir, const char *backend)
 {
 	char *path = rnd_strdup_printf("%s/gnet-%s.scm", dir, backend);
-	if (!rnd_file_readable(path))
+	if (!rnd_file_readable_(path))
 		rnd_message(RND_MSG_WARNING, "WARNING: %s is not found, gnetlist will probably fail; please check your pcb-rnd installation!\n", path);
 	free(path);
 }
@@ -384,6 +379,8 @@ void require_gnetlist_backend(const char *dir, const char *backend)
 
 const char *local_project_pcb_name = NULL;
 
+void gsch2pcb_conf_core_init(void) {}
+
 /************************ main ***********************/
 int main(int argc, char ** argv)
 {
@@ -391,19 +388,22 @@ int main(int argc, char ** argv)
 
 	method_import_register();
 
-	rnd_conf_userdir_path = CONF_USER_DIR;
-	rnd_pcphl_conf_user_path = rnd_concat(CONF_USER_DIR, "/pcb-conf.lht", NULL);
-	rnd_conf_sysdir_path = PCBCONFDIR;
-	rnd_conf_sys_path = rnd_concat(PCBCONFDIR, "/pcb-conf.lht", NULL);
-	rnd_menu_file_paths[0] = "./";
-	rnd_menu_file_paths[1] = "~/.pcb-rnd/";
-	rnd_menu_file_paths[2] = rnd_concat(PCBCONFDIR, "/", NULL);
-	rnd_menu_file_paths[3] = NULL;
+	rnd_app.package = "gsch2pcb-rnd";
+	rnd_app.version = PCB_VERSION;
+	rnd_app.revision = PCB_REVISION;
+
+	rnd_app.conf_userdir_path = CONF_USER_DIR;
+	rnd_app.conf_user_path = rnd_concat(CONF_USER_DIR, "/conf_core.lht", NULL);
+	rnd_app.conf_sysdir_path = PCBCONFDIR;
+	rnd_app.conf_sys_path = rnd_concat(PCBCONFDIR, "/conf_core.lht", NULL);
+
+	rnd_hidlib_init1(gsch2pcb_conf_core_init);
 
 	rnd_file_loaded_init();
 	rnd_conf_init();
 	conf_core_init();
-	rnd_hidlib_conf_init();
+
+	rnd_conf_set(RND_CFR_CLI, "rc/dup_log_to_stderr", 0, "1", RND_POL_OVERWRITE);
 
 	gadl_list_init(&schematics, sizeof(char *), NULL, NULL);
 	gadl_list_init(&extra_gnetlist_arg_list, sizeof(char *), NULL, NULL);
@@ -422,7 +422,7 @@ int main(int argc, char ** argv)
 	rnd_conf_update(NULL, -1); /* because of CLI changes */
 
 	if (!have_cli_project_file && !have_cli_schematics) {
-		if (!rnd_file_readable(LOCAL_PROJECT_FILE)) {
+		if (!rnd_file_readable_(LOCAL_PROJECT_FILE)) {
 			rnd_message(RND_MSG_ERROR, "Don't know what to do: no project or schematics given, no local project file %s found. Try %s --help\n", LOCAL_PROJECT_FILE, argv[0]);
 			exit(1);
 		}
@@ -493,7 +493,8 @@ int main(int argc, char ** argv)
 
 	current_method->uninit();
 
-	rnd_conf_uninit();
+	conf_core_uninit_pre();
+	rnd_hidlib_uninit();
 
 	free_strlist(&schematics);
 	free_strlist(&extra_gnetlist_arg_list);
